/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:08 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package Aboutbox;
 
import java.awt.*;
import java.io.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.text.*;
import java.net.*;

import DICOMscope;

import jToolkit.Gui.*;


/**
 * Displays an about box in a panel. The content will be get from a html-page
 * in the Aboutbox-folder. The four logos of the participated companies are
 * shown above the information text. Hyperlinks in the content will open
 * the default web browser with the relating site.
 * 
 * @author Andreas Schroeter
 * @since 30.04.1999
 */
public class AboutBox extends Panel implements HyperlinkListener
{
    /**
     * Constructor. Sets up the panel.
     * 
     * @param highQS Use High-QS resolution for output
     * @since 30.04.1999
     */
    public AboutBox (boolean highQS)
    {
        // This code is automatically generated by Visual Cafe when you add
		// components to the visual environment. It instantiates and initializes
		// the components. To modify the code, only use code syntax that matches
		// what Visual Cafe can generate, or Visual Cafe may be unable to back
		// parse your Java file into its visual environment.
		//{{INIT_CONTROLS
		setLayout(new BorderLayout(10,10));
		setBackground (Color.white);
		
		boolean iconsOnTop = true; // false = right side
			
		try
		{		    
		    File fileObject = new File ("icons/about.html");		    			
			URL url = new URL ("file:///" + fileObject.getCanonicalFile());
	        
	        JEditorPane html;		
            html = new JEditorPane ();
            html.setBackground (Color.white);
            html.setContentType ("text/html");
            html.setPage (url); 
                        
            html.setEditable (false);
            html.addHyperlinkListener(this);

            File f;
            URL furl;
            ImageIcon icon;

            f = new File ("icons/uniwh.gif");		    			
			furl = new URL ("file:///" + f.getCanonicalFile());
            icon = new ImageIcon (furl);
            JLabel iconlabel1 = new JLabel (icon);
            
            f = new File ("icons/offis.gif");		    			
			furl = new URL ("file:///" + f.getCanonicalFile());
            icon = new ImageIcon (furl);            
            JLabel iconlabel2 = new JLabel (icon);
            
            f = new File ("icons/otech.gif");		    			
			furl = new URL ("file:///" + f.getCanonicalFile());
            icon = new ImageIcon (furl);
            JLabel iconlabel3 = new JLabel (icon);
            
            f = new File ("icons/lakegriffin.gif");		    			
			furl = new URL ("file:///" + f.getCanonicalFile());
            icon = new ImageIcon (furl);
            JLabel iconlabel4 = new JLabel (icon);            
            
            Panel upperArea = new Panel (new BorderLayout ());
            Panel iconpanel; 
            if (iconsOnTop) iconpanel = new Panel(new GridLayout(1, 4, 10, 10));
            else iconpanel = new Panel(new GridLayout(4, 1, 10, 10));
            iconpanel.add (iconlabel1);
            iconpanel.add (iconlabel2);
            iconpanel.add (iconlabel3);
            iconpanel.add (iconlabel4);
            
            upperArea.add ("Center", iconpanel);
            if (iconsOnTop) upperArea.add ("North", new JLabel ("     "));
            else upperArea.add ("East", new JLabel ("     "));
            
            if (iconsOnTop) add ("North", upperArea);            
            else add ("East", upperArea);
            
            add ("Center", html);
                        
        }
        catch (Exception e)
        {
            add ("Center", new JLabel ("error in Aboutbox!"));
            System.err.println ("error " + e);
            e.printStackTrace();
        }
    }
    
   
    /**
     * Handler for hyperlink clicks
     * 
     * @param e the event
     * @since 30.04.1999
     */
    public void hyperlinkUpdate (HyperlinkEvent e)
    {
        if (e.getEventType() == HyperlinkEvent.EventType.ACTIVATED)
        {         
            BrowserControl.displayURL (e.getURL().toExternalForm());
        }
    }
}
/*
 *  CVS Log
 *  $Log: AboutBox.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:08  Schroeter
 *  initial commit of release 1.0
 *
*/
