/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 * Author :      $Author: Schroeter $
 * Last update : $Date: 1999/05/14 10:02:31 $
 * Revision :    $Revision: 1.2 $
 * State :       $State: Exp $
*/


#include "J2Ci_jDVInterface.h"
#include "J2Ci_jDVPresentationState.h"

#include "jInterface.h"

// ------------------- accessing C++-Objects

inline DVInterface* getAddressOfDVInterface (JNIEnv *env, jobject obj)
{
	jclass cls = env->GetObjectClass (obj);
	jfieldID fid = env->GetFieldID (cls, "cppClassAddress", "J");

	if (fid == 0) exit (-1);

	return (DVInterface*) env->GetLongField (obj, fid);
}

inline void setAddressOfDVInterface (JNIEnv *env, jobject obj, DVInterface* dvi)
{
	jclass cls = env->GetObjectClass (obj);
	jfieldID fid = env->GetFieldID (cls, "cppClassAddress", "J");

	if (fid == 0) exit (-1);

	env->SetLongField (obj, fid, (jlong) dvi);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    createObjOfDVInterface
 * Signature: (Ljava/lang/String;)V
 */
JNIEXPORT void JNICALL Java_J2Ci_jDVInterface_createObjOfDVInterface
  (JNIEnv *env, jobject obj, jstring configfile)
{
	char *fn = (char*) env->GetStringUTFChars (configfile, 0);

	DVInterface *dvi = new DVInterface (fn);

	env->ReleaseStringUTFChars (configfile, fn);	

	setAddressOfDVInterface (env, obj, dvi);
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    removeObjOfDVInterface
 * Signature: ()V
 */
JNIEXPORT void JNICALL Java_J2Ci_jDVInterface_removeObjOfDVInterface
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	delete dvi;
}


// ----------------------------------------------------------------------------
// native Methoden
// ----------------------------------------------------------------------------


/*
 * Class:     J2Ci_jDVInterface
 * Method:    loadImage
 * Signature: (Ljava/lang/String;)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_loadImage__Ljava_lang_String_2
  (JNIEnv *env, jobject obj, jstring filename)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *fn = (char*) env->GetStringUTFChars (filename, 0);

	E_Condition res = dvi->loadImage (fn);

	env->ReleaseStringUTFChars (filename, fn);

	return (jint) res;
}


/*
 * Class:     J2Ci_jDVInterface
 * Method:    loadImage
 * Signature: (Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_loadImage__Ljava_lang_String_2Ljava_lang_String_2Ljava_lang_String_2
  (JNIEnv *env, jobject obj, jstring studyUID, jstring seriesUID, jstring instanceUID)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *stu = (char*) env->GetStringUTFChars (studyUID, 0);
	char *ser = (char*) env->GetStringUTFChars (seriesUID, 0);
	char *ins = (char*) env->GetStringUTFChars (instanceUID, 0);

	E_Condition res = dvi->loadImage (stu, ser, ins);

	env->ReleaseStringUTFChars (studyUID, stu);
	env->ReleaseStringUTFChars (seriesUID, ser);
	env->ReleaseStringUTFChars (instanceUID, ins);

	return (jint) res;
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    loadPState
 * Signature: (Ljava/lang/String;Ljava/lang/String;)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_loadPState__Ljava_lang_String_2Ljava_lang_String_2
  (JNIEnv *env, jobject obj, jstring pstName, jstring imgName)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *psn = (char*) env->GetStringUTFChars (pstName, 0);
	char *imn = (char*) env->GetStringUTFChars (imgName, 0);

	E_Condition res = dvi->loadPState (psn, imn);

	env->ReleaseStringUTFChars (pstName, psn);
	env->ReleaseStringUTFChars (imgName, imn);

	return (jint) res;
}


/*
 * Class:     J2Ci_jDVInterface
 * Method:    loadPState
 * Signature: (Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_loadPState__Ljava_lang_String_2Ljava_lang_String_2Ljava_lang_String_2
  (JNIEnv *env, jobject obj, jstring studyUID, jstring seriesUID, jstring instanceUID)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *stu = (char*) env->GetStringUTFChars (studyUID, 0);
	char *ser = (char*) env->GetStringUTFChars (seriesUID, 0);
	char *ins = (char*) env->GetStringUTFChars (instanceUID, 0);

	// changeStatus = true to change img to "old"
	E_Condition res = dvi->loadPState (stu, ser, ins, OFTrue);

	env->ReleaseStringUTFChars (studyUID, stu);
	env->ReleaseStringUTFChars (seriesUID, ser);
	env->ReleaseStringUTFChars (instanceUID, ins);

	return (jint) res;
}


/*
 * Class:     J2Ci_jDVInterface
 * Method:    savePState
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_savePState__
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	E_Condition res = dvi->savePState();
	
	return (jint) res; 
}


/*
 * Class:     J2Ci_jDVInterface
 * Method:    savePState
 * Signature: (Ljava/lang/String;Z)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_savePState__Ljava_lang_String_2Z
  (JNIEnv *env, jobject obj, jstring filename, jboolean explicitVR)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *fn = (char*) env->GetStringUTFChars (filename, 0);
	OFBool expVR = explicitVR == JNI_TRUE ? OFTrue : OFFalse;
	
	E_Condition res = dvi->savePState(fn, expVR);
	
	env->ReleaseStringUTFChars (filename, fn);

	return (jint) res; 
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getCurrentPStateN
 * Signature: ()J
 */
JNIEXPORT jlong JNICALL Java_J2Ci_jDVInterface_getCurrentPStateN
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	DVPresentationState *ps = &(dvi->getCurrentPState ());

	return (jlong) ps;
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    releaseDatabase
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_releaseDatabase
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	E_Condition res = dvi->releaseDatabase();
	
	return (jint) res; 
}





/*
 * Class:     J2Ci_jDVInterface
 * Method:    getNumberOfStudies
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_getNumberOfStudies
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	int res = dvi->getNumberOfStudies();

	return (jint) res; 
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    selectStudy
 * Signature: (I)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_selectStudy
  (JNIEnv *env, jobject obj, jint index)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	E_Condition res = dvi->selectStudy(index);
	
	return (jint) res; 
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getStudyUID
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getStudyUID
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getStudyUID();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}





/*
 * Class:     J2Ci_jDVInterface
 * Method:    getStudyDescription
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getStudyDescription
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getStudyDescription();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getStudyStatus
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_getStudyStatus
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	DVIFhierarchyStatus res = dvi->getStudyStatus();
	
	return (jint) res;
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getNumberOfSeries
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_getNumberOfSeries
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	int res = dvi->getNumberOfSeries();

	return (jint) res; 
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    selectSeries
 * Signature: (I)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_selectSeries
  (JNIEnv *env, jobject obj, jint index)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	E_Condition res = dvi->selectSeries(index);
	
	return (jint) res; 
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getSeriesUID
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getSeriesUID
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getSeriesUID();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getSeriesStatus
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_getSeriesStatus
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	DVIFhierarchyStatus res = dvi->getSeriesStatus();
	
	return (jint) res;
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    isPresentationStateSeries
 * Signature: ()Z
 */
JNIEXPORT jboolean JNICALL Java_J2Ci_jDVInterface_isPresentationStateSeries
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	OFBool res = dvi->isPresentationStateSeries();
	
	if (res == OFTrue) return JNI_TRUE;
	else return JNI_FALSE;
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getNumberOfInstances
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_getNumberOfInstances
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	int res = dvi->getNumberOfInstances();
	
	return (jint) res; 
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    selectInstance
 * Signature: (I)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_selectInstance
  (JNIEnv *env, jobject obj, jint index)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	E_Condition res = dvi->selectInstance(index);
	
	return (jint) res; 
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getInstanceUID
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getInstanceUID
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getInstanceUID();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getModality
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getModality
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getModality();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getInstanceStatus
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_getInstanceStatus
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	DVIFhierarchyStatus res = dvi->getInstanceStatus();
	
	return (jint) res;
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    isPresentationState
 * Signature: ()Z
 */
JNIEXPORT jboolean JNICALL Java_J2Ci_jDVInterface_isPresentationState
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	OFBool res = dvi->isPresentationState();
	
	if (res == OFTrue) return JNI_TRUE;
	else return JNI_FALSE;
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    instanceReviewed
 * Signature: (Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_instanceReviewed
  (JNIEnv *env, jobject obj, jstring studyUID, jstring seriesUID, jstring instanceUID)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *stu = (char*) env->GetStringUTFChars (studyUID, 0);
	char *ser = (char*) env->GetStringUTFChars (seriesUID, 0);
	char *ins = (char*) env->GetStringUTFChars (instanceUID, 0);

	E_Condition res = dvi->instanceReviewed(stu, ser, ins);

	env->ReleaseStringUTFChars (studyUID, stu);
	env->ReleaseStringUTFChars (seriesUID, ser);
	env->ReleaseStringUTFChars (instanceUID, ins);
	
	return (jint) res;
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    deleteInstance
 * Signature: (Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_deleteInstance
  (JNIEnv *env, jobject obj, jstring studyUID, jstring seriesUID, jstring instanceUID)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *stu = (char*) env->GetStringUTFChars (studyUID, 0);
	char *ser = (char*) env->GetStringUTFChars (seriesUID, 0);
	char *ins = (char*) env->GetStringUTFChars (instanceUID, 0);

	E_Condition res = dvi->deleteInstance(stu, ser, ins);

	env->ReleaseStringUTFChars (studyUID, stu);
	env->ReleaseStringUTFChars (seriesUID, ser);
	env->ReleaseStringUTFChars (instanceUID, ins);
	
	return (jint) res;
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    deleteSeries
 * Signature: (Ljava/lang/String;Ljava/lang/String;)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_deleteSeries
  (JNIEnv *env, jobject obj, jstring studyUID, jstring seriesUID)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *stu = (char*) env->GetStringUTFChars (studyUID, 0);
	char *ser = (char*) env->GetStringUTFChars (seriesUID, 0);

	E_Condition res = dvi->deleteSeries(stu, ser);
	
	env->ReleaseStringUTFChars (studyUID, stu);
	env->ReleaseStringUTFChars (seriesUID, ser);
	
	return (jint) res;
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    deleteStudy
 * Signature: (Ljava/lang/String;)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_deleteStudy
  (JNIEnv *env, jobject obj, jstring studyUID)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *stu = (char*) env->GetStringUTFChars (studyUID, 0);

	E_Condition res = dvi->deleteStudy(stu);
	
	env->ReleaseStringUTFChars (studyUID, stu);

	return (jint) res;
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    sendIOD
 * Signature: (Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_sendIOD
  (JNIEnv *env, jobject obj, jstring targetID, jstring studyUID, jstring seriesUID, jstring instanceUID)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *tid = (char*) env->GetStringUTFChars (targetID, 0);
	char *stu = (char*) env->GetStringUTFChars (studyUID, 0);
	char *ser = (char*) env->GetStringUTFChars (seriesUID, 0);
	char *ins = (char*) env->GetStringUTFChars (instanceUID, 0);

	E_Condition res = dvi->sendIOD(tid, stu, ser, ins);
	
	env->ReleaseStringUTFChars (targetID, tid);
	env->ReleaseStringUTFChars (studyUID, stu);
	env->ReleaseStringUTFChars (seriesUID, ser);
	env->ReleaseStringUTFChars (instanceUID, ins);

	return (jint) res;
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getNumberOfTargets
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_getNumberOfTargets
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	int res = dvi->getNumberOfTargets();
	
	return (jint) res; 
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getTargetID
 * Signature: (I)Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getTargetID
  (JNIEnv *env, jobject obj, jint index)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getTargetID(index);

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getTargetDescription
 * Signature: (I)Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getTargetDescription__I
  (JNIEnv *env, jobject obj, jint index)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getTargetDescription(index);

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getTargetDescription
 * Signature: (Ljava/lang/String;)Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getTargetDescription__Ljava_lang_String_2
  (JNIEnv *env, jobject obj, jstring targetID)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *tid = (char*) env->GetStringUTFChars (targetID, 0);

	const char *res = dvi->getTargetDescription (tid);
	
	env->ReleaseStringUTFChars (targetID, tid);

	if (res == NULL) return NULL;

	return env->NewStringUTF (res);
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getStudyDate
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getStudyDate
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getStudyDate();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getStudyTime
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getStudyTime
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getStudyTime();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getReferringPhysiciansName
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getReferringPhysiciansName
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getReferringPhysiciansName();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getAccessionNumber
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getAccessionNumber
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getAccessionNumber();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getNameOfPhysiciansReadingStudy
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getNameOfPhysiciansReadingStudy
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getNameOfPhysiciansReadingStudy();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getSeriesNumber
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getSeriesNumber
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getSeriesNumber();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getSeriesDate
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getSeriesDate
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getSeriesDate();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getSeriesTime
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getSeriesTime
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getSeriesTime();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getSeriesDescription
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getSeriesDescription
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getSeriesDescription();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getSeriesPerformingPhysiciansName
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getSeriesPerformingPhysiciansName
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getSeriesPerformingPhysiciansName();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getSeriesProtocolName
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getSeriesProtocolName
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getSeriesProtocolName();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getSeriesOperatorsName
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getSeriesOperatorsName
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getSeriesOperatorsName();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    saveDICOMImage
 * Signature: (Ljava/lang/String;[BJJD)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_saveDICOMImage__Ljava_lang_String_2_3BJJD
  (JNIEnv *env, jobject obj, jstring filename, jbyteArray pixelData, jlong width, 
   jlong height, jdouble aspectRatio)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *fname = (char*) env->GetStringUTFChars (filename, 0);
	
	const void *array;
	jboolean isCopy;
	array = (const void*) env->GetByteArrayElements (pixelData, &isCopy);

	E_Condition res = dvi->saveDICOMImage (fname, array, (long) width, (long) height, aspectRatio);
	
	env->ReleaseStringUTFChars (filename, fname);


#ifdef _WINDOWS
	env->ReleaseByteArrayElements (pixelData, (signed char*) array, JNI_ABORT);
#else
	env->ReleaseByteArrayElements (pixelData, (char*) array, JNI_ABORT);
#endif

	return (jint) res;
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    resetPresentationState
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_resetPresentationState
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	E_Condition res = dvi->resetPresentationState();
	
	return (jint) res; 
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getFilename
 * Signature: (Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;)Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getFilename
  (JNIEnv *env, jobject obj, jstring studyUID, jstring seriesUID, jstring instanceUID)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *stu = (char*) env->GetStringUTFChars (studyUID, 0);
	char *ser = (char*) env->GetStringUTFChars (seriesUID, 0);
	char *ins = (char*) env->GetStringUTFChars (instanceUID, 0);

	const char* res = dvi->getFilename (stu, ser, ins);

	env->ReleaseStringUTFChars (studyUID, stu);
	env->ReleaseStringUTFChars (seriesUID, ser);
	env->ReleaseStringUTFChars (instanceUID, ins);

	if (res == NULL) return NULL;

	return env->NewStringUTF (res);

}





/*
 * Class:     J2Ci_jDVInterface
 * Method:    getPatientName
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getPatientName
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getPatientName();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getPatientID
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getPatientID
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getPatientID();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getPatientBirthDate
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getPatientBirthDate
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getPatientBirthDate();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getPatientSex
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getPatientSex
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getPatientSex();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getPatientBirthTime
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getPatientBirthTime
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getPatientBirthTime();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getOtherPatientNames
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getOtherPatientNames
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getOtherPatientNames();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getOtherPatientID
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getOtherPatientID
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getOtherPatientID();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getEthnicGroup
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getEthnicGroup
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getEthnicGroup();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getImageNumber
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getImageNumber
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getImageNumber();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    sendStudy
 * Signature: (Ljava/lang/String;Ljava/lang/String;)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_sendStudy
  (JNIEnv *env, jobject obj, jstring targetID, jstring studyUID)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *stu = (char*) env->GetStringUTFChars (studyUID, 0);
	char *tid = (char*) env->GetStringUTFChars (targetID, 0);

	E_Condition res = dvi->sendStudy(tid, stu);
	
	env->ReleaseStringUTFChars (studyUID, stu);
	env->ReleaseStringUTFChars (targetID, tid);
	
	return (jint) res;
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    sendSeries
 * Signature: (Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_sendSeries
  (JNIEnv *env, jobject obj, jstring targetID, jstring studyUID, jstring seriesUID)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *tid = (char*) env->GetStringUTFChars (targetID, 0);
	char *stu = (char*) env->GetStringUTFChars (studyUID, 0);
	char *ser = (char*) env->GetStringUTFChars (seriesUID, 0);

	E_Condition res = dvi->sendSeries(tid, stu, ser);
	
	env->ReleaseStringUTFChars (targetID, tid);
	env->ReleaseStringUTFChars (studyUID, stu);
	env->ReleaseStringUTFChars (seriesUID, ser);
	
	return (jint) res;
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getTargetHostname
 * Signature: (Ljava/lang/String;)Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getTargetHostname
  (JNIEnv *env, jobject obj, jstring targetID)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *tid = (char*) env->GetStringUTFChars (targetID, 0);

	const char* res = dvi->getTargetHostname(tid);

	env->ReleaseStringUTFChars (targetID, tid);

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getTargetPort
 * Signature: (Ljava/lang/String;)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_getTargetPort
  (JNIEnv *env, jobject obj, jstring targetID)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *tid = (char*) env->GetStringUTFChars (targetID, 0);

	int res = dvi->getTargetPort(tid);
	
	env->ReleaseStringUTFChars (targetID, tid);
	
	return (jint) res;
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getTargetAETitle
 * Signature: (Ljava/lang/String;)Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getTargetAETitle
  (JNIEnv *env, jobject obj, jstring targetID)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *tid = (char*) env->GetStringUTFChars (targetID, 0);

	const char* res = dvi->getTargetAETitle (tid);

	env->ReleaseStringUTFChars (targetID, tid);

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getTargetMaxPDU
 * Signature: (Ljava/lang/String;)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_getTargetMaxPDU
  (JNIEnv *env, jobject obj, jstring targetID)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *tid = (char*) env->GetStringUTFChars (targetID, 0);

	int res = dvi->getTargetMaxPDU (tid);
	
	env->ReleaseStringUTFChars (targetID, tid);
	
	return (jint) res;
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getTargetImplicitOnly
 * Signature: (Ljava/lang/String;)Z
 */
JNIEXPORT jboolean JNICALL Java_J2Ci_jDVInterface_getTargetImplicitOnly
  (JNIEnv *env, jobject obj, jstring targetID)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *tid = (char*) env->GetStringUTFChars (targetID, 0);

	OFBool res = dvi->getTargetImplicitOnly (tid);

	env->ReleaseStringUTFChars (targetID, tid);

	if (res == OFTrue) return JNI_TRUE;
	else return JNI_FALSE;
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getTargetDisableNewVRs
 * Signature: (Ljava/lang/String;)Z
 */
JNIEXPORT jboolean JNICALL Java_J2Ci_jDVInterface_getTargetDisableNewVRs
  (JNIEnv *env, jobject obj, jstring targetID)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *tid = (char*) env->GetStringUTFChars (targetID, 0);

	OFBool res = dvi->getTargetDisableNewVRs(tid);

	env->ReleaseStringUTFChars (targetID, tid);
	
	if (res == OFTrue) return JNI_TRUE;
	else return JNI_FALSE;
}





/*
 * Class:     J2Ci_jDVInterface
 * Method:    getDatabaseFolder
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getDatabaseFolder
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getDatabaseFolder();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getSenderName
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getSenderName
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getSenderName();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getReceiverName
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getReceiverName
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getReceiverName();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}


// -------------------------------------------------




/*
 * Class:     J2Ci_jDVInterface
 * Method:    startReceiver
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_startReceiver
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	E_Condition res = dvi->startReceiver();
	
	return (jint) res; 
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    terminateReceiver
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_terminateReceiver
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	E_Condition res = dvi->terminateReceiver();
	
	return (jint) res; 
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    newInstancesReceived
 * Signature: ()Z
 */
JNIEXPORT jboolean JNICALL Java_J2Ci_jDVInterface_newInstancesReceived
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	OFBool res = dvi->newInstancesReceived();

	if (res == OFTrue) return JNI_TRUE;
	else return JNI_FALSE;
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getNetworkAETitle
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getNetworkAETitle
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getNetworkAETitle();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getNetworkImplicitVROnly
 * Signature: ()Z
 */
JNIEXPORT jboolean JNICALL Java_J2Ci_jDVInterface_getNetworkImplicitVROnly
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	OFBool res = dvi->getNetworkImplicitVROnly();
	
	if (res == OFTrue) return JNI_TRUE;
	else return JNI_FALSE;
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getNetworkDisableNewVRs
 * Signature: ()Z
 */
JNIEXPORT jboolean JNICALL Java_J2Ci_jDVInterface_getNetworkDisableNewVRs
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	OFBool res = dvi->getNetworkDisableNewVRs();
	
	if (res == OFTrue) return JNI_TRUE;
	else return JNI_FALSE;
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getNetworkBitPreserving
 * Signature: ()Z
 */
JNIEXPORT jboolean JNICALL Java_J2Ci_jDVInterface_getNetworkBitPreserving
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	OFBool res = dvi->getNetworkBitPreserving();
	
	if (res == OFTrue) return JNI_TRUE;
	else return JNI_FALSE;
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getNetworkPort
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_getNetworkPort
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	unsigned short res = dvi->getNetworkPort();
	
	return (jint) res; 
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getNetworkMaxPDU
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_getNetworkMaxPDU
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	unsigned long res = dvi->getNetworkMaxPDU();
	
	return (jint) res; 
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getGUIConfigEntry
 * Signature: (Ljava/lang/String;)Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getGUIConfigEntry
  (JNIEnv *env, jobject obj, jstring key)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *ckey = (char*) env->GetStringUTFChars (key, 0);

	const char* res = dvi->getGUIConfigEntry(ckey);

	env->ReleaseStringUTFChars (key, ckey);

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getGUIConfigEntryBool
 * Signature: (Ljava/lang/String;Z)Z
 */
JNIEXPORT jboolean JNICALL Java_J2Ci_jDVInterface_getGUIConfigEntryBool
  (JNIEnv *env, jobject obj, jstring key, jboolean dfl)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *ckey = (char*) env->GetStringUTFChars (key, 0);
	OFBool cdfl = dfl == JNI_TRUE ? OFTrue : OFFalse;

	OFBool res = dvi->getGUIConfigEntryBool(ckey, cdfl);

	env->ReleaseStringUTFChars (key, ckey);
	
	if (res == OFTrue) return JNI_TRUE;
	else return JNI_FALSE;
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getMonitorCharacteristicsFile
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getMonitorCharacteristicsFile
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getMonitorCharacteristicsFile();

	if (res == NULL) return NULL;
	
	return env->NewStringUTF (res);
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    saveCurrentImage
 * Signature: (Ljava/lang/String;Z)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_saveCurrentImage  
  (JNIEnv *env, jobject obj, jstring filename, jboolean explicitVR)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *fn = (char*) env->GetStringUTFChars (filename, 0);
	OFBool expVR = explicitVR == JNI_TRUE ? OFTrue : OFFalse;
	
	E_Condition res = dvi->saveCurrentImage(fn, expVR);
	
	env->ReleaseStringUTFChars (filename, fn);

	return (jint) res; 
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    saveDICOMImage
 * Signature: (Ljava/lang/String;[BJJDZLjava/lang/String;)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_saveDICOMImage__Ljava_lang_String_2_3BJJDZLjava_lang_String_2
  (JNIEnv *env, jobject obj, jstring filename, jbyteArray pixelData, jlong width, jlong height, 
   jdouble aspectRatio, jboolean explicitVR, jstring instanceUID)
{	
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	char *fname = (char*) env->GetStringUTFChars (filename, 0);
	char *iUID = (char*) env->GetStringUTFChars (instanceUID, 0);
	
	OFBool expVR = explicitVR == JNI_TRUE ? OFTrue : OFFalse;
	
	const void *array;
	jboolean isCopy;
	array = (const void*) env->GetByteArrayElements (pixelData, &isCopy);

	E_Condition res = dvi->saveDICOMImage (fname, array, (long) width, (long) height, aspectRatio, expVR, iUID);
	
	env->ReleaseStringUTFChars (filename, fname);
	env->ReleaseStringUTFChars (instanceUID, iUID);

#ifdef _WINDOWS
	env->ReleaseByteArrayElements (pixelData, (signed char*) array, JNI_ABORT);
#else
	env->ReleaseByteArrayElements (pixelData, (char*) array, JNI_ABORT);
#endif

	return (jint) res;
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    disablePState
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_disablePState
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	E_Condition res = dvi->disablePState();
	
	return (jint) res;
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    enablePState
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_enablePState
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	E_Condition res = dvi->enablePState();
	
	return (jint) res;
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getNumberOfPStates
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_getNumberOfPStates
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	int res = dvi->getNumberOfPStates();
	
	return (jint) res;
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    selectPState
 * Signature: (IZ)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_selectPState
  (JNIEnv *env, jobject obj, jint idx, jboolean changeStatus)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	E_Condition res = dvi->selectPState(idx, changeStatus == JNI_TRUE ? OFTrue : OFFalse);
	
	return (jint) res;	
}

 


/*
 * Class:     J2Ci_jDVInterface
 * Method:    getPStateDescription
 * Signature: (I)Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getPStateDescription
  (JNIEnv *env, jobject obj, jint idx)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getPStateDescription(idx);

	if (res == NULL) return NULL;

	return env->NewStringUTF (res);
}


/*
 * Class:     J2Ci_jDVInterface
 * Method:    isBartenTransformPossible
 * Signature: ()Z
 */
JNIEXPORT jboolean JNICALL Java_J2Ci_jDVInterface_isBartenTransformPossible
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);
	
	OFBool res = dvi->isBartenTransformPossible ();

	if (res == OFTrue) return JNI_TRUE;
	else return JNI_FALSE;
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    setAmbientLightValue
 * Signature: (D)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_setAmbientLightValue
  (JNIEnv *env, jobject obj, jdouble alv)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	E_Condition res = dvi->setAmbientLightValue(alv);
	
	return (jint) res;
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getAmbientLightValue
 * Signature: (LJ2Ci/jDoubleByRef;)I
 */
JNIEXPORT jint JNICALL Java_J2Ci_jDVInterface_getAmbientLightValue
  (JNIEnv *env, jobject obj, jobject alv)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	double _alv = 0.0;

	E_Condition res = dvi->getAmbientLightValue(_alv);

	if (res != EC_Normal) return (jint) res;

	jclass DoubleByRefcls = env->GetObjectClass (alv);
		
	jfieldID value = env->GetFieldID (DoubleByRefcls, "value", "D");
		
	env->SetDoubleField (alv, value, _alv);
		
	return (jint) EC_Normal;
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getPresentationDescription
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getPresentationDescription
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getPresentationDescription();

	if (res == NULL) return NULL;

	return env->NewStringUTF (res);
}




/*
 * Class:     J2Ci_jDVInterface
 * Method:    getPStateLabel
 * Signature: (I)Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getPStateLabel
  (JNIEnv *env, jobject obj, jint idx)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getPStateLabel(idx);

	if (res == NULL) return NULL;

	return env->NewStringUTF (res);
}



/*
 * Class:     J2Ci_jDVInterface
 * Method:    getPresentationLabel
 * Signature: ()Ljava/lang/String;
 */
JNIEXPORT jstring JNICALL Java_J2Ci_jDVInterface_getPresentationLabel
  (JNIEnv *env, jobject obj)
{
	DVInterface *dvi = getAddressOfDVInterface (env, obj);

	const char* res = dvi->getPresentationLabel();

	if (res == NULL) return NULL;

	return env->NewStringUTF (res);
}



/*
 *  CVS Log
 *  $Log: DVInterface.cpp,v $
 *  Revision 1.2  1999/05/14 10:02:31  Schroeter
 *  Log-Tags for CVS corrected
 *
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/

