/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *
 *  Author :      $Author: Kleber $
 *  Last update : $Date: 1999/07/05 08:42:54 $
 *  Revision :    $Revision: 1.2 $
 *  State:        $State: Exp $
*/


import java.io.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

// Import all packages of the project:
import J2Ci.*;
import StuMan.*;
import Main.MainContext;
import Viewer.Main.*;
import Viewer.Presentation.*;
import jToolkit.Gui.*;
import jToolkit.io.*;
import Aboutbox.*;

/**
 * This is the main class. This class initializes the study
 * browser, the viewer and the about box.
 * 
 * @author Andreas Schroeter
 * @author Klaus Kleber
 * @since 30.03.
 */

public class DICOMscope extends Frame
{

    /**
     * This member stores the original output stream before it is redirected to a null-stream
     * 
     * @since 30.03
     */
    private PrintStream oldOut = null;

    /**
     * Main Method. Initializes this class.
     * 
     * @param args Command arguments
     * @since 30.03
     */
    
    static public void main (String[] args)
    {
        System.out.println ("starting DICOMscope");
        System.out.println ("please wait...");
        System.out.flush(); // force output right now!
        
        MainContext mc = MainContext.instance(); // create context
        
        DICOMscope sup = new DICOMscope();
        sup.setVisible(true);
    }

    /**
     * The interface to the Dicom Toolkit
     * 
     * @since 30.03
     */
    
    
    jDVInterface dvi = null;

    /**
     * the status bar reference
     * 
     * @since 30.03
     */
    Statusline sl;

	/**
	 * Constructor. Sets up the main tab panel and the contents 
	 * of this panel.
	 * 
	 * @since 30.03
	 */

    

	public DICOMscope()
	{
		// This code is automatically generated by Visual Cafe when you add
		// components to the visual environment. It instantiates and initializes
		// the components. To modify the code, only use code syntax that matches
		// what Visual Cafe can generate, or Visual Cafe may be unable to back
		// parse your Java file into its visual environment.
		
		dvi = new jDVInterface ("DICOMscope.cfg"); // change with configfile
		
		
		MainContext mc = MainContext.instance(); // create context
		
		mc.highQualitySystem = dvi.getGUIConfigEntryBool("HIGHENDSYSTEM", false);
		mc.usedRGB = dvi.getGUIConfigEntryBool("USERGB", false);
		
		if (mc.highQualitySystem) System.out.println ("High Quality System");
		else System.out.println ("Low Cost System");
		
		//{{INIT_CONTROLS
		setLayout(new BorderLayout (5, 5));
		setSize(800,600);
		
		setVisible(false);
		setTitle("DICOMscope v1.01");
				
		setBackground (Color.lightGray);		
		//}}

		//{{INIT_MENUS
		//}}

		//{{REGISTER_LISTENERS
		SymWindow aSymWindow = new SymWindow();
		this.addWindowListener(aSymWindow);
		addComponentListener(new CmpAdapter());
		//}}
		
		addNotify (); // create peer
		setVisible(true);
		
		tabpane = new TabPanel();			
		add("North", new Label());
		sl = new Statusline ();
        sl.setText("loading");        
		add ("South", sl);
		addNotify();		
		
		repaint();
		
		int fs = mc.bigBrowserFontSize;
		
		if (mc.highQualitySystem) jFontTools.setFontSize(tabpane, fs);
		if (mc.highQualitySystem) jFontTools.setFontSize(sl, fs);
		
		ViewInterface viewInterface = new ViewInterface(new PresentationStateGraphicsHandler(dvi), this, sl);
		
		tabpane.add ("StudyMan", new StudyMan (dvi, this, viewInterface, sl));
		tabpane.add ("Viewer", viewInterface.getViewPanel());
		tabpane.add ("About", new AboutBox (mc.highQualitySystem));
		
		add ("Center", tabpane);
		
		dvi.startReceiver (); // Gegenstck in Supp33_WindowClosing()
		
		sl.setText ("ready.");
		
		disableConsoleOutput();		
	}


    /**
     * Shows or hides the component depending on the boolean flag b.
     * 
     * @param b if true, show the component
     * @since 30.03
     * @see java.awt.Component#isVisible
     */
    public void setVisible(boolean b)
	{
		if(b)
		{
			setLocation(50, 50);
		}
		super.setVisible(b);
	}

	/**
	 * Sends a notify-message to the peer of this frame
	 * 
	 * @since 30.03
	 */

	
	public void addNotify()
	{
	    // Record the size of the window prior to calling parents addNotify.
	    Dimension d = getSize();
	    
		super.addNotify();

		if (fComponentsAdjusted)
			return;

		// Adjust components according to the insets
		Insets insets = getInsets();
		setSize(insets.left + insets.right + d.width, insets.top + insets.bottom + d.height);
		Component components[] = getComponents();
		for (int i = 0; i < components.length; i++)
		{
			Point p = components[i].getLocation();
			p.translate(insets.left, insets.top);
			components[i].setLocation(p);
		}
		fComponentsAdjusted = true;
	}

    // Used for addNotify check.
	boolean fComponentsAdjusted = false;

	//{{DECLARE_CONTROLS

	/**
	 * Tab panel reference
	 * 
	 * @since 30.03
	 */
	TabPanel tabpane;
	//}}

	//{{DECLARE_MENUS
	//}}
    

	class SymWindow extends java.awt.event.WindowAdapter
	{
		public void windowClosing(java.awt.event.WindowEvent event)
		{
			Object object = event.getSource();
			if (object == DICOMscope.this)
				DICOMscope_WindowClosing(event);
		}
	}

	/**
	 * Closes the application and terminates the network receiver.
	 * 
	 * @param event The calling event. ignored.
	 * @since 30.03
	 */
	
	public void DICOMscope_WindowClosing(java.awt.event.WindowEvent event)
	{
	    enableConsoleOutput();
	    System.out.println ("closing...");
	    dvi.terminateReceiver();	   
	    System.out.println (".");
		setVisible(false);		 // hide the Frame
		System.exit (0);
	}
	
	class CmpAdapter extends ComponentAdapter 
	{
        public void componentResized(ComponentEvent evt) 
        {            
            MainContext mc = MainContext.instance(); // create context
		    
            Dimension d = getSize();
                        
            if (mc.highQualitySystem) // doppelte Gre als Minimum
            {
                if (d.width < 2*900) d.width = 2*900;
                if (d.height < 2*900) d.height = 2*900;
            }
            else
            {
                if (d.width < 720) d.width = 720;
                if (d.height < 650) d.height = 650;
            }
            
            setSize (d);
        }
    }

	/**
	 * Toggles the tab panel to the viewer.
	 * 
	 * @since 30.03
	 */
	
	
	public void switchToViewer ()
	{
	    tabpane.show("Viewer");
	}

	/**
	 * Disables console output via the out-Stream.
	 * 
	 * @since 30.03
	 */
	
	public void disableConsoleOutput ()
	{
        oldOut = System.out;	    
	    System.setOut(new NullPrintStream());
	}

	/**
	 * Enables the out-Stream for console output
	 * 
	 * @since 30.03
	 */
	
	public void enableConsoleOutput ()
	{
	    if (oldOut != null) System.setOut(oldOut);
	    oldOut = null;
	}
	
	
}


/*
 *  CVS Log
 *  $Log: DICOMscope.java,v $
 *  Revision 1.2  1999/07/05 08:42:54  Kleber
 *  Change version name from 1.0 to 1.01
 *
 *  Revision 1.1.1.1  1999/05/14 09:33:07  Schroeter
 *  initial commit of release 1.0
 *
*/