/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/06/25 09:59:00 $
 *  Revision :    $Revision: 1.5 $
 *  State:        $State: Exp $
*/

package J2Ci;

import java.awt.Point;

/** 
 * A <em>jDVPresentationState</em> is the Java-sided class for the C++-Class
 * DVPresentationState. The Constructor is disabled !. 
 *
 * @author 	Andreas Schrter
*/
public class jDVPresentationState
{
    /**
     * Constructor is disabled !!!
    */
    protected jDVPresentationState()
    {
        // emtpy 
    }
    
    /**
     * Constructor for attaching an existing C++-Object. FOR INTERNAL USE ONLY!
     * @param attachAdr Address of C++-Object
    */    
    public jDVPresentationState (long attachAdr)
    {
        cppClassAddress = attachAdr;
    }
    
    // -------------------------------- Methods for C++-Class Binding
    
    /**
     * Address of C++-Object for access in the DLL. Never change manually!!
    */
    private long cppClassAddress = (long) 0; // never change!
    
    
    // ----------------------------------- Methods of Class jDVPresentationState
    
   

    /** 
     * Returns a label for the presentation state.
     * If no label is available, null is returned.
     * @return a pointer to a string or null.
    */
    public native String getPresentationLabel ();
    
    
    /** 
     * Sets the presentation state label.
     * The passed string must be a valid DICOM Code String
     * (i.e. max 16 characters, only uppercase and numbers).
     * @param label the new presentation state label
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int setPresentationLabel (String newLabel);
    
    
    /** 
     * Returns a description for the presentation state.
     * If no description is available, NULL is returned.
     * @return a pointer to a string or NULL.
    */
    public native String getPresentationDescription ();
    
    
    /** 
     * Sets the presentation state description.
     * The passed string must be a valid DICOM Long String
     * (i.e. max 64 characters, no backslash or control chars).
     * @param descr the new presentation state description
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int setPresentationDescription (String descr);
    
    
    /** 
     * Returns the creator's name for the presentation state.
     * If no name is available, NULL is returned.
     * @return a pointer to a string or NULL.
    */
    public native String getPresentationCreatorsName ();


    /** 
     * Sets the presentation state creator's name.
     * The passed string must be a valid DICOM Person Name String
     * (see NEMA PS3.5:1998).
     * @param name the new creator's name
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int setPresentationCreatorsName (String newName);
   

    /** 
     * Gets the current rotation status of the presentation state.
     * @return the current rotation status (from jDVPSRotationType).
    */
    public native int getRotation ();
    
    
    /** 
     * Sets rotation status of the presentation state.
     * @param rotation the rotation to be set (from jDVPSRotationType).
     * @return EC_Normal if successful, an error code otherwise (from jE_Condition).
    */
    public native int setRotation (int rotation);   
    
    
    /** 
     * Gets the current horizontal flip status of the presentation state.
     * @return true if flip is on, false if flip is off.
    */
    public native boolean getFlip ();
    
    
    /** 
     * Sets horizontal flip status of the presentation state.
     * @param isFlipped the flip status, true for on, false for off.
     * @return EC_Normal if successful, an error code otherwise (from jE_Condition).
    */
    public native int setFlip (boolean isFlipped);   
 
    
    /** 
     * Resets the object to initial state.
     * After this call, the object is in the same state as after
     * creation with the default constructor.
    */
    public native void clear();
 
        
    /** 
     * Apply presentation state to attached image and return image bitmap.
     * This method sets all parameter required to correctly render the pixel data
     * in the image attached to the presentation state and then creates the
     * required pixel data which contains all grayscale transformations but none
     * of the none-grayscale transformations of the presentation state "burned in"
     * into the pixel data. The pixel data returned is already corrected by a
     * Barten transform for the current display device and can be mapped directly
     * to digital driving levels of the graphics board. The pointer to the pixel
     * data remains valid until the next call to this function, or until the
     * image is detached or the presentation state is deleted.
     * @param pixel this object contains a reference to the pixeldata and the height
     *        and width of the image. This object must be created before passed as param.
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int getPixelData (jDVPrStateParam_GetPixelData pixel);
    
    
    /** 
     * Adds a reference to an image to this presentation state.
     * This method checks if the given SOP class and Study UID match
     * for this presentation state and returns an error code otherwise.
     * @param studyUID the Study Instance UID of the image reference to be added.
     * @param seriesUID the Series Instance UID of the image reference to be added.
     * @param sopclassUID the SOP class UID of the image reference to be added.
     * @param instanceUID the SOP instance UID of the image reference to be added.
     * @param frames a list of frame numbers in DICOM IS format
     *   (integer numbers separated by '\' characters). Default: frame numbers absent.
     *   The frame numbers are required if the referenced image is a multiframe image.
     * @return EC_Normal if successful, an error code otherwise (from jE_Condition).
    */
    public native int addImageReference (String studyUID, String seriesUID, 
                      String sopClassUID, String instanceUID, String frames);
                      
                      
    /** 
     * adds a reference to the currently attached image to this
     * presentation state. This method checks if the given image
     * is not yet referenced and if its Study UID and SOP class
     * match for this presentation state and returns an error code otherwise.
     * @return EC_Normal if successful, an error code otherwise (from jE_Condition).
    */
    public native int addImageReferenceAttached ();
    
    
    /** 
     * Removes a reference to an image from this presentation state.
     * @param studyUID the Study Instance UID of the image reference to be removed.
     * @param seriesUID the Series Instance UID of the image reference to be removed.
     * @param instanceUID the SOP instance UID of the image reference to be removed.
     * @return EC_Normal if successful, an error code otherwise (from jE_Condition).
    */
    public native int removeImageReference (String studyUID, String seriesUID, String instanceUID);
                      
                      
    /** 
     * Removes a reference to the currently attached image from this presentation state.
     * @return EC_Normal if successful, an error code otherwise (from jE_Condition).
    */
    public native int removeImageReferenceAttached ();
    
    
    /**
     * Gets the current Presentation LUT type.
     * @return the current presentation LUT type (from jDVPSPresentationLUTType).
    */
    public native int getPresentationLUT ();
    
    
    /**
     * Checks if a real Presentation LUT (not shape)
     * is available in the presentation state.
     * @return OFTrue if the presentation state contains
     *   a presentation LUT, no matter if it is activated or not.
     *   Returns OFFalse otherwise.
    */
    public native boolean havePresentationLookupTable ();
    
    
    /**
     * Returns the X component of the displayed area
     * top left hand corner.
     * @return TLHC X component.
    */
    public native int getDisplayedAreaTLHC_x ();
    
    
    /**
     * Returns the Y component of the displayed area
     * top left hand corner.
     * @return TLHC Y component.
    */
    public native int getDisplayedAreaTLHC_y ();
    
    
    /**
     * Returns the X component of the displayed area
     * bottom right hand corner.
     * @return BRHC X component.
    */
    public native int getDisplayedAreaBRHC_x ();
    
    
    /**
     * Returns the Y component of the displayed area
     * bottom right hand corner.
     * @return BRHC Y component.
    */
    public native int getDisplayedAreaBRHC_y ();
    
    
    /**
     * Sets the displayed area top left hand corner.
     * @param x TLHC X component
     * @param y TLHC Y component
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int setDisplayedAreaTLHC (int x, int y);


    /**
     * Sets the displayed area bottom right hand corner.
     * @param x BRHC X component
     * @param y BRHC Y component
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int setDisplayedAreaBRHC (int x, int y);

 
    /**
     * Gets rectangular shutter left vertical edge.
     * May only be called if a rectangular shutter is active.
     * @return the rect shutter LV edge.    
    */
    public native int getRectShutterLV ();

    
    /**
     * Gets rectangular shutter right vertical edge.
     * May only be called if a rectangular shutter is active.
     * @return the rect shutter RV edge.
    */
    public native int getRectShutterRV ();
    
    
    /**
     * Gets rectangular shutter upper horitontal edge.
     * May only be called if a rectangular shutter is active.
     * @return the rect shutter UH edge.
    */
    public native int getRectShutterUH ();
    
    
    /**
     * Gets rectangular shutter lower horiztonal edge.
     * May only be called if a rectangular shutter is active.
     * @return the rect shutter LH edge.
    */
    public native int getRectShutterLH ();
    
    
    /**
     * Sets and activates rectangular display shutter.
     * If a bitmap shutter is exists, it is deactivated if this
     * method returns successfully. If no shutter display value exists,
     * a default of 0 (black) is set.
     * @param lv the left vertical edge
     * @param rv the right vertical edge
     * @param uh the upper horizontal edge
     * @param lh the lower horizontal edge
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int setRectShutter (int lv, int rv, int uh, int lh);
    
    
    /**
     * Checks if a display shutter of given type is active.
     * @param type the shutter type (from jDVPSShutterType)
     * @return true if this type of shutter is currently active.
    */
    public native boolean haveShutter (int type);
    
    
    /**
     * Sets the current Presentation LUT type.
     * DVPSP_table can only be used if the presentation state
     * contains a lookup table, i.e. if havePresentationLookupTable() returns OFTrue.
     * @param newType the new presentation LUT type (from jDVPSPresentationLUTType).
     * @return EC_Normal if successful, an error code otherwise (from jE_Condition).
    */
    public native int setCurrentPresentationLUT (int type);
    
    
    /** 
     * Gets a description of the current presentation LUT.
     * For well-known presentation LUT shapes, a standard text
     * is returned. For presentation LUTs, the LUT explanation
     * is returned if it exists and a standard text otherwise.
     * This method never returns (null).
     * @return A string describing the current presentation LUT.
    */
    public native String getCurrentPresentationLUTExplanation();


    /** 
     * Returns the LUT explanation of the presentation LUT
     * if it exists and is non-empty. 
     * Otherwise returns (null).
     * @return A string with the explanation.
    */
    public native String getPresentationLUTExplanation();
 
 
    /** 
     * Gets circular shutter center x component.
     * May only be called if a circular shutter is active.
     * @return the circ shutter center x component
    */
    public native int getCenterOfCircularShutter_x();


    /** 
     * Gets circular shutter center y component.
     * May only be called if a circular shutter is active.
     * @return the circ shutter center y component
    */
    public native int getCenterOfCircularShutter_y();


    /** 
     * Gets circular shutter radius.
     * May only be called if a circular shutter is active.
     * Note: In DICOM, a circular shutter must be rendered
     * with consideration of the image pixel aspect ratio.
     * The radius returned by this method is the number
     * of pixels describing a horizontal line from the
     * center of the circle to its border. See sample figures
     * in NEMA PS3.3:1998.
     * @return the circ shutter radius
    */
    public native int getRadiusOfCircularShutter();


    /** 
     * Sets and activates circular display shutter.
     * If a bitmap shutter is exists, it is deactivated if this
     * method returns successfully. If no shutter display value exists,
     * a default of 0 (black) is set.
     * @param centerX the X component of the shutter center
     * @param centerY the Y component of the shutter center
     * @param radius the (horizontal) radius of the shutter
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int setCircularShutter(int centerX, int centerY, int radius);

   
    /** 
     * Gets polygonal shutter number of points.
     * May only be called if a polygonal shutter is active.
     * @return the number of points describing the poly shutter
    */
    public native int getNumberOfPolyShutterVertices();


    /** 
     * Sets polygonal display shutter origin.
     * This method creates a
     * polygonal shutter consisting only of a single point.
     * The polygonal display shutter is deactivated after this method.
     * @param x the x component of the shutter origin
     * @param y the x component of the shutter origin
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int setPolyShutterOrigin(int x, int y);


    /** 
     * Sets polygonal display shutter point.
     * This method adds a point to the polygonal display shutter,
     * which must already have at least an origin.
     * If the point set with this method is identical to the
     * origin of the shutter, the shutter is activated and
     * a possible bitmap shutter is deactivated. If no shutter display value exists,
     * a default of 0 (black) is set.
     * @param x the x component of the shutter origin
     * @param y the x component of the shutter origin
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int addPolyShutterVertex(int x, int y);
 
    
    /** 
     * Get polygonal shutter point.
     * May only be called if a polygonal shutter is active.
     * Shutter points are relative to the origin 1\1 which is
     * the left upper edge of the image. Param xy must be an existing object before passing
     * it to this method!
     * @param idx the index of the shutter point, must be < getNumberOfPolyShutterVertices()
     * @param xy returns the x and y component of the point. xy must be created before passing to this method!
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int getPolyShutterVertex(int idx, Point xy);


    /** 
     * Gets the shutter presentation value. If no shutter display
     * value exists, a default of 0 (black) is set.
     * @return the shutter presentation value as 16bit unsigned P-value
    */
    public native int getShutterPresentationValue();


    /**
     * Sets the shutter presentation value to the given P-value.
     * @param pvalue the shutter presentation value.
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int setShutterPresentationValue(int pvalue);


    /** 
     * Sorts the graphic layers according to
     * the graphic layer order. Layers with lower order have lower
     * indices after sorting which means that the layers can be
     * drawn to the screen in ascending index order.
     * Calling this routine may result in a re-numbering
     * of the graphic layer orders in a way that does not affect
     * their sequence.
    */
    public native void sortGraphicLayers();


    /** 
     * Returns the number of graphic layers.
     * @return number of graphic layers
    */
    public native int getNumberOfGraphicLayers();


    /** 
     * Gets the unique name of the graphic
     * layer with the given index. If no layer for the given
     * index exists, NULL is returned.
     * @param idx index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @return name of the graphic layer
    */
    public native String getGraphicLayerName(int idx);

    
    /** 
     * Gets the index of the graphic
     * layer with the given unique name. If no matching layer
     * is found, (-1) is returned.
     * @param name name of the graphic layer
     * @return index of the graphic layer
    */
    public native int getGraphicLayerIndex(String name);


    /** 
     * Gets a description string for the graphic
     * layer with the given index. If no layer for the given
     * index exists, or if the description is empty, NULL is returned.
     * @param idx index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @return description of the graphic layer
    */
    public native String getGraphicLayerDescription(int idx);


    /** 
     * Checks whether a recommended display value
     * for the given graphic layer exists.
     * @param idx index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @return true if a recommended display value exists
    */
    public native boolean haveGraphicLayerRecommendedDisplayValue(int idx);


    /** 
     * Checks whether a recommended display value
     * for the given graphic layer exists and is monochrome.
     * @param idx index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @return true if a recommended display value exists and is monochrome
    */
    public native boolean isGrayGraphicLayerRecommendedDisplayValue(int idx);
   
   
    /** 
     * Gets the recommended display value for the
     * given graphic layer (monochrome). If the recommended display value is a color,
     * it is implicitly converted to grayscale. Param gray must be created before
     * passing to this method!
     * @param idx index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @param gray the recommended display value as an unsigned 16-bit P-value
     *   is returned in this parameter. gray must be created before passing to this
     *   method!
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int getGraphicLayerRecommendedDisplayValueGray(int idx, jIntByRef gray);
   
   
    /** 
     * Gets the recommended display value for the
     * given graphic layer (color). If the recommended display value is monochrome,
     * identical R, G and B components are passed back. The objects 
     * r, g, b must be created before passing to this method!
     * @param idx index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @param r returns the R component of the recommended display value as unsigned 16-bit P-value. 
     *        Must be created before passing to this method!
     * @param g returns the G component of the recommended display value as unsigned 16-bit P-value
     *        Must be created before passing to this method!
     * @param b returns the B component of the recommended display value as unsigned 16-bit P-value
     *        Must be created before passing to this method!
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int getGraphicLayerRecommendedDisplayValueRGB(int idx, jIntByRef r, jIntByRef g, jIntByRef b);


    /** 
     * Sets the recommended display value for the
     * given graphic layer.
     * @param idx index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @param gray the recommended display value as an unsigned 16-bit P-value
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int setGraphicLayerRecommendedDisplayValueGray(int idx, int gray);


    /** 
     * Sets the recommended display value for the
     * given graphic layer.
     * @param idx index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @param r the R component of the recommended display value as unsigned 16-bit P-value
     * @param g the G component of the recommended display value as unsigned 16-bit P-value
     * @param b the B component of the recommended display value as unsigned 16-bit P-value
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int setGraphicLayerRecommendedDisplayValueRGB(int idx, int r, int g, int b);


    /** 
     * Assigns a new unique name to the given graphic layer.
     * The new name must be unique, otherwise an error code is returned.
     * Upon success, all references (for graphic annotations, curves and overlays) to the given
     * graphic layer are also renamed so that the presentation state remains
     * consistent.
     * @param idx index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @param name the new name of the graphic layer. Must be a valid DICOM Code String.
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int setGraphicLayerName(int idx, String name);
    

    /** 
     * Sets a new description to the given graphic layer.
     * @param idx index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @param descr description of the graphic layer. Must be a valid DICOM Long String.
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int setGraphicLayerDescription(int idx, String descr);


    /** 
     * Makes a graphic layer the highest layer for display.
     * This method assigns a graphic layer order higher than all
     * existing graphic layer orders to the given graphic layer,
     * sorts and renumbers the list of graphic layers. Upon success,  
     * the given graphic layer is guaranteed to have the new index
     * (getNumberOfGraphicLayers()-1).
     * @param idx index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int toFrontGraphicLayer(int idx);

   
    /** 
     * Makes a graphic layer the lowest layer for display.
     * This method assigns a graphic layer order lower than all
     * existing graphic layer orders to the given graphic layer,
     * sorts and renumbers the list of graphic layers. Upon success,
     * the given graphic layer is guaranteed to have the new index 0.
     * @param idx index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int toBackGraphicLayer(int idx);

    
    /** 
     * Creates a new graphic layer with the given
     * name and optional description.
     * The new name must be unique, otherwise an error code is returned.
     * The toFrontGraphicLayer() method is implicitly called for the new layer.
     * @param gLayer the name of the graphic layer. Must be a valid DICOM Code String.
     * @param gLayerDescription the optional description of the graphic layer.
     *    Must be a valid DICOM Long String.
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int addGraphicLayer(String gLayer, String gLayerDescription);


    /** 
     * Removes and deletes a graphic layer. All text, graphic, curve
     * and overlay objects on this graphic layer are also deleted or deactivated, respectively.
     * @param idx index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int removeGraphicLayer(int idx);

    
    /** 
     * Deactivates display shutter of given type.
     * After a call to this method haveShutter(type) will return OFFalse.
     * @param type the shutter type (from jDVPSShutterType).
    */
    public native void removeShutter(int type);


    /** 
     * Returns the number of text objects for the given
     * graphic layer.
     * @param idx index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @return number of text objects
    */
    public native int getNumberOfTextObjects(int layer);
    

    /** 
     * Gets the text object with the given index
     * on the given layer. If the text object or the graphic layer does
     * not exist, NULL is returned.
     * @param layer index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @param idx index of the text object, must be < getNumberOfTextObjects(layer)
     * @return the text object.
    */
    public jDVPSTextObject getTextObject(int layer, int idx)
    {
        long addr = getTextObjectN(layer, idx);
        if (addr == 0) return null;
        return new jDVPSTextObject (addr);
    }
   
    private native long getTextObjectN(int layer, int idx);


    /** 
     * Creates a new text object on the given layer.
     * returns a pointer to the new text object. If the graphic layer
     * does not exist or if the creation of the text object fails, NULL is returned.
     * @param layer index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @return a pointer to the new text object
    */
    public jDVPSTextObject addTextObject(int layer)    
    {
        long addr = addTextObjectN(layer);
        if (addr == 0) return null;
        return new jDVPSTextObject (addr);
    }
   
    private native long addTextObjectN (int layer);
    

    /** 
     * Deletes the text object with the given index
     * on the given layer.
     * @param layer index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @param idx index of the text object, must be < getNumberOfTextObjects(layer)
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int removeTextObject(int layer, int idx);


    /** 
     * Moves the text object with the given index on the given
     * layer to a different layer.
     * @param old_layer index of the graphic layer on which the text object is,
     *   must be < getNumberOfGraphicLayers()
     * @param idx index of the text object, must be < getNumberOfTextObjects(layer)
     * @param new_layer index of the graphic layer to which the text object is moved,
     *   must be < getNumberOfGraphicLayers()
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int moveTextObject(int old_layer, int idx, int new_layer);


    /** 
     * Returns the number of graphic objects for the given
     * graphic layer.
     * @param idx index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @return number of graphic objects
    */
    public native int getNumberOfGraphicObjects(int layer);


    /** 
     * Gets the graphic object with the given index.
     * on the given layer. If the graphic object or the graphic layer does
     * not exist, NULL is returned.
     * @param layer index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @param idx index of the graphic object, must be < getNumberOfGraphicObjects(layer)
     * @return the graphic object.
    */
    public jDVPSGraphicObject getGraphicObject(int layer, int idx)
    {
        long addr = getGraphicObjectN(layer, idx);
        if (addr == 0) return null;
        return new jDVPSGraphicObject (addr);
    }
    
    private native long getGraphicObjectN(int layer, int idx);


    /** 
     * Creates a new graphic object on the given layer.
     * Returns a pointer to the new graphic object. If the graphic layer
     * does not exist or if the creation of the graphic object fails, NULL is returned.
     * @param layer index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @return a pointer to the new graphic object
    */
    public jDVPSGraphicObject addGraphicObject(int layer)
    {
        long addr = addGraphicObjectN(layer);
        if (addr == 0) return null;
        return new jDVPSGraphicObject (addr);
    }
    
    private native long addGraphicObjectN(int layer);


    /** 
     * Deletes the graphic object with the given index
     * on the given layer.
     * @param layer index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @param idx index of the graphic object, must be < getNumberOfGraphicObjects(layer)
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int removeGraphicObject(int layer, int idx);


    /** 
     * Moves the graphic object with the given index on the given
     * layer to a different layer.
     * @param old_layer index of the graphic layer on which the graphic object is,
     *   must be < getNumberOfGraphicLayers()
     * @param idx index of the graphic object, must be < getNumberOfGraphicObjects(layer)
     * @param new_layer index of the graphic layer to which the graphic object is moved,
     *   must be < getNumberOfGraphicLayers()
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int moveGraphicObject(int old_layer, int idx, int new_layer);


    /**
     * Detaches and frees the image attached to the presentation state.
    */
    public native void detachImage();


    /** 
     * Sets the specific character set for this presentation state.
     * @param charset the new character set for this text object (from jDVPScharacterSet).
     * @return EC_Normal if successful, an error code otherwise (from jE_Condition).
    */
    public native int setCharset(int charset);


    /** 
     * Gets the specific character set for this presentation state.
     * @return character set identifier (from jDVPScharacterSet).
    */
    public native int getCharset();


    /** 
     * Gets the specific character set string for this presentation state.
     * @return character set if present, NULL otherwise
    */
    public native String getCharsetString();


    /** 
     * Returns the number of curve activations for the given
     * graphic layer.
     * @param idx index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @return number of curves
    */
    public native int getNumberOfCurves(int layer);

 
    /** 
     * Gets the curve with the given index
     * on the given layer. If the curve or the graphic layer does
     * not exist, NULL is returned.
     * @param layer index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @param idx index of the curve, must be < getNumberOfCurves(layer)
     * @return a pointer to the curve
    */
    public jDVPSCurve getCurve(int layer, int idx)
    {
        long addr = getCurveN(layer, idx);
        if (addr == 0) return null;
        return new jDVPSCurve (addr);
    }   
    
    private native long getCurveN (int layer, int idx);


    /** 
     * Returns the number of curves in the attached image
     * that could be activated in the presentation state.
     * @return number of available curves
    */
    public native int getNumberOfCurvesInImage();


    /** 
     * Gets the curve with the given index
     * from the attached image. If the curve does
     * not exist, NULL is returned.
     * @param idx index of the curve, must be < getNumberOfCurvesInImage()
     * @return the curve
    */
    public jDVPSCurve getCurveInImage(int idx)
    {
        long addr = getCurveInImageN(idx);
        if (addr == 0) return null;
        return new jDVPSCurve (addr);
    }   
    
    private native long getCurveInImageN (int idx);


    /** 
     * Activates curve in presentation state.
     * This method adds an activation for the given curve from the
     * attached image to the given graphic layer in the presentation state.
     * @param layer index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @param curveidxinimage index of the curve in the attached image,
     *   must be < getNumberOfCurvesInImage()
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int addCurve(int layer, int curveidxinimage);

 
    /** 
     * Deletes the curve activation with the given index
     * on the given layer.
     * @param layer index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @param idx index of the curve activation, must be < getNumberOfCurves(layer)
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int removeCurve(int layer, int idx);

 
    /** 
     * Moves the curve activation with the given index on the given
     * layer to a different layer.
     * @param old_layer index of the graphic layer on which the curve is,
     *   must be < getNumberOfGraphicLayers()
     * @param idx index of the curve activation, must be < getNumberOfCurves(layer)
     * @param new_layer index of the graphic layer to which the curve is moved,
     *   must be < getNumberOfGraphicLayers()
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int moveCurve(int old_layer, int idx, int new_layer);



	
	
	
	/** 
	 * Check if a VOI window is currently active.
     * @return true if a VOI window is active
    */
    public native boolean haveActiveVOIWindow();


    /** 
     * Check if a VOI LUT is currently active.
     * @return OFTrue if a VOI LUT is active
    */
    public native boolean haveActiveVOILUT();


    /** 
     * Returns a description string for a currently active VOI transform.
     * If no description is available, NULL is returned.
     * @return a pointer to a string or NULL.
    */
    public native String getCurrentVOIDescription();


    /** 
     * Gets the width of the current VOI window.
     * May only be called if haveActiveVOIWindow() is OFTrue.
     * @param w the window width is returned in this parameter
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */  
    public native int getCurrentWindowWidth(jDoubleByRef w);
  
  
    /** 
     * Get the center of the current VOI window.
     * May only be called if haveActiveVOIWindow() is OFTrue.
     * @param c the window center is returned in this parameter
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */  
    public native int getCurrentWindowCenter(jDoubleByRef c);
  
  
    /** 
     * Gets the number of VOI LUTs available in the attached image.
     * @return number of VOI LUTs.
    */
    public native int getNumberOfVOILUTsInImage();
  
    /** 
     * Gets the number of VOI Windows available in the attached image.
     * @return number of VOI Windows.
    */
    public native int getNumberOfVOIWindowsInImage();
  
 
    /** 
     * Returns a description string for the given VOI LUT in the attached
     * image.
     * If no description for the given index is available, NULL is returned.
     * @param idx index, must be < getNumberOfVOILUTsInImage()
     * @return a pointer to a string or NULL.
    */
    public native String getDescriptionOfVOILUTsInImage(int idx);
    

    /** 
     * Returns a description string for the given VOI Window
     * in the attached image.
     * If no description for the given index is available, NULL is returned.
     * @param idx index, must be < getNumberOfVOIWindowsInImage()
     * @return a pointer to a string or NULL.
    */
    public native String getDescriptionOfVOIWindowsInImage(int idx);
    
   
    /** 
     * Activates one of the VOI LUTs from the attached image.
     * @param idx index of the VOI transform, must be < getNumberOfVOILUTsInImage().
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int setVOILUTFromImage(int idx);


    /** 
     * Activates one of the VOI Windows from the attached image.
     * @param idx index of the VOI transform, must be < getNumberOfVOIWindowsInImage().
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int setVOIWindowFromImage(int idx);
    
 
    /** 
     * Sets a user defined VOI window center and width.
     * @param wCenter the window center
     * @param wWidth  the window width
     * @param description an optional description. Default: absent.
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int setVOIWindow(double wCenter, double wWidth, String description);

   
    /** 
     * Deactivates the current VOI transformation.
     * After a call to this method, no VOI transform is active.
    */
    public native void deactivateVOI();


    /** 
     * Gets the number of overlays that are currently activated
     * on the given graphic layer.
     * @param layer index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @return number of active overlays
    */   
    public native int getNumberOfActiveOverlays(int layer);


    /** 
     * Gets the repeating group number of the given activated overlay.
     * @param layer index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @param idx index of the overlay, must be < getNumberOfActiveOverlays().
     * @return repeating group number if found, 0 otherwise.
    */
    public native int getActiveOverlayGroup(int layer, int idx);

  
    /** 
     * Gets the overlay label of the given activated overlay.
     * @param layer index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @param idx index of the overlay, must be < getNumberOfActiveOverlays().
     * @return label string if it exists, NULL otherwise.
    */
    public native String getActiveOverlayLabel(int layer, int idx);


    /** 
     * Gets the overlay description of the given activated overlay.
     * @param layer index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @param idx index of the overlay, must be < getNumberOfActiveOverlays().
     * @return description string if it exists, NULL otherwise.
    */
    public native String getActiveOverlayDescription(int layer, int idx);

  
    /** 
     * Checks whether the given activated overlay is a ROI
     * (region of interest) overlay.
     * @param layer index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @param idx index of the overlay, must be < getNumberOfActiveOverlays().
     * @return true if overlay exists and is ROI, false otherwise.
    */
    public native boolean activeOverlayIsROI(int layer, int idx);

    
    /** 
     * Gets one overlay bitmap.
     * This method may only be called if has beed called before
     * for the current presentation state settings.
     * The parameter is an object from class jDVPrStateParam_GetOverlayData.
     * It must be created and set with the IN-params before passing to this
     * method! OUT-params will be set by this method.
     * @param od.layer index of the graphic layer on which this overlay is
     *   activated, must be < getNumberOfGraphicLayers().
     * @param od.idx index of the overlay activation on the given layer,
     *   must be < getNumberOfActiveOverlays(layer).
     * @param od.overlayData upon success a pointer to the overlay plane is passed back
     *   in this parameter. The overlay plane is organized as one byte per pixel.
     *   The byte values are already transformed from pvalues to DDLs.
     * @param od.width upon success the width of the overlay bitmap in pixels is returned in this parameter.
     * @param od.height upon success the height of the overlay bitmap in pixels is returned in this parameter.
     * @param od.left upon success the horizontal position of the overlay relative to the image 
     *  is returned. 0 means that the overlay is left aligned with the image. 
     *  Since the overlay is cropped at the borders of the image, values < 0 are impossible.
     * @param od.top upon success the vertical position of the overlay relative to the image 
     *  is returned.
     * @param od.isROI returns OFTrue if the overlay is ROI, OFFalse if the overlay is Graphic.
     * @param od.frame frame number of the image. Since overlays can differ for different image frames,
     *  the image frame also selects the overlays. Default: first frame.
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int getOverlayData(jDVPrStateParam_GetOverlayData od);
    
    
    /** 
     * Gets the number of overlays which are embedded in the
     *  image currently attached to the presentation state. Overlays in the image are counted only
     *  if they are not shadowed by overlays that are embedded in the presentation state
     *  and use the same repeating group number.
     *  @return number of overlays in attached image
    */
    public native int getNumberOfOverlaysInImage();
  
  
    /** 
     * Gets the repeating group number of the given overlay in the attached image.
     * @param idx index of the overlay, must be < getNumberOfOverlaysInImage().
     * @return repeating group number if found, 0 otherwise.
    */
    public native int getOverlayInImageGroup(int idx);
  
 
    /** 
     * Gets the overlay label of the given overlay in the attached image.
     * @param idx index of the overlay, must be < getNumberOfOverlaysInImage().
     * @return label string if it exists, NULL otherwise.
    */
    public native String getOverlayInImageLabel(int idx);
    

    /** 
     * Gets the overlay description of the given overlay in the attached image.
     * @param idx index of the overlay, must be < getNumberOfOverlaysInImage().
     * @return description string if it exists, NULL otherwise.
    */
    public native String getOverlayInImageDescription(int idx);


    /** 
     * Gets the index of the activation layer on which the given
     * overlay from the attached image is activated.
     * @param idx index of the overlay, must be < getNumberOfOverlaysInImage().
     * @return layer index (which is < getNumberOfGraphicLayers()) if overlay exists
     *    and is activated, (-1) otherwise.
    */
    public native int getOverlayInImageActivationLayer(int idx);
  
  
    /** 
     * Checks whether the given overlay in the attached image is a ROI
     * (region of interest) overlay.
     * @param idx index of the overlay, must be < getNumberOfOverlaysInImage().
     * @return true if overlay exists and is ROI, false otherwise.
    */
    public native boolean overlayInImageIsROI(int idx);

  
    /** 
     * Gets the number of overlays which are embedded in the
     * presentation state. 
     * @return number of overlays in presentation state
    */
    public native int getNumberOfOverlaysInPresentationState();
    
    
    /** 
     * Gets the repeating group number of the given overlay in the presentation state.
     * @param idx index of the overlay, must be < getNumberOfOverlaysInPresentationState().
     * @return repeating group number if found, 0 otherwise.
     */
    public native int getOverlayInPresentationStateGroup(int idx);


    /** 
     * Gets the overlay label of the given overlay in the presentation state.
     * @param idx index of the overlay, must be < getNumberOfOverlaysInPresentationState().
     * @return label string if it exists, NULL otherwise.
    */
    public native String getOverlayInPresentationStateLabel(int idx);


    /**    
     * Gets the overlay description of the given overlay in the presentation state.
     * @param idx index of the overlay, must be < getNumberOfOverlaysInPresentationState().
     * @return description string if it exists, NULL otherwise.
    */
    public native String getOverlayInPresentationStateDescription(int idx);
    
    
    /** 
     * Gets the index of the activation layer on which the given
     * overlay from the presentation state is activated. If an overlay is used
     * as a bitmap shutter, it is reported as being not activated by this method.
     * @param idx index of the overlay, must be < getNumberOfOverlaysInPresentationState().
     * @return layer index (which is < getNumberOfGraphicLayers()) if overlay exists
     *    and is activated, DVPS_IDX_NONE otherwise.
    */
    public native int getOverlayInPresentationStateActivationLayer(int idx); 
    
  
    /** 
     * Checks if the given overlay in the presentation state
     * is currently activated as a bitmap shutter.
     * @param idx index of the overlay, must be < getNumberOfOverlaysInPresentationState().
     * @return true if overlay exists and is activated as bitmap shutter, false otherwise.
    */
    public native boolean overlayIsBitmapShutter(int idx);
    
  
    /** 
     * Checks whether the given overlay in the presentation state is a ROI
     * (region of interest) overlay.
     * @param idx index of the overlay, must be < getNumberOfOverlaysInPresentationState().
     * @return true if overlay exists and is ROI, false otherwise.
    */
    public native boolean overlayInPresentationStateIsROI(int idx);
    
  
    /** 
     * Removes an overlay from the presentation state.
     * If the overlay is activated, the activation is also removed.
     * Since overlays in the presentation state can shadow overlays in the attached image,
     * execution of this method may change the number of overlays reported in the attached image.
     * @param idx index of the overlay, must be < getNumberOfOverlaysInPresentationState().
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int removeOverlayFromPresentationState(int idx);
    

    /** 
     * Changes the repeating group used for an overlay in the presentation state.
     * Since overlays in the presentation state can shadow overlays in the attached image,
     * execution of this method may change the number of overlays reported in the attached image.
     * @param idx index of the overlay, must be < getNumberOfOverlaysInPresentationState().
     * @param newGroup new repeating group number 0x6000-0x601F (even). If this optional parameter is omitted,
     *   the method attemps to automatically determine a new group number so that no overlay in the
     *   attached image is shadowed any more. If this is impossible, the method fails and leaves
     *   the overlay repeating group unchanged.
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int changeOverlayGroupInPresentationState(int idx, int newGroup);
  

    /** 
     * Checks if an overlay from the presentation state is suitable
     * for use as a bitmap shutter. An overlay is suitable if it is a graphic overlay
     * with the same size as the attached image and with the origin 1\1.
     * This method does not check wether the overlay is already activated as overlay
     * or bitmap shutter.
     * @param idx index of the overlay, must be < getNumberOfOverlaysInPresentationState().
     * @return true if overlay can be used as display shutter.
    */
    public native boolean overlayIsSuitableAsBitmapShutter(int idx); 
  
  
    /**
     * Activates the given overlay from the attached image
     * on the given graphic layer.
     * If the overlay is already activated (i.e.
     * getOverlayInImageActivationLayer(idx) != DVPS_IDX_NONE) this method fails.
     * @param layer index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @param idx index of the overlay, must be < getNumberOfOverlaysInImage().
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int activateOverlayInImage(int layer, int idx);


    /** 
     * Activates the given overlay from the presentation state
     * on the given graphic layer.
     * If the overlay is already activated or used as a bitmap overlay (i.e.
     * getOverlayInPresentationStateActivationLayer(idx) != DVPS_IDX_NONE or
     * overlayIsBitmapShutter(idx) == OFTrue) this method fails.
     * @param layer index of the graphic layer, must be < getNumberOfGraphicLayers()
     * @param idx index of the overlay, must be < getNumberOfOverlaysInPresentationState().
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int activateOverlayInPresentationState(int layer, int idx);
  
  
    /** 
     * Activates an overlay as bitmap shutter.
     * The overlay must not be activated on a graphic layer (i.e.
     * getOverlayInPresentationStateActivationLayer(idx) != DVPS_IDX_NONE, 
     * otherwise this method fails.
     * @param idx index of the overlay, must be < getNumberOfOverlaysInPresentationState().
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int activateOverlayAsBitmapShutter(int idx);


    /** 
     * Removes activation for an overlay which may be
     * embedded in the attached image or part of the presentation state.
     * @param layer index of the graphic layer on which this overlay is
     *   activated, must be < getNumberOfGraphicLayers().
     * @param idx index of the overlay activation on the given layer,
     *   must be < getNumberOfActiveOverlays(layer).
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */
    public native int deactivateOverlay(int layer, int idx);
  
  
    /** 
     * Moves the overlay activation with the given index on the given
     * layer to a different layer. 
     * @param old_layer index of the graphic layer on which the curve is, 
     *   must be < getNumberOfGraphicLayers()
     * @param idx index of the overlay activation, must be < getNumberOfActiveOverlays(layer)
     * @param new_layer index of the graphic layer to which the curve is moved, 
     *   must be < getNumberOfGraphicLayers()
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */   
    public native int moveOverlay(int old_layer, int idx, int new_layer);


    /** 
     * Gets the pixel aspect ratio of the attached image.
     * Pixel aspect ratio is defined here as the width of a pixel divided
     * by the height of a pixel (x/y).
     * This method may only be called when an image is attached to the
     * presentation state.
     * @param ratio upon success, the pixel aspect ratio is returned in this parameter.
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */   
    public native int getImageAspectRatio(jDoubleByRef ratio);
  
   
    /** 
     * Gets smallest and biggest possible pixel value in the attached image.
     * These values are defined as the smallest and biggest number that
     * could possibly be contained in the image after application of the Modality transform,
     * but before any VOI, Presentation or Barten transform.
     * This method may only be called when an image is attached to the
     * presentation state. 
     * @param minValue upon success, the smallest value is returned in this parameter.
     * @param maxValue upon success, the biggest value is returned in this parameter.
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */   
    public native int getImageMinMaxPixelRange(jDoubleByRef minValue, jDoubleByRef maxValue);


    /** 
     * Gets smallest and biggest occuring pixel value in the attached image.
     * These values are defined as the smallest and biggest number that
     * are actually contained in the image after application of the Modality transform,
     * but before any VOI, Presentation or Barten transform.
     * This method may only be called when an image is attached to the
     * presentation state. 
     * @param minValue upon success, the smallest value is returned in this parameter.
     * @param maxValue upon success, the biggest value is returned in this parameter.
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */   
    public native int getImageMinMaxPixelValue(jDoubleByRef minValue, jDoubleByRef maxValue);


    /** 
     * Gets the width of the attached image. 
     * The rotation status of the presentation state is not taken
     * into account, i.e. the width of an unrotated image is returned.
     * This method may only be called when an image is attached to the
     * presentation state. Param width must be created before passing to
     * this method.
     * @param width upon success, the image width (pixels) is returned in this parameter.
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */   
    public native int getImageWidth(jIntByRef width);


    /** 
     * Gets the height of the attached image. 
     * The rotation status of the presentation state is not taken
     * into account, i.e. the height of an unrotated image is returned.
     * This method may only be called when an image is attached to the
     * presentation state. Param height must be created before passing to
     * this method.
     * @param height upon success, the image height (pixels) is returned in this parameter.
     * @return EC_Normal upon success, an error code otherwise
    */   
    public native int getImageHeight(jIntByRef height);
    

    /** 
     * Gets the number of image references in all series managed by this list.
     * @return number of image references
    */
    public native int numberOfImageReferences();
    
  
    /** 
     * UNTESTED - Gets an image reference with the given index.
     * @param idx index, must be < numberOfImageReferences().
     * @param param.studyUID the Study Instance UID is returned in this string
     * @param param.seriesUID the Series Instance UID is returned in this string
     * @param param.sopclassUID the SOP Class UID is returned in this string
     * @param param.instanceUID the SOP Instance UID is returned in this string
     * @param param.frames the list of frames is returned in this string
     * @return EC_Normal if successful, an error code otherwise (from jE_Condition).
    */
    public native int getImageReference(int idx, jDVPrStateParam_GetImageReference param);
    
 
 
    /**
     * Checks whether Barten correction is switched on or off. Barten transform
     * will only be performed if switched on _and_ a valid monitor character 
     * description exists. Default is on.
     * @return true if Barten transform is on.
    */
    public native boolean getBartenTransform ();
    
    
    /**
     * Activates or deactivates Barten correction. Barten transform
     * will only be performed if switched on _and_ a valid monitor character 
     * description exists. Default is on.
     * @param flag true to switch on, false to switch off.
    */
    public native void setBartenTransform (boolean flag);
    
    
    /** 
     * Exchanges the layer order of the two graphic layers with   
     * the given indices. This method does not sort or renumber   
     * the graphic layers.   
     * @param idx1 index of the first graphic layer, must be < getNumberOfGraphicLayers()   
     * @param idx2 index of the second graphic layer, must be < getNumberOfGraphicLayers()   
     * @return EC_Normal upon success, an error code otherwise (from jE_Confition).   
    */  
    public native int exchangeGraphicLayers(int idx1, int idx2);
    
    
    /** 
     * Converts a 16-bit P-Value to an 8-bit DDL value for on-sceen display.    
     * If a display function is set and enabled (see setBartenTransform()),    
     *  the DDL is corrected for the nonlinearity of the display, otherwise    
     *  a simple linear mapping is performed.    
     *  @param pvalue P-Value 0..0xFFFF    
     *  @return display driving level (DDL), 0..0xFF    
    */   
    public native byte convertPValueToDDL (int pvalue);
     
     
    /**
     * Generates a new SOP Instance UID which is used when writing the
     * Presentation State to file.
     * @return new SOP Instance UID if successfully set
    */
    public native String createInstanceUID();
 
     
    /** 
     * Same as method above apart from the fact that the storage area is handled   
     * externally.   
     * @param pixelData pointer to storage area where the pixel data is copied to.   
     *   The storage area must be allocated and deleted from the calling method.   
     * @param size specifies size of the storage area in bytes.   
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).   
    */   
    public native int getPixelData(byte[] pixelData, long size);
       
        
    /** 
     * Inverts image by changing presentation state LUT or presentation state LUT 
     * shape. Pixel data has to be re-get after this transformation.   
     * @return EC_Normal upon success, an error code otherwise (from jE_Condition).
    */  
    public native int invertImage();
    
    
    /** 
     * Checks whether image is inverse (shape, plut or mono1).
     * @return OFTrue if image is inverse, OFFalse otherwise.
    */
    public native boolean isInverse();
    
     
    // -------------------------------------------------------------
    // -- Method for transformations of the image
    //
    // The following methods are not part of the relating c++-class DVPresentationState !!!
    //
    
    
    /**
     * Gets the pixel data and perfom zooming and scaling with all existing layers.
     * A part of the original data is chosen by point TLHC, a zoom factor and a scaling for
     * x and y. The output size is defined by the array size passed to this method.
     * @return true on success, false otherwise.
    */
    public native boolean getScreenData (jDVPrStateParam_GetScreenData info);
}

/*
 *  CVS Log
 *  $Log: jDVPresentationState.java,v $
 *  Revision 1.5  1999/06/25 09:59:00  Schroeter
 *  Bugs fixed to avoid GPF occuring while drawing the very first annots.
 *
 *  Revision 1.4  1999/06/25 09:49:15  Schroeter
 *  Bugs fixed to avoid GPF occuring while drawing the very first annots.
 *
 *  Revision 1.1.1.1  1999/05/14 09:33:09  Schroeter
 *  initial commit of release 1.0
 *
*/
