/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:10 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package Main;
import java.awt.image.*;
/**
 * This class creates ColorModels for this programm and makes them available.
 * 
 * @author Klaus Kleber
 * @since 30.04.99
 */
public class GrayColorIndex extends java.lang.Object
{

    /**
     * IndexColorModel for image data which contains 1 byte per pixel.
     * Every pixel will be interpreted as gray color.
     * 
     * @since 30.04.1999
     */
    private static  IndexColorModel grayColorModel;

    /**
     * Number of bits each pixel occupies
     * 
     * @since 30.04.1999
     */

    private static int bits;

    /**
     * Size of the color component array
     * 
     * @since 30.04.1999
     */
    private static int size ;

    /**
     * Array of red color components
     * 
     * @since 30.04.1999
     */
    private static byte[] r;

    /**
     * Array of green color components
     * 
     * @since 30.04.1999
     */
    private static byte[] g;

    /**
     * Array of green color components.
     * 
     * @since 30.04.1999
     */
    private static byte[] b;

    /**
     * Array of alpha color components.
     * 
     * @since 30.04.1999
     */
    private static byte[] a;;

    public static void  fillIndexColorModel()
    {
        bits = 8;
        size = 256;
        r = new byte[size];
        g = new byte[size];
        b = new byte[size];
        a = new byte[size];
        for (int i = 0; i < size; i++)
        {
            r[i] = (byte)i;
            g[i] = (byte)i;
            b[i]= (byte)i;
            a[i]= (byte)0xFF;
        }
        //Transparent Color
        grayColorModel = new IndexColorModel(bits, size, r, g, b);
            
        
    }

    /**
     * Returns the IndexColorModel for gray image data.
     * 
     * @return IndexColorModel for image data.
     * @since 30.04.1999
     */
    public static IndexColorModel getGrayColorModel()
    {
        return grayColorModel;
    }
    
    /**
     * Returns a IndexColorModel for overlay data.This ColorModel contains the same Colors as the grayColorModel. 
     * There are only one difference: One Color is transparent. This Color has an alpha-value of 0x00.
     * 
     * 
     * @return IndexColorModel for image data.
     * @since 30.04.1999
     */
    public static IndexColorModel getOverlayGrayColorModel(int transparentIndex)
    {
        for (int i = 0; i < size; i++)a[i]= (byte)0xFF;
        a[transparentIndex] = (byte)0x00;
        return new IndexColorModel(bits, size, r, g, b,a);
    }
    
}

/*
 *  CVS Log
 *  $Log: GrayColorIndex.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:10  Schroeter
 *  initial commit of release 1.0
 *
*/

