/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:10 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/


package Main;

import java.io.*;
import java.awt.*;
import java.awt.image.*;
import java.awt.geom.*;
import java.awt.font.*;
import java.awt.color.*;

/**
 * This class manages the context of DICOMscope. 
 * Some global variables of the programm are available by 
 * methods of this class.
 * It implements the singleton pattern.
 * 
 * @author Klaus Kleber
 * @author Andreas Schroeter
 * @since 30.04.1999
 */

public class MainContext extends java.lang.Object
{   
    //import static library
    static
    {
        System.loadLibrary ("jInterface");
    }

    /**
     * The only instance of this class.
     * 
     * @since 30.04.1999
     */
    private static MainContext theInstance = null;    
    
    
    /**
     * If true the DICOMscope will running in the testmodus. 
     * 
     * @since 30.04.1999
     */
    public boolean testInstallation = false;

    /**
     * Fontsize  for the widget on the slow quality monitor
     * 
     * @since 30.04.1999
     */
    public int fontSizeLowQuality = 12;

    
    /**
     * Fontsize of the PresentationStateTextObject for the low quality monitor.
     * 
     * @since 30.04.1999
     */
    public int fontSizeTextLowQuality = 16;
    
    /**
     * Fontsize for the widgets in the StudyMan class on the high quality monitor.
     * 
     * @since 30.04.1999
     */
    public int bigBrowserFontSize = 30;
    
    /**
     * Fontsize  for the widget on the high quality monitor
     * 
     * @since 30.04.1999
     */
    public int fontSizeHighQuality = 30;
    
     /**
     * Fontsize of the PresentationStateTextObject for the high quality monitor.
     * 
     * @since 30.04.1999
     */
    public int fontSizeTextHighQuality = 48;
    
    
     /**
     * True if the hight quality monitor with the dome board is used.
     * 
     * @since 30.04.1999
     */
    public boolean highQualitySystem = false;
    
     /**
     * Name of the font for the widget.
     * 
     * @since 30.04.1999
     */
    public String fontName = new String("SansSerif");
    
     /**
     * Name of the font for drawing PresentationStateTextObject.
     * 
     * @since 30.04.1999
     */
    public String fontNameText = new String("SansSerif");
    
     /**
     * Not used yet
     * 
     * @since 30.04.1999
     */
    public boolean usedRGB = false;
    
     /**
     * Contains a value for the size of windows in the low quality modus.
     * 
     * @since 30.04.1999
     */
    public int sizeFactorLow = 1;
    
    
     /**
     * Contains a value for the size of windows in the low quality modus.
     * 
     * @since 30.04.1999
     */
    public int sizeFactorHigh = 3;
    
    /**
    * Application Name
    * 
    * @since 30.04.1999
    */
    static public String appName = new String ("Supplement 33");
    
    /**
     * Application Version (high number). The complete version number is
     * <appVersionH>.<appVersionL>
    *
    * @since 30.04.1999
    */
    static public int appVersionH = 1;
    
    
    /**
     * Application Version (low number)
    *
    * @since 30.04.1999
    */
    static public int appVersionL = 0;
    
    
     
        
        
    
    /**
    * Contains the ColorModel for drawing the images. The ColorModel depends 
    * from the display system. If the display system the low quality system then 
    * a 8 bit IndexColorModel will used. If the display system is the high 
    * quality system 8 Bit ColorModel loaded from de GraphicsConfiguration will be 
    * used.
    *
    * @since 30.04.1999
    */
    ColorModel usedColorModel;
    
    //static Dimension screenSize;
    
    /**
    * Outputstream for log file
    *
    * @since 30.04.1999
    */
    
    static PrintStream out;
    
    /**
     * Return the only instance of a MainContext object. If there is no instance 
     * this methode create this instance.
     * <br> 
     * status: tested
     * 
     * @return The only intance of this class.
     * @since 30.04.1999
     */
    public static MainContext instance()
    {
        if (theInstance == null) theInstance = new MainContext();
        return theInstance;
    }

    /**
     * Constructor. This class implements the singleton pattern. 
     * This constructor should only called from the 
     * instance() methode of this class.
     * 
     * @since 30.04.1999
     * @see MainContext.instance()
     */
    
    private MainContext()
    {
        //Open  printstream
        if (testInstallation)
        {
            
            try
            {
                out = new PrintStream (new FileOutputStream("LogFile.log")); 
                out.println("Start");
            }
            catch(IOException e)
            {
                System.out.println(e);
            }
        }
        //Load deviceColorModell
        loadDeviceInformation();
    
    }
    
    
    /**
     * Prints the specified text in the log file.
     * 
     * @param output Text which should print.
     * @since 30.04.1999
     */
    public void printLogFile(String output)
    {
        if (testInstallation)
        {
            out.println(output);
        }
        
    }
    
    /**
    * Loads and constructs the color model from the  device.
    *
    * @since 30.04.1999
    */
    private void loadDeviceInformation()
    {
            
        //
        GraphicsEnvironment  gr;
        GraphicsDevice gd;
        ColorModel cm;
        GraphicsConfiguration gc;
        
        
        gr = GraphicsEnvironment.getLocalGraphicsEnvironment();
        gd = gr.getDefaultScreenDevice();
        gc = gd.getDefaultConfiguration();
        cm = gc.getColorModel();
        usedColorModel = cm;
       
        
        GrayColorIndex.fillIndexColorModel();
        
    }       
    
    
    /**
     * Returns a 8 Bit IndexColorModel
     * 
     * @param A 8 Bit IndexColorModel
     * @since 30.04.1999
     */
    public ColorModel getIndexColorModel()
    {
         return GrayColorIndex.getGrayColorModel();
    }
    
    
    /**
     * Returns the ColorModel used for displaying images. Depends
     * from the system.
     * 
     * @return The ColorModel used for displaying images.
     * @since 30.04.1999
     */
    public ColorModel getUsedColorModel()
    {
        if (highQualitySystem)return usedColorModel;
        else return GrayColorIndex.getGrayColorModel();
    }
    
    /**
     * Returns a value for the size of Windows. 
     * Depends from the system.
     * 
     * @return A value for the size of Windows.
     * @since 30.04.1999
     */
    public int getSizeFactor()
    {
        if (highQualitySystem)  return  sizeFactorHigh;
        else  return  sizeFactorLow;
    }
    
    /**
     * Returns the font for the widgets.
     * Depends from the system.
     * 
     * @return The font for the widgets.
     * @since 30.04.1999
     */
    public Font getUsedFont()
    {
        if (highQualitySystem)  return  new Font(fontName, 0,fontSizeHighQuality);
        else  return  new Font(fontName, 0,fontSizeLowQuality);
    }
    
    /**
     * Returns the font for displaying PresentationStateTextObjects.
     * Depends from the system.
     * 
     * @return The  font for displaying PresentationStateTextObjects.
     * @since 30.04.1999
     */
    public Font getFontTextAnnotations()
    {
        if (highQualitySystem)  return  new Font(fontNameText, 0,fontSizeTextHighQuality);
        else  return  new Font(fontName, 0,fontSizeTextLowQuality);
    }
    
    

}//FontRenderContext

/*
 *  CVS Log
 *  $Log: MainContext.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:10  Schroeter
 *  initial commit of release 1.0
 *
*/
