/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:10 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package StuMan;

/*
	A basic extension of the java.awt.Dialog class
 */

import java.awt.*;
import javax.swing.*;
import Main.MainContext;
import jToolkit.Gui.*;

/**
 * Asks the user for confirmation. Used before deleting elements 
 * 
 * @author Andreas Schroeter
 * @since 30.04.1999
*/
public class ConfirmationDlg extends Dialog
{
    public boolean okClicked = false;
        
	public ConfirmationDlg(Frame parent)
	{
		super(parent);

		// This code is automatically generated by Visual Cafe when you add
		// components to the visual environment. It instantiates and initializes
		// the components. To modify the code, only use code syntax that matches
		// what Visual Cafe can generate, or Visual Cafe may be unable to back
		// parse your Java file into its visual environment.
		//{{INIT_CONTROLS
		setLayout(new BorderLayout (5, 5));
		setSize(200,100);
		setVisible(false);
		setLocation (300, 200);
		//}}
		
		setModal (true);
		setTitle ("Delete elements");

		//{{REGISTER_LISTENERS
		SymWindow aSymWindow = new SymWindow();
		this.addWindowListener(aSymWindow);
		//}}
		
		
		add ("Center", text = new JLabel ("Are you sure?", SwingConstants.CENTER));
		
		JPanel p = new JPanel ();
		
		okBt.setText("OK");
		okBt.setBackground(java.awt.Color.lightGray);
		okBt.setBounds(24,264,108,24);		
		p.add(okBt);
		
		cancelBt.setText("Cancel");
		cancelBt.setBackground(java.awt.Color.lightGray);
		cancelBt.setBounds(24,264,108,24);		
		p.add(cancelBt);
		
		add ("South", p);
		
		SymAction lSymAction = new SymAction();
		okBt.addActionListener(lSymAction);
		cancelBt.addActionListener(lSymAction);
		
		MainContext mc = MainContext.instance();
		int fs = mc.bigBrowserFontSize;
				
		if (mc.highQualitySystem)
		{
		    setSize (600, 400);
		    jFontTools.setFontSize(text, fs);
		    jFontTools.setFontSize(okBt, fs);		    
		    jFontTools.setFontSize(cancelBt, fs);		    
		}
	}
	
	
	public void setLabelText (String newText)
	{
	    text.setText (newText);
	    
	    Dimension pSize = text.getPreferredSize();
	    setSize (pSize.width + 50, pSize.height + 100);
	}
	
	public void addNotify()
	{
  	    // Record the size of the window prior to calling parents addNotify.
	    Dimension d = getSize();

		super.addNotify();

		if (fComponentsAdjusted)
			return;

		// Adjust components according to the insets
		Insets insets = getInsets();
		setSize(insets.left + insets.right + d.width, insets.top + insets.bottom + d.height);
		Component components[] = getComponents();
		for (int i = 0; i < components.length; i++)
		{
			Point p = components[i].getLocation();
			p.translate(insets.left, insets.top);
			components[i].setLocation(p);
		}
		fComponentsAdjusted = true;
	}

    // Used for addNotify check.
	boolean fComponentsAdjusted = false;



    /**
     * Shows or hides the component depending on the boolean flag b.
     * @param b  if true, show the component; otherwise, hide the component.
     * @see java.awt.Component#isVisible
     */
    public void setVisible(boolean b)
	{
		if(b)
		{
			Rectangle bounds = getParent().getBounds();
			Rectangle abounds = getBounds();
	
			setLocation(bounds.x + (bounds.width - abounds.width)/ 2,
				 bounds.y + (bounds.height - abounds.height)/2);
		}
		super.setVisible(b);
	}

	//{{DECLARE_CONTROLS
	JButton okBt = new JButton ();
	JButton cancelBt = new JButton ();
	JLabel text;
	//}}

	class SymWindow extends java.awt.event.WindowAdapter
	{
		public void windowClosing(java.awt.event.WindowEvent event)
		{
			Object object = event.getSource();
			if (object == ConfirmationDlg.this)
				ConfirmationDlg_WindowClosing(event);
		}
	}
	
	void ConfirmationDlg_WindowClosing(java.awt.event.WindowEvent event)
	{
		setVisible(false);
	}
	
	class SymAction implements java.awt.event.ActionListener
	{
		public void actionPerformed(java.awt.event.ActionEvent event)
		{
			Object object = event.getSource();			
			if (object == okBt) OnOk ();
			if (object == cancelBt) ConfirmationDlg_WindowClosing (null);
			
		}
	}
	
	protected void OnOk()
	{
        okClicked = true;	    
	    ConfirmationDlg_WindowClosing (null);
	}
	
}
/*
 *  CVS Log
 *  $Log: ConfirmationDlg.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:10  Schroeter
 *  initial commit of release 1.0
 *
*/
