/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:10 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package StuMan;

/*
	A basic extension of the java.awt.Dialog class
 */

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import J2Ci.*;
import jToolkit.Gui.*;
import Main.MainContext;

/**
 * Opens a Send-To-Dialog for sending IODs, series and studies to another DICOM-application.
 * After choosing a target and clicking on OK the targetID is returned in selectedItem.
 * Element okClicked indicates whether the SendTo-Button is clicked or not.
 *
 * @author Andreas Schroeter
 * @since 30.04.1999
*/
public class SendToDlg extends Dialog
{
    JList list;
    
    /**
     * Indicated whether the SentTo button was clicked to close the dialog frame.
    */
    public boolean okClicked = false;
    
    /**
     * Contains a targetID after dialog closing (if OK-Button is clicked).
    */
    public String selectedItem = null;
    
    private jDVInterface dvi;
    Frame parent;
    boolean highQualityScreen = false;
    
	public SendToDlg(Frame parent, jDVInterface dvi)
	{
		super(parent);
		
		this.parent = parent;
		
		MainContext mc = MainContext.instance();
		highQualityScreen = mc.highQualitySystem;

		// This code is automatically generated by Visual Cafe when you add
		// components to the visual environment. It instantiates and initializes
		// the components. To modify the code, only use code syntax that matches
		// what Visual Cafe can generate, or Visual Cafe may be unable to back
		// parse your Java file into its visual environment.
		//{{INIT_CONTROLS
		setLayout(new BorderLayout (5, 5));
		
		if (highQualityScreen) setSize(500,400);
		else setSize(250,200);
		
		setVisible(false);
		setLocation (300, 200);
		//}}
        setModal (true);
		setTitle("Send IOD to...");

		//{{REGISTER_LISTENERS
		SymWindow aSymWindow = new SymWindow();
		this.addWindowListener(aSymWindow);
		//}}
		
		this.dvi = dvi;
		
		addNotify();

		DefaultListModel lm = new DefaultListModel(); 
		
		list = new JList (lm);
		add("Center", new JScrollPane(list));
		
		JPanel p = new JPanel ();		
				
		int fs = mc.bigBrowserFontSize;
		
		if (highQualityScreen)
		{
		    jFontTools.setFontSize(list, fs);
		    jFontTools.setFontSize(sendBt, fs);
		    jFontTools.setFontSize(infoBt, fs);
		    jFontTools.setFontSize(cancelBt, fs);
		}
			
		sendBt.setText("Send to");
		sendBt.setBackground(java.awt.Color.lightGray);
		sendBt.setBounds(24,264,108,24);		
		p.add(sendBt);
		
		infoBt.setText("Details...");
		infoBt.setBackground(java.awt.Color.lightGray);
		infoBt.setBounds(24,264,108,24);		
		p.add(infoBt);
		
		cancelBt.setText("Cancel");
		cancelBt.setBackground(java.awt.Color.lightGray);
		cancelBt.setBounds(24,264,108,24);		
		p.add(cancelBt);
		
		add ("South", p);
		
		LoadAll ();
		
		SymAction lSymAction = new SymAction();
		infoBt.addActionListener(lSymAction);
		sendBt.addActionListener(lSymAction);
		cancelBt.addActionListener(lSymAction);
	}
	
	public void addNotify()
	{
  	    // Record the size of the window prior to calling parents addNotify.
	    Dimension d = getSize();

		super.addNotify();

		if (fComponentsAdjusted)
			return;

		// Adjust components according to the insets
		Insets insets = getInsets();
		setSize(insets.left + insets.right + d.width, insets.top + insets.bottom + d.height);
		Component components[] = getComponents();
		for (int i = 0; i < components.length; i++)
		{
			Point p = components[i].getLocation();
			p.translate(insets.left, insets.top);
			components[i].setLocation(p);
		}
		fComponentsAdjusted = true;
	}

    // Used for addNotify check.
	boolean fComponentsAdjusted = false;

    /**
     * Shows or hides the component depending on the boolean flag b.
     * @param b  if true, show the component; otherwise, hide the component.
     * @see java.awt.Component#isVisible
     */
    public void setVisible(boolean b)
	{
		if(b)
		{
			Rectangle bounds = getParent().getBounds();
			Rectangle abounds = getBounds();
	
			setLocation(bounds.x + (bounds.width - abounds.width)/ 2,
				 bounds.y + (bounds.height - abounds.height)/2);
		}
		super.setVisible(b);
	}

	//{{DECLARE_CONTROLS
	JButton sendBt = new JButton ();
	JButton cancelBt = new JButton ();
	JButton infoBt = new JButton ();
	//}}

	class SymWindow extends java.awt.event.WindowAdapter
	{
		public void windowClosing(java.awt.event.WindowEvent event)
		{
			Object object = event.getSource();
			if (object == SendToDlg.this)
				SendToDlg_WindowClosing(event);
		}
	}
	
	void SendToDlg_WindowClosing(java.awt.event.WindowEvent event)
	{
		setVisible(false);
	}
	
	class SymAction implements java.awt.event.ActionListener
	{
		public void actionPerformed(java.awt.event.ActionEvent event)
		{
			Object object = event.getSource();
			if (object == infoBt) OnDetails ();
			if (object == sendBt) OnSend ();
			if (object == cancelBt) SendToDlg_WindowClosing (null);
			
		}
	}
	
	protected void LoadAll()
	{
	    DefaultListModel lm = (DefaultListModel) list.getModel();
	    
	    int nrOfTargets = dvi.getNumberOfTargets();
	    
	    for (int i = 0; i < nrOfTargets; i++)
	    {
	        String tid = dvi.getTargetID(i);
	        
	        lm.addElement (dvi.getTargetDescription(tid));
	    }
	}
	
	protected void OnSend()
	{
	    
	    DefaultListModel lm = (DefaultListModel) list.getModel();
	    
	    int si = list.getSelectedIndex();
	    if (si == -1) return;
	    
	    okClicked = true;	    
	    selectedItem = dvi.getTargetID(si);
	    
	    SendToDlg_WindowClosing (null);
	}
	
	public void OnDetails ()
	{	
	    int si = list.getSelectedIndex();
	    if (si == -1) return;	    
	    
	    JDialog detailDlg = new JDialog (parent, "Details", true);
	    
	    DefaultListModel lm = new DefaultListModel(); 
	    JList info = new JList(lm);
	    Font f = new Font("Courier", Font.PLAIN, 12);
	    info.setFont(f);
	    	    
	    detailDlg.getContentPane().setLayout (new BorderLayout (5, 5));
	    detailDlg.setLocation (200, 150);
	    
	    CommandJButton okBt = new CommandJButton (new DisposeCommand(detailDlg), 0);
	    okBt.setText("  Ok  ");
		okBt.setBackground(java.awt.Color.lightGray);		
		JPanel p = new JPanel ();
		p.add (okBt);
		
		MainContext mc = MainContext.instance();
		int fs = mc.bigBrowserFontSize;
		
		if (highQualityScreen)
		{
		    jFontTools.setFontSize(info, fs);
		    jFontTools.setFontSize(okBt, fs);		    
		}
        
        Font listfont = info.getFont();
		
		String tid = dvi.getTargetID(si);
		String desc, hostn, aet;
		lm.addElement((desc = " Description     : " + dvi.getTargetDescription(tid)));
		lm.addElement(" ID              : " + tid);
		lm.addElement((hostn = " Hostname        : " + dvi.getTargetHostname(tid)));
		lm.addElement(" Port            : " + dvi.getTargetPort(tid));
		lm.addElement((aet = " AETitle         : " + dvi.getTargetAETitle(tid)));
		lm.addElement(" Max. PDU        : " + dvi.getTargetMaxPDU(tid));
		lm.addElement(" Implicit Only   : " + (dvi.getTargetImplicitOnly(tid) ? "yes" : "no"));
		lm.addElement(" Disable new VRs : " + (dvi.getTargetDisableNewVRs(tid) ? "yes" : "no"));

		
		FontMetrics fm = getFontMetrics (listfont);
		int l = fm.stringWidth(desc);
		if (fm.stringWidth(hostn) > l) l = fm.stringWidth(hostn);
		if (fm.stringWidth(aet) > l) l = fm.stringWidth(aet);
		
		if (highQualityScreen) detailDlg.setSize(l+50, 500);
		else detailDlg.setSize(l+50, 250);

		detailDlg.getContentPane().add ("South", p);
		detailDlg.getContentPane().add ("Center", new JScrollPane(info));
	    
	    detailDlg.show();
	}
}
/*
 *  CVS Log
 *  $Log: SendToDlg.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:10  Schroeter
 *  initial commit of release 1.0
 *
*/
