/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:10 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package StuMan;


/**
 * This class represents a tree element with all possible contents.
 *
 * @author Andreas Schroeter
 * @since 30.04.1999
*/
public class TreeElement
{
    public String text;
    
    public int studyIdx = -1;
    public int seriesIdx = -1;
    public int instanceIdx = -1;
    public boolean isPresentationState = false;
    public boolean isNew = true;
    
    public static boolean showUID = false;
    public String UID;
    
    public static boolean showModality = false;
    public String Modality;
    
    public static boolean showDescription = false;
    public String Description;
    
    public static boolean showPatientInfo = false;
    public String PatientInfo;
    
    public static boolean showDateTime = false;
    public String DateTime;
    
    public static boolean showFilename = false;
    public String Filename;
    
    public static boolean showLabel = false;
    public String Label;
    
    public static boolean showNewWithIcon = false;
    
    public TreeElement (String t, int st, int se, int in)
    {
        text = t;
        studyIdx = st;
        seriesIdx = se;
        instanceIdx = in;
    }
    
    public TreeElement (String t, int st, int se)
    {
        this (t, st, se, -1);
    }
    
    public TreeElement (String t, int st)
    {
        this (t, st, -1);
    }
    
    public TreeElement (String t)
    {
        this (t, -1);
    }
    
    public TreeElement ()
    {
        this (null);
    } 
    
    public void setToPS ()
    {
        isPresentationState = true;
    }    
    
    public boolean isPS ()
    {
        return isPresentationState;
    }
    
    public void setToNew()
    {
        isNew = true;
    }
    
    public void setToOld ()
    {
        isNew = false;
    }
    
    public boolean isNew ()
    {
        return isNew;
    }    
    
        
    public String toString ()
    {
        String temp = new String (text + " ");
        
        if (Description == null) Description = new String ("");
        if (UID == null) UID = new String ("");
        if (Modality == null) Modality = new String ("");
        if (PatientInfo == null) PatientInfo = new String ("");
        if (DateTime == null) DateTime = new String ("");
        if (Filename == null) Filename = new String ("");
        if (Label == null) Label = new String ("");
        
        
        if (instanceIdx != -1) // Bild
        {            
            if (TreeElement.showLabel) temp = appendStr (temp, Label);
            if (TreeElement.showDescription) temp = appendStr (temp, Description);
            if (TreeElement.showUID) temp = appendStr (temp, UID);
            if (TreeElement.showFilename) temp = appendStr (temp, "[" + Filename + "]");
            
            if (!TreeElement.showLabel && !TreeElement.showDescription && !TreeElement.showUID && !showFilename) temp += " #" + studyIdx + "." + seriesIdx + "." + instanceIdx + "#";
        }
        else if (seriesIdx != -1) // Serie
        {
            if (TreeElement.showModality) temp = appendStr (temp, Modality);
            if (TreeElement.showDateTime) temp = appendStr (temp, DateTime);
            if (TreeElement.showDescription) temp = appendStr (temp, Description);
            if (TreeElement.showUID) temp = appendStr (temp, UID);
            
            if (!TreeElement.showDateTime && !TreeElement.showModality && !TreeElement.showDescription && !TreeElement.showUID) temp += " #" + studyIdx + "." + seriesIdx + "#";
        }
        else if (studyIdx != -1) // Studie
        {
            if (TreeElement.showPatientInfo) temp = appendStr (temp, PatientInfo);
            if (TreeElement.showDateTime) temp = appendStr (temp, DateTime);
            if (TreeElement.showDescription) temp = appendStr (temp, Description);
            if (TreeElement.showUID) temp = appendStr (temp, UID);
            
            if (!TreeElement.showDateTime && !TreeElement.showPatientInfo && !TreeElement.showDescription && !TreeElement.showUID) temp += " #" + studyIdx + "#";
        }       
        
        return temp;
    }	
    
    
    private String appendStr (String dest, String what)
    {     
        if (what == null) return dest;
        if (what.equals ("")) return dest;
        
        if (dest.charAt(dest.length()-1) == ' ') return dest + what;        
        else return dest + " * " + what;
    }
    
}

/*
 *  CVS Log
 *  $Log: TreeElement.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:10  Schroeter
 *  initial commit of release 1.0
 *
*/
