/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:10 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package Viewer.Controller;

import java.awt.event.*;
import java.awt.*;
import java.awt.geom.*;
import Viewer.GUI.*;
import Viewer.Presentation.*;
import Viewer.Main.*;
import Viewer.Paint.*;

/**
 * This class contains the Listeners for the class AnnotationPanel 
 * 
 * @author Klaus Kleber
 * @since 30.04.1999
 */
public class AnnotationPanelEventController implements java.awt.event.ActionListener,ItemListener
{

	
	/**
	 * Contains the current ScreenImageHandler
	 * 
	 * @since 30.04.1999
	 */
	private ScreenImageHandler screenImageHandler;

	
	/**
	 * Contains the AnnotationPanel which fires the Events.
	 * 
	 * @since 30.04.1999
	 */
    AnnotationPanel annotationPanel;
	
	
	
	/**
	 * Construct an EventImageCanvas.
	 * 
	 * @param annotationPanel Contains the AnnotationPanel wich fires the Events.
	 * @param screenImageHandler Contains the current ScreenImageHandler
	 * @since 30.04.1999
	 */
	public AnnotationPanelEventController(AnnotationPanel annotationPanel, ScreenImageHandler screenImageHandler)
	{
	   this.annotationPanel = annotationPanel;
	   this.screenImageHandler = screenImageHandler;
	}

	/**
	 * Handles the ItemEvents fired form the AnnotationPanel.
	 *
	 * @param e ItemEvents
	 * @since 30.04.1999
	 */
	
	public void itemStateChanged(ItemEvent e)
	{
	    
	    //Changing the current layer
	    if ( e.getSource() instanceof Choice)
	    {
	        Choice layerChoice = (Choice)e.getSource();
	        if (layerChoice.getItemCount() != 0)
	        {
	            screenImageHandler.presentationStateGraphicsHandler.setCurrentLayerIndex(layerChoice.getSelectedIndex()); 
                screenImageHandler.mainImageViewerPanel.funktionBasisTabPanel.layerPanel.deactiveAnnotationListisVisible = false;
	            
	            screenImageHandler.mainImageViewerPanel.setValue();
	        }
	    }
	    else
	    {
	        Checkbox checkbox = (Checkbox)e.getSource();
	        //set filled
	        if (checkbox.getName().equals("filled"))
	        {
	          
	            screenImageHandler.paintStructure.setFilled(checkbox.getState());
	        }
	        
	        //set image relative
	        if (checkbox.getName().equals("image"))
	        {
	            screenImageHandler.paintStructure.setDisplayRelative(!checkbox.getState());
	            
	        }
	        
	    }
	}

	/**
	 * Handles the ActionEvents fired from the AnnotationPanel.
	 *
	 * @param e ActionEvent
	 * @since 30.04.1999
	 */
	
	public void actionPerformed(ActionEvent e)
	{
         
         Button button = (Button)e.getSource();
         
         //If there is no layer you have to insert one layer before you can create a new Annotation
         if (screenImageHandler.presentationStateGraphicsHandler.listPresentationStateGraphicLayer.size()<= 0)
         {
            LayerDialog layerDialog = new LayerDialog(screenImageHandler.mainImageViewerPanel.parentFrame,"Insert new layer",true,screenImageHandler,false);
            layerDialog.setVisible(true);
            
         }
         
         
         if (screenImageHandler.presentationStateGraphicsHandler.listPresentationStateGraphicLayer.size()> 0)
         {
            PaintObject ann=null;
            
            //insert new line
            if (button.getName().equals("Line")) 
            {
   		        ann = new Line2DObject();
                ann.isDisplayRelative = !annotationPanel.image.getState();
   		        screenImageHandler.setNewPaintObjectAction(ann);
   		    }
            
            //Insert new polyline
            if (button.getName().equals("Polyline")) 
            {
   		        ann = new PolylineObject();
                ann.setFilled(annotationPanel.filled.getState());
                ann.isDisplayRelative = !annotationPanel.image.getState();
   		        screenImageHandler.setNewPaintObjectAction(ann);
   		    }
            
            //Insert new ellipse
            if (button.getName().equals("Ellipse")) 
            {
   		        ann = new Ellipse2DObject();
                ann.setFilled(annotationPanel.filled.getState());
                ann.isDisplayRelative = !annotationPanel.image.getState();
   		        screenImageHandler.setNewPaintObjectAction(ann);
                
            }
            
            //insert new circle
            if (button.getName().equals("Circle")) 
            {
   		        ann = new Circle2DObject();
                ann.setFilled(annotationPanel.filled.getState());
                ann.isDisplayRelative = !annotationPanel.image.getState();
   		        screenImageHandler.setNewPaintObjectAction(ann);
                
            }
            
            //edit PaintObject
            if (button.getName().equals("SetWork")) 
            {
               screenImageHandler.setEditAction();
            }
            
            //insert rectangle
            if (button.getName().equals("Rectangle")) 
            {
   		        ann = new Rectangle2DObject();
                ann.setFilled(annotationPanel.filled.getState());
                ann.isDisplayRelative = !annotationPanel.image.getState();
   		        screenImageHandler.setNewPaintObjectAction(ann);
   		    }
            
            //insert interpolated
            if (button.getName().equals("Interpolated")) 
            {
   		        ann = new InterpolatedObject();
                ann.isDisplayRelative = !annotationPanel.image.getState();
   		        screenImageHandler.setNewPaintObjectAction(ann);
   		    }
            
            //insert text
            if (button.getName().equals("Text")) 
            {
                TextDialog textDialog = new TextDialog(screenImageHandler.mainImageViewerPanel.parentFrame,"Insert new text",true,screenImageHandler);
                textDialog.setVisible(true);
   		    }
            
   		    
   		    button.setBackground(Color.gray);
   		    annotationPanel.setActiveButton(button);
   	    }
	}
    
}
/*
 *  CVS Log
 *  $Log: AnnotationPanelEventController.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:10  Schroeter
 *  initial commit of release 1.0
 *
*/

