/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:10 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/
package Viewer.Controller;

import java.awt.event.*;
import java.awt.*;
import java.awt.geom.*;

import Viewer.GUI.*;
import Viewer.Main.*;
import Viewer.Main.*;
import Viewer.Presentation.*;

/**
 * This class handles the MouseEvents for editing a PresentationStateLayerObject.
 * 
 * @author Klaus Kleber
 * @since 30.04.1999
 * @see GUI.ImageCanvas
 * @see ImageCanvasMouseEventListener
 */
public  class ImageCanvasEditListener extends ImageCanvasMouseEventListener
{
	
	
	
	/**
	 * Construct a ImageCanvasEditListener.
	 * 
	 * @param screenImageHandler Contains the current ScreenImageHandler.
	 * @since 30.04.1999
	 */
	public ImageCanvasEditListener(ScreenImageHandler screenImageHandler)
	{
	    super(screenImageHandler);
	   
	    
	    screenImageHandler.imageCanvas.setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
   }

	/**
	 * Handles the mouse pressed action. If one PresentationStateLayerObject 
	 * contains the pressed point, these object will be marked.
	 * 
	 * @param e MouseEvent.
	 * @since 30.04.1999
	 */
	public void mousePressed(MouseEvent e)
	{
	   screenImageHandler.setClick(new Point2D.Float((float)(e.getX()),(float)( e.getY())));
         //PopUpTrigger
         showPopup(e); 
    }

    
   /**
    * Shows the PopupMenu for editing a PresentationStateGraphicObject.
    * 
    * @param e MouseEvent.
    * @since 30.04.1999
    */
   void handlePopup(MouseEvent e)
   {
        PresentationStateLayerObject handleObject = screenImageHandler.presentationStateGraphicsHandler.getCurrentLayerObject();
        ImageCanvas imageCanvas = screenImageHandler.getImageCanvas();
        PopupMenu imageCanvasPopup = null;
        imageCanvas.removePopupMenu();
        if (handleObject!= null)
        {
            if (handleObject instanceof PresentationStateGraphicObject)imageCanvasPopup = new ImageCanvasPopupEdit( screenImageHandler,(PresentationStateGraphicObject)handleObject);
            if (handleObject instanceof PresentationStateTextObject)imageCanvasPopup =  new ImageCanvasPopupEditText( screenImageHandler,(PresentationStateTextObject)handleObject);
            imageCanvas.addPopupMenu(imageCanvasPopup);
            imageCanvasPopup.show(imageCanvas,e.getX(),e.getY());
        }
   }
}


/*
 *  CVS Log
 *  $Log: ImageCanvasEditListener.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:10  Schroeter
 *  initial commit of release 1.0
 *
*/
