/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:10 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package Viewer.Controller;

import java.awt.event.*;
import java.awt.*;
import java.awt.geom.*;
import Viewer.Main.*;

/**
 * This class ist the super class for all MouseEventListneres and MouseMotionListeners of
 * the ImageCanvas.
 * 
 * @author Klaus Kleber
 * @since 30.04.1999
 * @see ImageCanvas
 * @see ImageCanvasMoveListener
 * @see ImageCanvasMoveTextListener
 * @see ImageCanvasEditListener
 * @see ImageCanvasNewListner
 */
public  abstract class ImageCanvasMouseEventListener extends    java.awt.event.MouseAdapter 
                                  implements java.awt.event.MouseMotionListener
{
   
	
	
	
	/**
	 * Contains the current ScreenImageHandler
	 * 
	 * @since 30.04.1999
	 */
	protected ScreenImageHandler screenImageHandler;


	/**
	 * Construct an EventImageCanvas.
	 * 
	 * @param screenImageHandler Contains the current ScreenImageHandler
	 * @since 30.04.1999
	 */
	public ImageCanvasMouseEventListener(ScreenImageHandler screenImageHandler)
	{
	    this.screenImageHandler = screenImageHandler;
    }
	
	
	/**
	 * Handles the mouse pressed action  and triggers a PopupMenu.
	 * 
	 * @param e MouseEvent
	 * @since 30.04.1999
	 */
	public void mousePressed(MouseEvent e)
	{
         //PopUpTrigger
         showPopup(e); 
    }

    /**
	 * Handles the MouseEvent in the same way as the mouseMove action.
     * 
     * @param e MouseEvent
     * @since 30.04.1999
     */
    public void mouseDragged(MouseEvent e)
    {
      mouseMoved(e);
    }

    /**
     * Empty action. Should be overwritten form a derived class
     *
     * @param e MouseEvent
     * @since 30.04.1999
     */
    public void mouseMoved(MouseEvent e)
    {
        
    }

    /**
	 * Handles the mouse released action and triggers a PopupMenu.
     * 
     * @param e MouseEvent
     * @since 30.04.1999
     */
    public void mouseReleased(MouseEvent e)
    {
         //Popuptrigger
         showPopup(e); 
        
    }

    /**
	 * Handles the mouse clicekd action and triggers a PopupMenu.
     * 
     * @param e MouseEvent
     * @since 30.04.1999
     */
    
    public void mouseClicked(MouseEvent e)
    {
         showPopup(e); 
    }

    /**
     * Calls a PopupMenu if the specified MouseEvent is a PopupTrigger.
     * 
     * @param e MouseEvent
     * @since 30.04.1999
     */
    
    void showPopup(MouseEvent e)
    {
        if(e.isPopupTrigger()) 
        {
            handlePopup(e);
        }
    } 

   /**
    * Shows a PopupMenu depending form the derived class.
    * 
    * @param e MouseEvent
    * @since 30.04.1999
    */
   
   abstract void handlePopup(MouseEvent e);
}

/*
 *  CVS Log
 *  $Log: ImageCanvasMouseEventListener.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:10  Schroeter
 *  initial commit of release 1.0
 *
*/
