/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/17 08:10:16 $
 *  Revision :    $Revision: 1.3 $
 *  State:        $State: Exp $
*/


package Viewer.Controller;
import java.awt.event.*;
import java.awt.*;

import Viewer.Presentation.*;
import Viewer.GUI.*;
import Viewer.Main.*;
import Main.*;

/**
 * Contains the listeners for the class LayerDialog.
 * 
 * @author Klaus Kleber
 * @since 30.04.1999
 * @see GUI.LayerDialog
 */
public class LayerDialogEventController implements java.awt.event.ActionListener,java.awt.event.ItemListener
{

    /**
     * Contains the current ScreenImageHandler
     * 
     * @since 30.04.1999
     */
    
    ScreenImageHandler screenImageHandler;

	/**
	 * Contains the LayerDialog which fired the Events
	 * 
	 * @since 30.04.1999
	 */
	LayerDialog layerDialog;

	/**
	 * Constructs a new object.
	 * 
	 * @param screenImageHandler Contains the current ScreenImageHandler
	 * @param layerDialog Contains the LayerDialog which fires the Events
	 * @since 30.04.1999
	 */
	public LayerDialogEventController (ScreenImageHandler screenImageHandler,LayerDialog layerDialog)
	{
	    this.screenImageHandler = screenImageHandler; 
	    this.layerDialog= layerDialog;
	}

	/**
	 * Reveives the ActionEvents. Inserts new PresentationStateGraphicLayer and  edit old 
	 * PresentationStateGraphicLayer.
	 * 
	 * @param e ActionEvent
	 * @since 30.04.1999
	 */
	public void actionPerformed(ActionEvent e)
    {
         Button button = (Button)e.getSource();
         
         if (button.getName().equals("ok")) 
         {
            int rValue;
            int gValue;
            int bValue;
            float mValue;
            
            //is layer name not null
            if (layerDialog.nameTextField.getText().trim().equals("")||layerDialog.nameTextField.getText()== null) (new AttentionDialog((Frame)layerDialog.getParent(), "Error", "Please insert layer name")).setVisible(true);
            else 
            {
                //handle monochome layer
                if (layerDialog.isMonochrome) 
                {
                    mValue = getIntValue(layerDialog.mTextField.getText());
                    try
                    {
                        //change in int value
                        mValue = (new Float(layerDialog.mTextField.getText().trim())).floatValue();
                        if (((mValue <0.0f) || (mValue > 1f)))
                        {
                            (new AttentionDialog((Frame)layerDialog.getParent(), "Error", "Please insert value 0.000 - 1.00 in field gray value")).setVisible(true);
                        }
                        else 
                        {
                            //insert new PresentationStateGraphicLayer with monochrome color
                            if (!layerDialog.edit)
                            {   
                                screenImageHandler.presentationStateGraphicsHandler.insertNewMonochromeLayer(layerDialog.nameTextField.getText(),layerDialog.descriptionTextArea.getText(),mValue);
                                layerDialog.setVisible(false);
                                screenImageHandler.presentationStateGraphicsHandler.setCurrentLayerIndex( screenImageHandler.presentationStateGraphicsHandler.listPresentationStateGraphicLayer.size()-1);
                                screenImageHandler.mainImageViewerPanel.setValue();
                            }
                            else
                            {
                                //edit  PresentationStateGraphicLayer
                                if (!screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().setNewName(layerDialog.nameTextField.getText()))
                                {
                                    (new AttentionDialog((Frame)layerDialog.getParent(), "Error", "Layer name must be unique")).setVisible(true);
                                }
                                else
                                {
                                    screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().setDescription(layerDialog.descriptionTextArea.getText());
                                    screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().setFloatColorValue(mValue);
                                    layerDialog.setVisible(false);
                                    screenImageHandler.mainImageViewerPanel.setValue();
                                    screenImageHandler.buildImageBuffer(false,false, false,true);
                                }   
                            }
                        }
                    }
                    catch(NumberFormatException t)
                    {
                            (new AttentionDialog((Frame)layerDialog.getParent(), "Error", "Please insert value 0.000 - 1.00 in field gray value")).setVisible(true);                       
                    }    
                }
                //handle color PresentationStateGraphicLayer
                else 
                {
                    rValue = getIntValue(layerDialog.rTextField.getText());
                    gValue = getIntValue(layerDialog.gTextField.getText());
                    bValue = getIntValue(layerDialog.bTextField.getText());
                    if ((rValue ==Integer.MAX_VALUE) ||(rValue >= 256)||(rValue < 0)) (new AttentionDialog((Frame)layerDialog.getParent(), "Error", "Please insert value 0 -255 in field r")).setVisible(true);
                    else if ((gValue ==Integer.MAX_VALUE) ||(gValue >= 256)||(gValue < 0)) (new AttentionDialog((Frame)layerDialog.getParent(), "Error", "Please insert value 0 -255 in field r")).setVisible(true);
                    else if ((bValue ==Integer.MAX_VALUE) ||(bValue >= 256)||(bValue < 0)) (new AttentionDialog((Frame)layerDialog.getParent(), "Error", "Please insert value 0 -255 in field r")).setVisible(true);
                    else
                    {
                        // insert new PresentationStateGraphicLayer
                        if (!layerDialog.edit)
                        {   
                        
                            screenImageHandler.presentationStateGraphicsHandler.insertNewColorLayer(   layerDialog.nameTextField.getText(),
                                                                                                        layerDialog.descriptionTextArea.getText(),
                                                                                                        (new Integer(layerDialog.rTextField.getText())).intValue(),
                                                                                                        (new Integer(layerDialog.gTextField.getText())).intValue(),
                                                                                                        (new Integer(layerDialog.bTextField.getText())).intValue());
                            layerDialog.setVisible(false);
                            screenImageHandler.presentationStateGraphicsHandler.setCurrentLayerIndex( screenImageHandler.presentationStateGraphicsHandler.listPresentationStateGraphicLayer.size()-1);
                            screenImageHandler.mainImageViewerPanel.setValue();
                        }
                        //edit old PresentationStateGraphicLayer
                        else
                        {
                            if (!screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().setNewName(layerDialog.nameTextField.getText()))
                            {
                                (new AttentionDialog((Frame)layerDialog.getParent(), "Error", "Layer name must be unique")).setVisible(true);
                            }
                            else
                            {
                                screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().setDescription(layerDialog.descriptionTextArea.getText());
                                screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().setGraphicLayerRecommendedDisplayValueRGB(rValue, gValue, bValue);
                                layerDialog.setVisible(false);
                                screenImageHandler.mainImageViewerPanel.setValue();
                                screenImageHandler.buildImageBuffer(false,false, false,true);
                            
                            }   
                            
                        }
                    }
                 }                                                                               
            }
         }
         if (button.getName().equals("cancel")) 
         {
            layerDialog.setVisible(false);
         }
         
    }
    /**
     * Handles the ItemEvents.
     *
     * @param e ItemEvent
     * @since 30.04.1999
     */
    public void itemStateChanged(ItemEvent e)
    {
        Checkbox trueCheckBox = layerDialog.colorCheckboxGroup.getSelectedCheckbox();
        if(trueCheckBox.getLabel().equals("RGB")) 
        {
            layerDialog.isMonochrome = false;
            layerDialog.monochromePanel.setEnabled(false);
            layerDialog.rgbPanel.setEnabled(true);
        }
        else  
        {
            layerDialog.isMonochrome = true;
            layerDialog.monochromePanel.setEnabled(true);
            layerDialog.rgbPanel.setEnabled(false);
        }
    }

    /**
     * Convert a String to an int value.
     *
     * @param textValue Contains the String which should be converted to an int-value.
     * @since 30.04.1999
     */
    public int getIntValue(String textValue)
    {
        try
        {
            //Umwandelung der Eingabe in einen intWert
            return (new Integer(textValue.trim())).intValue();
            
        }
        catch(NumberFormatException t)
        {
            System.out.println("Number Format Exception" + t);
            return Integer.MIN_VALUE;
        }    
        
    }

}



/*
 *  CVS Log
 *  $Log: LayerDialogEventController.java,v $
 *  Revision 1.3  1999/05/17 08:10:16  Schroeter
 *  Correction of some bad log tags
 *
 *  Revision 1.2  1999/05/14 10:02:32  Schroeter
 *  Log-Tags for CVS corrected
 *
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/
