/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/17 08:10:17 $
 *  Revision :    $Revision: 1.3 $
 *  State:        $State: Exp $
*/

package Viewer.Controller;

import java.awt.event.*;
import java.awt.*;

import Viewer.GUI.*;
import Main.*;
import Viewer.Main.*;
import Viewer.Presentation.*;

/**
 * Contains the listeners for the Class LayerPanel.
 *
 * @author Klaus Kleber
 * @since 30.04.1999
 */
public class LayerPanelEventController implements java.awt.event.ActionListener, java.awt.event.ItemListener
{

    /**
     * Contains the current ScreenImageHandler
     * 
     * @since 30.03.1999
     */
    
    ScreenImageHandler screenImageHandler;

	/**
	 * Contains the LayerPanel which fires the Events
	 * 
	 * @since 30.03.1999
	 */
	LayerPanel layerPanel;

	/**
	 * Builds a new LayerPanelActionHandler.
	 *
	 * @param screenImageHandler Contains the current ScreenImageHandler
	 * @param layerPanel Contains the LayerPanel which fires the Events
	 * @since 30.03.1999
	 */
	public LayerPanelEventController (ScreenImageHandler screenImageHandler,LayerPanel layerPanel)
	{
	    this.screenImageHandler = screenImageHandler; 
	    this.layerPanel= layerPanel;
	}

	/**
	 * Handles the ItemEvents of a LayerPanel object. 
	 *
	 * @param e ItemEvent
	 * @since 30.03.1999
	 */
	public void itemStateChanged(ItemEvent e)
	{
	    if (e.getSource() instanceof Choice)
	    {
	        Choice layerChoice = (Choice) e.getSource();
	        
	        //Change selected Layer
	        if (layerChoice.getName().equals("nameLayer"))
	        {
	            //if one layer exist.
	            if (layerChoice.getItemCount() >0)
	            {
                    //if selecteds item is a layer
                    if (layerChoice.getSelectedIndex() != screenImageHandler.presentationStateGraphicsHandler.listPresentationStateGraphicLayer.size())
                    {
                        layerPanel.deactiveAnnotationListisVisible = false;
                        
                        screenImageHandler.presentationStateGraphicsHandler.setCurrentLayerIndex(layerChoice.getSelectedIndex());
                        screenImageHandler.mainImageViewerPanel.setValue();
        	        }
        	        //if selected Item is the deactive List
        	        else
        	        {
                        layerPanel.deactiveAnnotationListisVisible = true;
                        screenImageHandler.mainImageViewerPanel.setValue();
        	            
        	        }
	            }
	        }
	    }
	    //change selectet PresentationStateAnnotationObject
	    else 
	    {
	        List layerContentList = (List) e.getSource();
	        if (layerContentList.getItemCount()!= 0) 
	        {
                if (layerContentList.getSelectedIndex() < screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().listPresentationStateObject.size())
                {
	            
	                screenImageHandler.setCurrentLayerObject(layerContentList.getSelectedIndex());
	            }
	        }
	    }
	}

	/**
	 * Handles the ActionEvents of a LayerPanel object. 
	 *
	 * @param e ActionEvent
	 * @since 30.03.1999
	 */
	
	public void actionPerformed(ActionEvent e)
    {
         if (e.getSource() instanceof Button)
         {
            Button button = (Button)e.getSource();
             
            //create new layer
            if (button.getName().equals("new")) 
            {
                LayerDialog layerDialog = new LayerDialog(screenImageHandler.mainImageViewerPanel.parentFrame,"New Layer",true,screenImageHandler,false);
                layerDialog.setVisible(true);
            }
            
            //deletes the selected layer
            if (button.getName().equals("delete")) 
            {
                //deltetes annotation
                if (layerPanel.layerNameChoice.getSelectedIndex()>=0)
                {
                    screenImageHandler.presentationStateGraphicsHandler.deleteLayer(layerPanel.layerNameChoice.getSelectedIndex());
                    screenImageHandler.buildImageBuffer(false,false,false,true);
                    screenImageHandler.mainImageViewerPanel.funktionBasisTabPanel.layerPanel.setValue();
                    screenImageHandler.mainImageViewerPanel.annotationPanel.setValue();
                }
            
            
            }
            
            //Edit  layer
            if (button.getName().equals("edit")) 
            {
                
                if ((layerPanel.layerNameChoice.getSelectedIndex()>=0)&&(layerPanel.layerNameChoice.getSelectedIndex() != screenImageHandler.presentationStateGraphicsHandler.listPresentationStateGraphicLayer.size()))
                {   
                    LayerDialog layerDialog = new LayerDialog(screenImageHandler.mainImageViewerPanel.parentFrame,"Edit Layer",true,screenImageHandler,true);
                    layerDialog.setVisible(true);
                }
                
            }
            
            //delete Annotation
            if (button.getName().equals("deleteObject")) 
            {
               if (layerPanel.annotationInLayerList.getSelectedIndex() < screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().listPresentationStateObject.size())
               {
                   
                    screenImageHandler.deleteActivePresentationStateGraphicObject();
               }
                //deletes overlay
                else
                {
                    if ((layerPanel.annotationInLayerList.getSelectedIndex()>=0)|| !layerPanel.deactiveAnnotationListisVisible)
                    {
                        int index = layerPanel.annotationInLayerList.getSelectedIndex()- screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().listPresentationStateObject.size();
                        screenImageHandler.presentationStateGraphicsHandler.ps.deactivateOverlay(layerPanel.layerNameChoice.getSelectedIndex(),index);
                        screenImageHandler.buildImageBuffer(false,false,false,true);
                        screenImageHandler.mainImageViewerPanel.funktionBasisTabPanel.layerPanel.setValue();
                        screenImageHandler.mainImageViewerPanel.annotationPanel.setValue();
                    
                    }
                }
                
            
                
            }
            
            //move annotation
            if (button.getName().equals("moveObject")) 
            {
                if ((layerPanel.moveToChoice.getSelectedIndex() >-1)&&(layerPanel.layerNameChoice.getSelectedIndex() >-1)&&(layerPanel.annotationInLayerList.getSelectedIndex() >-1))
                {
                   if (layerPanel.moveToChoice.getSelectedIndex() <screenImageHandler.presentationStateGraphicsHandler.listPresentationStateGraphicLayer.size())
                   {
                        
                        //Moves annotations and activate overlays
                        if (layerPanel.layerNameChoice.getSelectedIndex()<screenImageHandler.presentationStateGraphicsHandler.listPresentationStateGraphicLayer.size())
                        {
                            //Moves annotations 
                            if (layerPanel.annotationInLayerList.getSelectedIndex()< screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().listPresentationStateObject.size())
                            {
                                System.out.println("move Annotation to Layer");
                                screenImageHandler.presentationStateGraphicsHandler.moveToLayer( layerPanel.moveToChoice.getSelectedIndex(),
                                                                                                    layerPanel.layerNameChoice.getSelectedIndex(), 
                                                                                                    layerPanel.annotationInLayerList.getSelectedIndex());
                            }
                            //Moves overlays
                            else
                            {
                                int status = screenImageHandler.presentationStateGraphicsHandler.ps.moveOverlay(layerPanel.layerNameChoice.getSelectedIndex(),
                                                layerPanel.annotationInLayerList.getSelectedIndex()- screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().listPresentationStateObject.size(),
                                                layerPanel.moveToChoice.getSelectedIndex());
                            
                            }
                            //Repaints only if color is different
                            if (!screenImageHandler.presentationStateGraphicsHandler.getLayerAtIndex(layerPanel.moveToChoice.getSelectedIndex()).getColor().equals(screenImageHandler.presentationStateGraphicsHandler.getLayerAtIndex(layerPanel.layerNameChoice.getSelectedIndex()).getColor()))
                            {
                                    screenImageHandler.buildImageBuffer(false,false, false,true); 
                            }
                            screenImageHandler.mainImageViewerPanel.funktionBasisTabPanel.layerPanel.setValue();
                            
                        }
                        //Moves deactivate Overlays
                        else 
                        {
                                System.out.println("activate Overlay");
                            
                            screenImageHandler.presentationStateGraphicsHandler.overlayList.activateOverlay(layerPanel.annotationInLayerList.getSelectedIndex(),layerPanel.moveToChoice.getSelectedIndex());
                            screenImageHandler.buildImageBuffer(false,false,false,true);
                            screenImageHandler.mainImageViewerPanel.funktionBasisTabPanel.layerPanel.setValue();
                        
                        }
                   }
                }
                
            }
            
        }
    }
}




/*
 *  CVS Log
 *  $Log: LayerPanelEventController.java,v $
 *  Revision 1.3  1999/05/17 08:10:17  Schroeter
 *  Correction of some bad log tags
 *
 *  Revision 1.2  1999/05/14 10:02:33  Schroeter
 *  Log-Tags for CVS corrected
 *
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/
