/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:10 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/
package Viewer.Controller;

import java.awt.event.*;
import java.awt.*;
import java.awt.geom.*;

import Viewer.GUI.*;
import Viewer.Presentation.*;
import Viewer.Main.*;

/**
* This class handles the ActionEvents fired form any PopupMenu.
*
* @author  Klaus Kleber
* @since 30.04.1999
* @see GUI.ImageCanvasPopupEdit
* @see GUI.ImageCanvasPopupEditText
* @see GUI.ImageCanvasPopupNew
*/
public class PopupMenuEventController implements java.awt.event.ActionListener,java.awt.event.ItemListener
{

	
	/**
	* Contains the current ScreenImageHandler
	*
    * @since 30.04.1999
	*/
	private ScreenImageHandler screenImageHandler;


	
	
	/**
	* Constructs a new Object.
	* 
	* @param ScreenImageHander Contains the current ScreenImageHandler.
    * @since 30.04.1999
	*/
	public PopupMenuEventController(ScreenImageHandler screenImageHandler)
	{
	   this.screenImageHandler = screenImageHandler;
	}
	
	
	/**
	* Handles the ActionEvents received from any PopupMenu.
	* 
	* @param e ActionEvent
    * @since 30.04.1999
    * @see GUI.ImageCanvasPopupEdit
    * @see GUI.ImageCanvasPopupEditText
    * @see GUI.ImageCanvasPopupNew
	*/
	public void actionPerformed(ActionEvent e)
	{
         MenuItem menuItem = (MenuItem)e.getSource();
        if (screenImageHandler.imageCanvasMouseEventListener != null)
        {
            screenImageHandler.imageCanvas.removeMouseListener(screenImageHandler.imageCanvasMouseEventListener);
            screenImageHandler.imageCanvas.removeMouseMotionListener(screenImageHandler.imageCanvasMouseEventListener);
        }    
        screenImageHandler.mainImageViewerPanel.annotationPanel.setActiveButton(null);
         
            //handel delete
            if (menuItem.getName().equals("deleteNew")) 
            {
                screenImageHandler.paintStructure.deleteCurrentPaintObject();
                screenImageHandler.setEditAction();   
                
            }
            else if (menuItem.getName().equals("delete")) 
            {
	            screenImageHandler.deleteActivePresentationStateGraphicObject();
  
                
            }
	        //handle stop drawing poloylines
	        else if (menuItem.getName().equals("stop"))
	        {
                screenImageHandler.setStopNew();
                screenImageHandler.setEditAction();   
	            
	        }
	        //handle closing polylines
	        else if (menuItem.getName().equals("close"))
	        {
	            screenImageHandler.setCloseNew();
                screenImageHandler.setEditAction();   
	        }
	        //handle moving graphic annotations
	        else if (menuItem.getName().equals("move"))
	        {
                screenImageHandler.startMoveAnnotation();
	            
	        }
	        ///////////////////////////////////////////
	        /// Text Annotations
	        ///////////////////////////////////////////////
	        
	        //handle text editing  
	        else if (menuItem.getName().equals("edit"))
	        {
                EditTextDialog editTextDialog = new EditTextDialog(screenImageHandler.mainImageViewerPanel.parentFrame,"edit text",true,screenImageHandler,(PresentationStateTextObject)screenImageHandler.presentationStateGraphicsHandler.getCurrentLayerObject());
                editTextDialog.setVisible(true);
                screenImageHandler.setEditAction();   
	           
	        }
	        
	        //handle insert anchor point for text
	        else if (menuItem.getName().equals("insert anchor point display relative"))
	        {
                screenImageHandler.setNewTextPart(true,true);
	        }
	        //handle insert anchor point for text
	        else if (menuItem.getName().equals("insert anchor point image relative"))
	        {
                screenImageHandler.setNewTextPart(true,false);
	        }
	       
	         
	         //handle moving  anchor point
	         else if (menuItem.getName().equals("move anchor point"))
	         {
                screenImageHandler.setNewTextPart(true,false);
	            
	         }
	        //handle insert bounding box  for text
	         else if (menuItem.getName().equals("move bounding box"))
	         {

                screenImageHandler.setNewTextPart(false,false);
	          
	         }
	        
	        //handle insert bounding box  for text
	         else if (menuItem.getName().equals("insert bounding box display relative"))
	         {
                screenImageHandler.setNewTextPart(  false,true);
	         }
	        //handle insert bounding box  for text
	         else if (menuItem.getName().equals("insert bounding box image relative"))
	         {
                screenImageHandler.setNewTextPart(  false,false);
	            
	         }
	         else if (menuItem.getName().equals("remove anchor point"))
	         {
	            ((PresentationStateTextObject)screenImageHandler.presentationStateGraphicsHandler.getCurrentLayerObject()).removeAnchorPoint();
	            screenImageHandler.buildImageBuffer(false,false, false,true);
                screenImageHandler.setEditAction();   
	         
	         }
	         else if (menuItem.getName().equals("remove bounding box"))
	         {
	           ((PresentationStateTextObject)screenImageHandler.presentationStateGraphicsHandler.getCurrentLayerObject()).removeBoundingBox();
	            screenImageHandler.buildImageBuffer(false,false, false,true);
                screenImageHandler.setEditAction();   
	         
	         }
	         else if (menuItem.getName().equals("set bounding box display relative"))
	         {
	           convert(0);
	         }
	         else if (menuItem.getName().equals("set bounding box image relative"))
	         {
	           convert(0);
	         }
	         else if (menuItem.getName().equals("set anchor point display relative"))
	         {
	           convert(1);
	           
	         }
	         else if (menuItem.getName().equals("set anchor point image relative"))
	         {
	           convert(1);
	         
	         }
	         else if (menuItem.getName().equals("set anchor point invisible"))
	         {
                ((PresentationStateTextObject)screenImageHandler.presentationStateGraphicsHandler.getCurrentLayerObject()).setAnchorPointVisible(false);
	            screenImageHandler.buildImageBuffer(false,false, false,true);
                screenImageHandler.setEditAction();   
	            
	         }
	         else if (menuItem.getName().equals("set anchor point visible"))
	         {
                ((PresentationStateTextObject)screenImageHandler.presentationStateGraphicsHandler.getCurrentLayerObject()).setAnchorPointVisible(true);
	            screenImageHandler.buildImageBuffer(false,false, false,true);
                screenImageHandler.setEditAction();   
	         
	         }
	         
	        
	}
	
	
    public void itemStateChanged(ItemEvent event)
    {
        CheckboxMenuItem item = (CheckboxMenuItem) event.getSource();
	    if (item.getName().equals("Image relative"))
	    {
        ((PresentationStateGraphicObject)screenImageHandler.presentationStateGraphicsHandler.getCurrentLayerObject()).convert();
	    
	        screenImageHandler.buildImageBuffer(false,false,false,true);
	        screenImageHandler.setEditAction();
	        // update listbox
	        screenImageHandler.mainImageViewerPanel.funktionBasisTabPanel.layerPanel.setValue();
	    }
	    if (item.getName().equals("filled"))
	    {
            PresentationStateGraphicObject filledObject =  ((PresentationStateGraphicObject)screenImageHandler.presentationStateGraphicsHandler.getCurrentLayerObject());
            if (filledObject != null) 
            {
                if (filledObject.isfilled() == false)filledObject.setFilled(true);
                else filledObject.setFilled(false);
                screenImageHandler.buildImageBuffer(false,false,false,true);
            }
            screenImageHandler.setEditAction();
    	        
	    }
            
    }
   
    public void convert(int units)
    {
        ((PresentationStateTextObject)screenImageHandler.presentationStateGraphicsHandler.getCurrentLayerObject()).convert(units);
        screenImageHandler.setEditAction();   
    
    }

}


/*
 *  CVS Log
 *  $Log: PopupMenuEventController.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:10  Schroeter
 *  initial commit of release 1.0
 *
*/
