/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/17 08:10:18 $
 *  Revision :    $Revision: 1.2 $
 *  State:        $State: Exp $
*/

package Viewer.Controller;

import java.awt.event.*;
import java.awt.image.*;
import java.awt.*;

import Viewer.GUI.*;
import Main.*;
import Viewer.Main.*;
import Viewer.Presentation.*;

import jToolkit.Gui.*;
import StuMan.*;
import J2Ci.*;

/**
 * This class contains the listeners for the PresentationStatePanel.
 * 
 * @author Klaus Kleber
 * @since 30.03.1999
 * @see GUI.PresentationStatePanel
 */

public class PresentationStatePanelEventController implements java.awt.event.ActionListener,java.awt.event.FocusListener
{   

    /**
     * Contains the current ScreenImageHandler
     * 
     * @since 30.03.1999
     */
    ScreenImageHandler screenImageHandler;

	/**
	 * Contains the Panel which fires the events
	 * 
	 * @since 30.03.1999
	 */
	PresentationStatePanel presentationStatePanel;

	/**
	 * Constructor.
	 * 
	 * @param screenImageHandler Contains the current ScreenImageHandler
	 * @param presentationStatePanel Contains the Panel which fires the Events
	 * @since 30.03.1999
	 */
	public PresentationStatePanelEventController (ScreenImageHandler screenImageHandler,PresentationStatePanel presentationStatePanel)
	{
	    this.screenImageHandler = screenImageHandler; 
	    this.presentationStatePanel= presentationStatePanel;
	}

    /**
     * Not used
     *
     * @param e FocusEvent
     * @since 30.03.1999
     */
	
    public void focusGained(FocusEvent e)
    {
        
    }

    /**
     * Receives the Events form the TextFields/TextArea
     * 
     * @param e FocusEvent
     * @since 30.03.1999
     */
    public void focusLost(FocusEvent e)
    {
        // Fired form a TextField
        if (e.getSource() instanceof TextField)
        {
            TextField text = (TextField)e.getSource();
            
            //Save new label
            if (text.getName().equals("label"))
                screenImageHandler.presentationStateGraphicsHandler.ps.setPresentationLabel(text.getText());
            
            //save new creator
            if (text.getName().equals("creator"))
                screenImageHandler.presentationStateGraphicsHandler.ps.setPresentationCreatorsName(text.getText());
            
            //changeAmbientLight
            if (text.getName().equals("ambientlight")) changeAmbientLight(text.getText());           
            
        }
        //Fired form a TextArea
        else 
        {   
            TextArea text = (TextArea)e.getSource();
            
            //save new description
            screenImageHandler.presentationStateGraphicsHandler.ps.setPresentationDescription(text.getText());
        }
    }

	/**
	 * Changes the ambient light to the specified value. The specified 
	 * value must be greater than zero.
	 *
	 * @param toValue Specifies the new value for the ambient light.
	 * @since 30.03.1999
	 */
    
    
	public void changeAmbientLight (String toValue)
	{
	    float textValue;
        try
        {
            //Umwandelung der Eingabe in einen intWert
            textValue = (new Float(toValue.trim())).floatValue();
            
            if (textValue >= 0.0f)
            {                
                screenImageHandler.buildImageBuffer(false,true, false, true);
                presentationStatePanel.setValue();
            }
            else
            {
                presentationStatePanel.setValue();
                
            }
        }
        catch(NumberFormatException t)
        {
            System.out.println("Number Format Exception" + t);
            presentationStatePanel.setValue();
        }    
     
	}

	/**
	 * Reveives the ActionEvents.
	 *
	 * @param e ActionEvent.
	 * @since 30.03.1999
	 */
	public void actionPerformed(ActionEvent e)
    {
         //Event fired form a Button
         if (e.getSource() instanceof Button)
         {
            Button button = (Button)e.getSource();
             
            //Saves as a file 
            if (button.getName().equals("savefile")) 
            {
                OnSaveFile();
            }
             
            //saves the screen
            if (button.getName().equals("savescreen")) 
            {
                OnSaveScreen();
            }
             
            //Set barten on/off
            if (button.getName().equals("bartenOnOff")) 
            {
                OnBartenOnOff();
            }
             
            //Set presentation state on/off
            if (button.getName().equals("psOnOff")) 
            {
                OnPresStateOnOff();
            }
             
            //saves in the database
            if (button.getName().equals("save")) 
            {
                StudyMan sm = StudyMan.instance;
                if (sm != null) sm.suspendThread = true;            
                
                //??Filling TLHC new 
                //int status = screenImageHandler.presentationStateGraphicsHandler.dvi.savePState("pres\\"+ presentationStatePanel.getNameLabel());
                int status = screenImageHandler.presentationStateGraphicsHandler.dvi.savePState();
                screenImageHandler.mainImageViewerPanel.setValue();
               
                //Updates the database 
                try {Thread.sleep(2000);}catch(Exception ex){}
                if (sm != null) 
                {
                    sm.suspendThread = false;
                    sm.LoadAll (false);
                }
            }
            
            //resets the presentation state
            if (button.getName().equals("reset")) 
            {
                screenImageHandler.presentationStateGraphicsHandler.resetPresentationState();
                screenImageHandler.setNewImage();
                
            }
         }
         else if (e.getSource() instanceof TextField)
         {
            TextField tf = (TextField) e.getSource();
            //Changes the ambient light
            if (tf.getName().equals ("ambientlight"))
            {
                changeAmbientLight(tf.getText());
            }
            
         }
    
    }

    /**
     * Saves the current presentation state and the dicom image as file.
     * You can save the files in different transfer syntax
     *
     * @since 30.03.1999
     */
    public void OnSaveFile()
    {
        jDVInterface dvi = screenImageHandler.presentationStateGraphicsHandler.dvi;
        Frame parentF = screenImageHandler.mainImageViewerPanel.parentFrame;
        
        FileDialog saveDlg = new FileDialog (parentF, "Save DICOM file", FileDialog.SAVE);
	    saveDlg.show();
	    
	    if (saveDlg.getFile() == null) return;
	    
	    String DCMfilename = saveDlg.getDirectory() + saveDlg.getFile() + ".dcm";
	    String PSfilename = saveDlg.getDirectory() + saveDlg.getFile() + ".pres";

	    
	    	    
        boolean explicitVR = ChooseExplicitVR ();
	    dvi.savePState (PSfilename, explicitVR);
	    dvi.saveCurrentImage (DCMfilename, explicitVR);
    }

    /**
     * Saves the current screen as a DICOM SC file.
     * You can save the files in different transfer syntax
     *
     * @since 30.03.1999
     */
    public void OnSaveScreen()
    {
        Frame parentF = screenImageHandler.mainImageViewerPanel.parentFrame;
        jDVInterface dvi = screenImageHandler.presentationStateGraphicsHandler.dvi;
        jDVPresentationState ps = screenImageHandler.presentationStateGraphicsHandler.ps;
        
        FileDialog saveDlg = new FileDialog (parentF, "Save screenshot as DICOM file", FileDialog.SAVE);
	    saveDlg.show();
	    
	    if (saveDlg.getFile() == null) return;
	    String DCMfilename = saveDlg.getDirectory() + saveDlg.getFile();
	    
	    boolean explicitVR = ChooseExplicitVR ();
	    
	        dvi.saveDICOMImage (DCMfilename, ((DataBufferByte) (screenImageHandler.getBufferedScreenImage().getRaster().getDataBuffer())).getData(), 
	            screenImageHandler.imageCanvas.getSize().width, 
	            screenImageHandler.imageCanvas.getSize().height, 
	            1.0, explicitVR, ps.createInstanceUID());
    }

    /**
     * Invert the barten property.
     *
     * @since 30.03.1999
     */
    
    public void OnBartenOnOff()
    {        
        jDVPresentationState ps = screenImageHandler.presentationStateGraphicsHandler.ps;
        boolean bart = ps.getBartenTransform();
        bart = !bart;
        ps.setBartenTransform (bart);
        screenImageHandler.buildImageBuffer(false,true, false, true);
        presentationStatePanel.setValue();
    }

    /**
     * Enables/diables the presentation state.
     *
     * @since 30.03.1999
     */
    
    public void OnPresStateOnOff()
    {        
        jDVInterface dvi = screenImageHandler.presentationStateGraphicsHandler.dvi;
        
        if (screenImageHandler.presentationStateGraphicsHandler.enablePresentationState) 
        {
            System.out.println ("toggle PresStat Off");
            dvi.disablePState();
            screenImageHandler.presentationStateGraphicsHandler.enablePresentationState = false;
        }
        else
        {
            System.out.println ("toggle PresStat On");
            dvi.enablePState();            
            screenImageHandler.presentationStateGraphicsHandler.enablePresentationState = true;
        }
        
        screenImageHandler.presentationStateGraphicsHandler.updatePresentationState();
        
        screenImageHandler.setNewImage();        
    }

    /**
     * Creates and shows a Dialog where you can choose the transfer syntax
     * of the saving presentation state.
     *
     * @since 30.03.1999
     */
    public boolean ChooseExplicitVR ()
    {
        Frame parentF = screenImageHandler.mainImageViewerPanel.parentFrame;
        Checkbox e, i;
	    Button ok;
	    
	    Dialog expDlg = new Dialog (parentF, "Choose VR", true);
	    expDlg.setSize (250, 125);
	    expDlg.setLocation (200, 200);
	    expDlg.setLayout(new GridLayout(3, 1));
	    CheckboxGroup Group1 = new java.awt.CheckboxGroup();
	    e = new Checkbox("Explicit VR little endian", Group1, true);
	    i = new Checkbox("Implicit VR little endian", Group1, false);	    
        expDlg.add(e);
        expDlg.add(i);
        Panel p = new Panel ();
        p.add (ok = new CommandAWTButton ("OK", new DisposeCommand (expDlg), 0));        
        expDlg.add(p);
        expDlg.show();
        
        return e.getState();
    }
}



/*
 *  CVS Log
 *  $Log: PresentationStatePanelEventController.java,v $
 *  Revision 1.2  1999/05/17 08:10:18  Schroeter
 *  Correction of some bad log tags
 *
*/ 