/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/17 08:10:18 $
 *  Revision :    $Revision: 1.3 $
 *  State:        $State: Exp $
*/

package Viewer.Controller;

import java.awt.event.*;
import java.awt.*;

import Viewer.Presentation.*;
import Viewer.Paint.*;
import Viewer.GUI.*;
import Main.*;
import Viewer.Main.*;

/**
 * This class contains the Listeners used for the widgets of
 * a ShutterPanel object.
 * 
 * @author Klaus Kleber
 * @since 30.04.1999
 * @see GUI.ShutterPanel
 */
public class ShutterPanelEventController implements java.awt.event.ActionListener, ItemListener,FocusListener
{

    /**
     * Contains the current ScreenImageHandler
     * 
     * @since 30.03.1999
     */
    
    ScreenImageHandler screenImageHandler;

	/**
	 * Contains the ShutterPanel object which fires the events.
	 * 
	 * @since 30.03.1999
	 */
	ShutterPanel shutterPanel;

	/**
	 * Creates a new object.
	 *
	 * @param screenImageHandler Contains the current ScreenImageHandler.
	 * @param shutterPanel Contains the ShutterPanel object which fires the events.
	 */
	public ShutterPanelEventController (ScreenImageHandler screenImageHandler,ShutterPanel shutterPanel)
	{
	   this.screenImageHandler = screenImageHandler; 
	    this.shutterPanel= shutterPanel;
	}

    /**
     * not used.
     * 
     * @param e FocusEvent.
     * @since 30.03.1999
     */
    public void focusGained(FocusEvent e)
    {
    }

    /**
     * Receives the event form Textfield shutterPVTextField and set a new
     * color for the shutter. (Changing the shutter presentation value).
     *
     * @param e FocusEvent.
     * @since 30.03.1999
     */
    public void focusLost(FocusEvent e)
    {
        TextField text = (TextField)e.getSource();
        setNewColorValue(text);
    }

	/**
	 * Changes and draws the bitmaped shutters. 
	 *
	 * @param e ItemEvent
	 * @since 30.03.1999
	 */
	
	
	public void itemStateChanged(ItemEvent e)
	{
         if (e.getSource() instanceof Choice)
         {
            Choice bitmapChoice = (Choice) e.getSource();
            screenImageHandler.presentationStateGraphicsHandler.shutterList.activateBitmapShutter(bitmapChoice.getSelectedIndex()-1);
            screenImageHandler.buildImageBuffer(false,true, false,true);
          }
         shutterPanel.setValue();
	}

	/**
	 * Reveives the ActionEvents form the ShutterPanel object.
	 * These Events invoke methods for creating and deleting vector shutters and
	 * changing the shutter presentation value.
	 *
	 * @param e ActionEvent
	 * @since 30.03.1999
	 */
	public void actionPerformed(ActionEvent e)
    {
         //Button events
         if (e.getSource() instanceof Button)
         {
            Button button = (Button)e.getSource();
            
            //create polyline 
            if (button.getName().equals("newPolyline")) 
            {
                PaintObject ann = new PolylineObject();
   		        ann.isShutter = true;
   		        screenImageHandler.setNewPaintObjectAction(ann);
                    
            }
            
            //create rectangle
            if (button.getName().equals("newRectangle")) 
            {
                PaintObject ann = new Rectangle2DObject();
   		        ann.isShutter = true;
   		        screenImageHandler.setNewPaintObjectAction(ann);
            }
            
            //create circle
            if (button.getName().equals("newCircle")) 
            {
                PaintObject ann = new Circle2DObject();
   		        ann.isShutter = true;
   		        screenImageHandler.setNewPaintObjectAction(ann);
                    
            }
            
            //deltet polyline
            if (button.getName().equals("delPolyline")) 
            {
                screenImageHandler.presentationStateGraphicsHandler.shutterList.deletePolygonal();
                screenImageHandler.buildImageBuffer(false,false,false,true);
                shutterPanel.setValue();
            }
            
            //delete rectangle
            if (button.getName().equals("delRectangle")) 
            {
                screenImageHandler.presentationStateGraphicsHandler.shutterList.deleteRectangular();
                screenImageHandler.buildImageBuffer(false,false,false,true);
                shutterPanel.setValue();
            }
            
            //deltet circle
            if (button.getName().equals("delCircle")) 
            {
                screenImageHandler.presentationStateGraphicsHandler.shutterList.deleteCircular();
                screenImageHandler.buildImageBuffer(false,false,false,true);
                shutterPanel.setValue();
            }
        }
        //Events form TextFields. Changing the shutter presentation value.
        else
        {
            TextField text = (TextField) e.getSource();
            setNewColorValue(text);
            
        }
    }

    /**
     * Changes the color of the shutters to the specified colorvalue in the parameter.
     *
     * @param text Contains the TextFiled with the new color value.
     * @since 30.03.1999
     */
    private void setNewColorValue(TextField text)
    {
        float textValue;
        try
        {
            //conerting String to Float.
            textValue = (new Float(text.getText().trim())).floatValue();
            
            if (!((textValue <0.0f) || (textValue > 1f)))
            {
                screenImageHandler.presentationStateGraphicsHandler.shutterList.setShutterColor(textValue);
                screenImageHandler.buildImageBuffer(false,true,false,true);
                shutterPanel.setValue();
            }
            else
            {
                shutterPanel.setValue();
                
            }
        }
        catch(NumberFormatException t)
        {
            System.out.println("Number Format Exception" + t);
            shutterPanel.setValue();
        }    
        
    }
}



/*
 *  CVS Log
 *  $Log: ShutterPanelEventController.java,v $
 *  Revision 1.3  1999/05/17 08:10:18  Schroeter
 *  Correction of some bad log tags
 *
 *  Revision 1.2  1999/05/14 10:02:34  Schroeter
 *  Log-Tags for CVS corrected
 *
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/
