/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/17 08:10:19 $
 *  Revision :    $Revision: 1.3 $
 *  State:        $State: Exp $
*/

package Viewer.Controller;

import java.awt.event.*;
import java.awt.*;

import Viewer.Presentation.*;
import Viewer.GUI.*;
import Main.*;
import Viewer.Main.*;

/**
* This class handles the Events fired  form the class TextDialog.
*
* @author Klaus Kleber
* @since 30.04.1999
* @see GUI.TextDialog
*/
public class TextDialogEventController implements java.awt.event.ActionListener
{
    
    /**
    * Contains the current ScreenImageHandler.
    *
    * @since 30.04.1999
    */
    ScreenImageHandler screenImageHandler;
	
	/**
	* GUI class which fires the Events. 
    *
    * @since 30.04.1999
    */
	TextDialog textDialog;
	
	
	/**
	* Constructs a new object.
	*
	* @param screenImageHandler Controller class.
	* @param textDialog GUI class which fires the events. 
    * @since 30.04.1999
	*/
	public TextDialogEventController (ScreenImageHandler screenImageHandler,TextDialog textDialog)
	{
	   this.screenImageHandler = screenImageHandler; 
	   this.textDialog= textDialog;
	}
	
	
	/**
	* Handles the ActionEvent fired from a TextDialog object. 
	* Receiving an ActionEvent fired from the OKButton 
	* results in a new PresentationStateTextObejct.
	* Receiving an ActionEvent fired from the OKButton 
	* results in closiing the TextDialog.
	*
	* @param e ActionEvent.
    * @since 30.04.1999
	*/
	public void actionPerformed(ActionEvent e)
    {
         
         Button button = (Button)e.getSource();
         
         //Press the OK button
         if (button.getName().equals("ok")) 
         {
            if (textDialog.nameTextField.getText().equals(""))(new AttentionDialog((Frame)textDialog.getParent(), "Error", "Please insert text")).setVisible(true);
            else
            {
                screenImageHandler.setNewText(textDialog.nameTextField.getText(),
                                                textDialog.isBoundingCheckbox.getState(),
                                                textDialog.isAnchorCheckbox.getState(),
                                                textDialog.isBothCheckbox.getState(),
                                                textDialog.isAnchorDisplayRelativeCheckbox.getState(),
                                                textDialog.isBoxDisplayRelativeCheckbox.getState(),
                                                textDialog.isAnchorVisibleCheckbox.getState());
                textDialog.setVisible(false);
            }
         }
         //Handles the cancel Button
         if (button.getName().equals("cancel")) 
         {
            textDialog.setVisible(false);
         }
    }

}


/*
 *  CVS Log
 *  $Log: TextDialogEventController.java,v $
 *  Revision 1.3  1999/05/17 08:10:19  Schroeter
 *  Correction of some bad log tags
 *
 *  Revision 1.2  1999/05/14 10:02:34  Schroeter
 *  Log-Tags for CVS corrected
 *
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/
