/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/17 08:10:20 $
 *  Revision :    $Revision: 1.3 $
 *  State:        $State: Exp $
*/

package Viewer.Controller;

import java.awt.event.*;
import java.awt.*;

import Viewer.Presentation.*;
import Viewer.GUI.*;
import Viewer.Main.*;
import Main.*;
import J2Ci.*;

/**
* This class handles the ItemEvents fired  from  the 
* WLTabPanel objects. 
*
* @author Klaus Kleber
* @since 30.04.1999
* @see GUI.WLTabPanel
*/
public class WLTabPanelItemEventController implements java.awt.event.ItemListener
{
    
    /**
    * Contains the current ScreenImageHandler.
    *
    * @since 30.04.1999
    */
    ScreenImageHandler screenImageHandler;
	
	/**
	* GUI class which fires the Events. 
    *
    * @since 30.04.1999
    */
	WLTabPanel wLTabPanel;
	
	/**
	 * Constructs a new object.
	 * 
	 * @param screenImageHandler Contains the current screenImageHandler.
	 * @param WLTabPanel GUI class which fires the Events. 
	 * @since 30.04.1999
	 */
	public WLTabPanelItemEventController (ScreenImageHandler screenImageHandler,WLTabPanel wLTabPanel)
	{
	   this.screenImageHandler = screenImageHandler; 
	    this.wLTabPanel= wLTabPanel;
	}
	
	/**
	 * Handles the ItemEvents. Receiving a ItemEvent from the
	 * imageWindowChoice results in a new window level setting.
	 * Receiving a ItemEvent from the lutChoice results in 
	 * applying the LUT to the image.
	 * 
	 * @param e ItemEvent
	 * @since 30.04.1999
	 */
	public void itemStateChanged(ItemEvent e)
	{
	    jDVPresentationState ps = screenImageHandler.presentationStateGraphicsHandler.ps;
	    //handling for the choices
	    if (e.getSource() instanceof Choice)
	    {
	        Choice eventChoice = (Choice) e.getSource();
	        
	        //handling for standardWindowChoice
	        if (eventChoice.getName().equals("imageWindowChoise"))
	        {
	            //auto image
	            if (eventChoice.getSelectedIndex()==0)
	            {
                    jDoubleByRef minValue = new jDoubleByRef();
                    jDoubleByRef maxValue = new jDoubleByRef();
                    ps.getImageMinMaxPixelValue(minValue, maxValue);
                    screenImageHandler.setNewWindow((int)(minValue.value+(maxValue.value-minValue.value+1)/2),(int)(maxValue.value -minValue.value));
                	        
	            }
	            else ps.setVOIWindowFromImage(eventChoice.getSelectedIndex()-1);
                screenImageHandler.buildImageBuffer(false,true, false,false);
                screenImageHandler.mainImageViewerPanel.funktionBasisTabPanel.wLTabPanel.setValue();
            }
	        //handling for lutChoice
	        if (eventChoice.getName().equals("lutChoice"))
	        {
	            if (eventChoice.getSelectedIndex() < ps.getNumberOfVOILUTsInImage())
	            {	                
	                ps.setVOILUTFromImage(eventChoice.getSelectedIndex());
                    screenImageHandler.buildImageBuffer(false,true, false,false);
                    screenImageHandler.mainImageViewerPanel.funktionBasisTabPanel.wLTabPanel.setValue();
	                
	            }
            }
        }
        else
        {
	        Checkbox eventCheckbox = (Checkbox) e.getSource();
            if (eventCheckbox.getName().equals("lutCheckbox"))
	        {
	            ps.setVOILUTFromImage(0);
                screenImageHandler.buildImageBuffer(false,true, false,false);
                screenImageHandler.mainImageViewerPanel.funktionBasisTabPanel.wLTabPanel.setValue();
            
            }
            if (eventCheckbox.getName().equals("winCheckbox"))
	        {
                jDoubleByRef minValue = new jDoubleByRef();
                jDoubleByRef maxValue = new jDoubleByRef();
                ps.getImageMinMaxPixelValue(minValue, maxValue);
                screenImageHandler.setNewWindow((int)(minValue.value+(maxValue.value-minValue.value+1)/2),(int)(maxValue.value -minValue.value));
                screenImageHandler.buildImageBuffer(false,true, false,false);
                screenImageHandler.mainImageViewerPanel.funktionBasisTabPanel.wLTabPanel.setValue();
            
            }
            
        }
    }
}




/*
 *  CVS Log
 *  $Log: WLTabPanelItemEventController.java,v $
 *  Revision 1.3  1999/05/17 08:10:20  Schroeter
 *  Correction of some bad log tags
 *
 *  Revision 1.2  1999/05/14 10:02:35  Schroeter
 *  Log-Tags for CVS corrected
 *
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/
