/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:10 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package Viewer.Controller;

import java.awt.*;
import java.awt.event.*;
import java.util.*;

import Viewer.Main.*;
import Viewer.GUI.*;
import Viewer.Presentation.*;

/**
 * This class contains the listeners for the zoom PanelSlider 
 * in the WLTabPanel.
 * 
 * @author Klaus Kleber
 * @since 30.04.1999
 * @see GUI.WLTabPanel
 */
public class WLTabPanelZoomEventController implements SliderPanelListener
{
	/**
	 * Contains text of the PanelSlider before changing. If an error occurs
	 * the text can be restore.
	 * 
	 * @since 30.04.1999
	 */
    String oldText;
	
	/**
	 * Contains the PanelSlider which fired the Events.
	 * 
	 * @since 30.04.1999
	 */
    PanelSlider panelSlider;
	
	
	/**
	 * Contains the current ScreenImageHandler
	 * 
	 * @since 30.04.1999
	 */
    ScreenImageHandler screenImageHandler;
   
	/**
	 * Constructs a new object.
	 * 
	 * @param screenImageHandler Contains the current screenImageHandler.
	 * @since 30.04.1999
	 */
    public WLTabPanelZoomEventController( ScreenImageHandler screenImageHandler)
    {
        this.screenImageHandler = screenImageHandler;
        oldText = new String("");
    }
	/**
	 * Sets a new PanelSlider.
	 * 
	 * @param panelSlider The new PanelSlider
	 * @since 30.04.1999
	 */
    public void setPanelSlider(PanelSlider panelSlider)
    {
        this.panelSlider = panelSlider;
    }
    
	/**
	 * Handles the ActionEvents fired from the PanelSlider. The ActionEvent 
	 * are fired from the TextField and results in a new zoom value.
	 * 
	 * @param e ActionEvent
	 * @since 30.04.1999
	 */
    public void actionPerformed(ActionEvent e)
    {
        //Aufrufendes Textfeld
        TextField text = (TextField)e.getSource();
        
        //Sperren des Listeners
        text.removeActionListener(this);
        setValue(text);
        text.addActionListener(this);
        
    }
    
	/**
	 * Handles the focus gained action  from the PanelSlider. 
	 * This action results in saving the text off the fireing TextField.
	 * 
	 * @param e FocusEvent
	 * @since 30.04.1999
	 */
    
    public void focusGained(FocusEvent e)
    {
        TextField text = (TextField)e.getSource();
        text.removeFocusListener(this);
        oldText = new String(text.getText());
        text.addFocusListener(this);
        
    }
	
	
	/**
	 * Handles the focus gained action from the PanelSlider. The FocusEvent 
	 * are fired from the TextField and results in a new zoom value.
	 * 
	 * @param e FocusEvent
	 * @since 30.04.1999
	 */
    public void focusLost(FocusEvent e)
    {
        TextField text = (TextField)e.getSource();
        text.removeFocusListener(this);
        setValue(text);
        text.addFocusListener(this);
        
    }
	
	
	/**
	 * Handles the AdjustmentEvent fired from the PanelSlider. The AdjustmentEvent 
	 * are fired from the Scrollbar and results in a new zoom value.
	 * 
	 * @param e AdjustmentEvent
	 * @since 30.04.1999
	 */
    public void adjustmentValueChanged(AdjustmentEvent e)
    {
        Scrollbar scroll;
        //if (e.getAdjustmentType() == AdjustmentEvent.TRACK) return;
            scroll = (Scrollbar)e.getSource();
            scroll.removeAdjustmentListener(this);
            
            screenImageHandler.presentationStateGraphicsHandler.setZoomValue((double)panelSlider.getValue()/100d);
                
	    
	        screenImageHandler.buildImageBuffer(false,false,true,true);
            
            panelSlider.setText(Double.toString((double)panelSlider.getValue()/100d));
            
            scroll.addAdjustmentListener(this);
    }
    
    
    /**
    * Gets the  value from the specified TextField and sets a new zoom value.
    *    
    *
    * @param text Specifies the TextFiled with the value.
    * @since 30.04.1999
    */
    public void setValue(TextField text)
    {
        
        //Hilfsvariable
        float textValue;
        int newValue;
        try
        {
            //Umwandelung der Eingabe in einen intWert
            textValue = (new Float(text.getText().trim())).floatValue();
            
            if (!((textValue <0.1d) || (textValue > 10d)))
            {
                newValue = (int)  Math.round(textValue*100d);  
                
                text.setText( Double.toString((double)newValue/100d));
                
                panelSlider.setScrollbarValue(newValue);
                screenImageHandler.presentationStateGraphicsHandler.setZoomValue((double)newValue/100d);
                        
        	    
	            screenImageHandler.buildImageBuffer(false,false,true,true);
                
                oldText = new String (text.getText());
                
            }
            else
            {
                text.setText( oldText);
                
            }
        }
        catch(NumberFormatException t)
        {
            System.out.println("Number Format Exception" + t);
            text.setText( oldText);
        }    
        
    }
}
/*
 *  CVS Log
 *  $Log: WLTabPanelZoomEventController.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:10  Schroeter
 *  initial commit of release 1.0
 *
*/
