/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:10 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package Viewer.GUI;

import java.awt.*;
import java.util.*;

import Main.*;
import Viewer.Presentation.*;
import Viewer.Main.*;
import Viewer.Controller.*;

/**
 * This class contains the widgets for creating PresentationStateAnnotationObjects.
 * 
 * @author Klaus Kleber
 * @since 30.04.1999
 * @see Controller.AnnotationPanelEventController
 */
public class AnnotationPanel extends java.awt.Panel
{

	/**
	 * Contains the active Button. The active Button shows which kind of 
	 * mouse functions are possible in the viewPanel.
	 * 
	 * @since 30.03.99
	 */
	
	public Button activeButton = null;

	/**
	 * state true -  if the PresentationStateAnnotationObject should be drawn filled
	 * 
	 * @since 30.03.99
	 */
	
	public Checkbox filled;

	/**
	 * state true- if the PresentationStateAnnotationObject should be image relative, else display relative.
	 * 
	 * @since 30.03.99
	 */
	public Checkbox image;

	/**
	 * Contains the button for drawing a line.
	 * 
	 * @since 30.03.99
	 */
	
	Button buttonLine;

	/**
	 * Contains the Button for drawing a circle
	 * 
	 * @since 30.03.99
	 */
	Button buttonCircle;

	/**
	 * Contains the Button for drawing a polyline
	 * 
	 * @since 30.03.99
	 */
	Button buttonPolyline;

	/**
	 * Contains a Button for drawn an interpolated line.
	 * 
	 * @since 30.03.99
	 */
	Button buttonInterpolated;

	/**
	 * Contains a Button for drawing a ellipse.
	 * 
	 * @since 30.03.99
	 */
	Button buttonEllipse;

	/**
	 * Contains a Button for drawing a rectangle.
	 * 
	 * @since 30.03.99
	 */
	Button buttonRectangle;

	/**
	 * Contains a Button for drawing a text.
	 * 
	 * @since 30.03.99
	 */
	Button buttonText;

	/**
	 * Contains a Button for editing a PresentationStateAnnotationObject.
	 * 
	 * @since 30.03.99
	 */
	Button buttonEdit;

	/**
	 * Contains the layers of the current presentation state. 
	 * The PresentationStateAnnotationObject will be drawn in 
	 * the selected layer.
	 * 
	 * @since 30.03.99
	 */
	
	Choice layerChoice;

	/**
	 * Contains the current ScreenImageHandler.
	 * 
	 * @since 30.03.99
	 */
	
	ScreenImageHandler screenImageHandler;

	/**
	 * Constructor.
	 * 
	 * @param screenImageHandler Contains the current ScreenImageHandler
	 * @since 30.03.99
	 */
	public AnnotationPanel(ScreenImageHandler screenImageHandler)
	{
		super();
		this.screenImageHandler = screenImageHandler;
        //Init Eventhandler 
	     
        AnnotationPanelEventController theEventController = new AnnotationPanelEventController(this,screenImageHandler);
		
		
		setLayout(new BorderLayout(10,10));
		setBackground(new Color(12632256));
            
		
		Panel funktionPanel = new Panel();
		funktionPanel.setLayout(new GridLayout(2,5,5,5));
		add("Center", funktionPanel);
		
		//Line
		buttonLine = new java.awt.Button();
		buttonLine.setLabel("Line");
		buttonLine.setName("Line");
		buttonLine.addActionListener(theEventController);
		buttonLine.setBounds(93,5,21,23);
		buttonLine.setBackground(new Color(12632256));
		funktionPanel.add(buttonLine);
		
		//Polyline
		buttonPolyline = new java.awt.Button();
		buttonPolyline.setLabel("Polyline");
		buttonPolyline.setBounds(147,5,22,23);
		buttonPolyline.addActionListener(theEventController);
		buttonPolyline.setName("Polyline");
		buttonPolyline.setBackground(new Color(12632256));
		funktionPanel.add(buttonPolyline);
		
		//Circle
		buttonCircle = new java.awt.Button();
		buttonCircle.setLabel("Circle");
		buttonCircle.setName("Circle");
		buttonCircle.setBounds(196,5,23,23);
		buttonCircle.addActionListener(theEventController);
		buttonCircle.setBackground(new Color(12632256));
		funktionPanel.add(buttonCircle);
		
		//Text
		buttonText = new java.awt.Button();
		buttonText.setLabel("Text");
		buttonText.setBounds(251,5,21,23);
		buttonText.setBackground(new Color(12632256));
		buttonText.setName("Text");
		buttonText.addActionListener(theEventController);
		funktionPanel.add(buttonText);
		
		//Rectangle
		buttonRectangle = new java.awt.Button();
		buttonRectangle.setLabel("Rectangle");
		buttonRectangle.setBounds(119,5,23,23);
		buttonRectangle.setBackground(new Color(12632256));
		buttonRectangle.addActionListener(theEventController);
		buttonRectangle.setName("Rectangle");
		funktionPanel.add(buttonRectangle);
		
		
		//Interpolated
		buttonInterpolated = new java.awt.Button();
		buttonInterpolated.setLabel("Interpolated");
		buttonInterpolated.setBounds(174,5,17,23);
		buttonInterpolated.setBackground(new Color(12632256));
		buttonInterpolated.addActionListener(theEventController);
		buttonInterpolated.setName("Interpolated");
		
		funktionPanel.add(buttonInterpolated);
		
		
		
		//Ellipse
		buttonEllipse = new java.awt.Button();
		buttonEllipse.setLabel("Ellipse");
		buttonEllipse.setBounds(224,5,22,23);
		buttonEllipse.setBackground(new Color(12632256));
		buttonEllipse.setName("Ellipse");
		buttonEllipse.addActionListener(theEventController);
		funktionPanel.add(buttonEllipse);
		
		
		//edit
		buttonEdit = new java.awt.Button();
		buttonEdit.setLabel("Edit");
		buttonEdit.setName("SetWork");
		buttonEdit.addActionListener(theEventController);
		buttonEdit.setBounds(331,5,22,23);
		buttonEdit.setBackground(new Color(12632256));
		funktionPanel.add(buttonEdit);
		
		
		//LayerChoice
		Panel eastPanel = new Panel(new GridLayout(2,1));
		layerChoice = new Choice();
		layerChoice.addItem("                                       ");
		layerChoice.addItemListener(theEventController);
		eastPanel.add(layerChoice);
		
		//Checkpanel
		Panel checkPanel = new Panel(new GridLayout(1,2));
		filled = new Checkbox("filled");
		filled.addItemListener(theEventController);
		filled.setName("filled");
		checkPanel.add(filled);
		
		//imageCheckbox
		image= new Checkbox("image relative");
		image.setName("image");
		image.setState(true);
		image.addItemListener(theEventController);
		checkPanel.add(image);
		eastPanel.add(checkPanel);
		
		add("East",eastPanel);
		
		
		
	}


    /**
     * Updates the content of the GUI.
     * 
     * @since 30.03.99
     */
    public void setValue()
    {
        Vector listGraphicLayer = screenImageHandler.presentationStateGraphicsHandler.getListPresentationStateGraphicLayer();
        
        PresentationStateGraphicLayer nextLayer;
        
        //Remove all Items form layerChoice.
        if (layerChoice.getItemCount() >= 0) layerChoice.removeAll();
        
        //Fill layerChoice.
        for (int i = 0; i < listGraphicLayer.size(); i++)
        {
            nextLayer =   (PresentationStateGraphicLayer) (listGraphicLayer.elementAt(i));
            layerChoice.addItem(new String(i + " " +nextLayer.getName()));
        }
        
        //select actualLayer
        if (screenImageHandler.presentationStateGraphicsHandler.getCurrentLayerIndex() != -1) layerChoice.select(screenImageHandler.presentationStateGraphicsHandler.getCurrentLayerIndex());
    }

    /**
     * Activates the specified Button
     * 
     * @param activeButton Button which should be specified.
     * @since 30.03.99
     */
    public void setActiveButton(Button activeButton)
    {
        if (this.activeButton != null) this.activeButton.setBackground(Color.lightGray);
        this.activeButton = activeButton;
        if (this.activeButton != null) this.activeButton.setBackground(Color.gray);
    }
    
    /**
     * Activates the editButton
     * 
     * @since 30.03.99
     */
    public void setActiveButton()
    {
        if (this.activeButton != null) this.activeButton.setBackground(Color.lightGray);
        this.activeButton = buttonEdit;
        if (this.activeButton != null) this.activeButton.setBackground(Color.gray);
    }
}
/*
 *  CVS Log
 *  $Log: AnnotationPanel.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:10  Schroeter
 *  initial commit of release 1.0
 *
*/
