/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:10 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package Viewer.GUI;

import java.awt.*;

import Main.*;

/**
 * This class contains the GUI of a Dialog with message.
 * 
 * @author Klaus Kleber
 * @since 30.04.1999
 */
public class AttentionDialog extends Dialog
{

	/**
	 * Label which conatins the message.
	 * 
	 * @since 30.03.99
	 */
	java.awt.Label label1 = new java.awt.Label();

	/**
	 * ok Button
	 * 
	 * @since 30.03.99
	 */
	java.awt.Button okButton = new java.awt.Button();

	/**
	 * Constructor
	 * 
	 * @param parent Parent Frame
	 * @param title Title of the AttentionDialog
	 * @param message Contains the message which should be visible on the Dialog.
	 * @since 30.03.99
	 */
	public AttentionDialog(Frame parent, String title, String message)
	{
		super(parent, title,true);

		setBackground(new Color(12632256));
        setFont(MainContext.instance().getUsedFont());
        
        setSize(270*MainContext.instance().getSizeFactor(),73*MainContext.instance().getSizeFactor());

		setLayout(new BorderLayout());
		setVisible(false);
		
		//init label
		label1.setText(message);
		label1.setAlignment(Label.CENTER);
		add("Center",label1);
		
		//init okButton
		Panel buttonPanel = new Panel();
		okButton.setLabel("OK");
		buttonPanel.add(okButton);
		add("South", buttonPanel);
		okButton.setBackground(java.awt.Color.lightGray);
		//}}


		//{{REGISTER_LISTENERS
		SymAction lSymAction = new SymAction();
		okButton.addActionListener(lSymAction);
		//}}
	}



	public void addNotify()
	{
  	    // Record the size of the window prior to calling parents addNotify.
	    Dimension d = getSize();

		super.addNotify();

		if (fComponentsAdjusted)
			return;

		// Adjust components according to the insets
		Insets insets = getInsets();
		setSize(insets.left + insets.right + d.width, insets.top + insets.bottom + d.height);
		Component components[] = getComponents();
		for (int i = 0; i < components.length; i++)
		{
			Point p = components[i].getLocation();
			p.translate(insets.left, insets.top);
			components[i].setLocation(p);
		}
		fComponentsAdjusted = true;
	}

    // Used for addNotify check.
	boolean fComponentsAdjusted = false;

	//{{DECLARE_CONTROLS
	//}}
    
    /**
     * Shows or hides the component depending on the boolean flag b.
     * 
     * @param b if true, show the component
     * @since 30.03
     * @see java.awt.Component#isVisible
     */
    public void setVisible(boolean b)
	{
		if(b)
		{
			Rectangle bounds = getParent().getBounds();
			Rectangle abounds = getBounds();
	
			setLocation(bounds.x + (bounds.width - abounds.width)/ 2,
				 bounds.y + (bounds.height - abounds.height)/2);
		}
		super.setVisible(b);
	}

	/**
	 * Event handler.
	 * 
	 * @author Klaus Kleber
	 * @version 1.0
	 * @since 30.03
	 */

	class SymAction implements java.awt.event.ActionListener
	{

		/**
		 * Handles the ok Button Event.
		 * 
		 * @param event Event fire form the ob-Button.
		 */
		public void actionPerformed(java.awt.event.ActionEvent event)
		{
			Object object = event.getSource();
			if (object == okButton)
				okButton_ActionPerformed(event);
		}
	}

	void okButton_ActionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.

		okButton_ActionPerformed_Interaction1(event);
	}

	void okButton_ActionPerformed_Interaction1(java.awt.event.ActionEvent event)
	{
		try {
			this.dispose();
		} catch (Exception e) {
		}
	}
}


/*
 *  CVS Log
 *  $Log: AttentionDialog.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:10  Schroeter
 *  initial commit of release 1.0
 *
*/
