/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:10 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package Viewer.GUI;

import java.awt.*;

import Viewer.Presentation.*;
import Viewer.Main.*;
import Viewer.Controller.*;
import Main.*;

/**
* This class contains the GUI for editing text annotaions
* 
* @author Klaus Kleber
* @since 30.04.1999	
*/
	 
public class EditTextDialog extends Dialog
{

	/**
	 * 
	 * @since 30.03.99
	 */
	
	ScreenImageHandler screenImageHandler;

	/**
	 * ok Button of this dialog.
	 * 
	 * @since 30.03.99
	 */
	Button okButton;

	/**
	 * cancel Button
	 * 
	 * @since 30.03.99
	 */
	Button cancelButton;

	/**
	 * Contains the text.
	 * 
	 * @since 30.03.99
	 */
	public TextField nameTextField;

	/**
	 * 
	 * @since 30.03.99
	 */
	public PresentationStateTextObject text;

	/**
	 * Constructor.
	 *
	 * @param parent Parent Frame of this Diolog
	 * @param title Title of this dialog
	 * @param modal contains true if this dialog is modal.
	 * @param screenImageHandler Contains the curren ScreenImageHandler.
	 * @param text Text which should be edit.
	 * @since 30.03.99
	 */
	public EditTextDialog(Frame parent, String title, boolean modal,ScreenImageHandler screenImageHandler,PresentationStateTextObject text)
	{
		super(parent);
        this.text = text;
		this.screenImageHandler=screenImageHandler;
		setTitle(title);
        setModal(modal);
        
        
        setFont(MainContext.instance().getUsedFont());
        setSize(300*MainContext.instance().getSizeFactor(),100*MainContext.instance().getSizeFactor());
		setBackground(new Color(12632256));
        setLayout(new BorderLayout(10,10));
        
        //create Listener
        EditTextDialogEventController editTextDialogEventController = new EditTextDialogEventController(screenImageHandler,this);
        
        
        Panel topPanel = new Panel(new GridLayout(3,1));
        topPanel.add(new Label(""));
        
        //init nameTextField
        nameTextField = new TextField(text.getTextValue());
        topPanel.add(nameTextField);
        topPanel.add(new Label(""));
        add("North", topPanel);
        
        //init ok Button
        Panel buttonPanel = new Panel();
        okButton = new Button("OK");
        okButton.addActionListener(editTextDialogEventController);
        okButton.setName("ok");
        buttonPanel.add(okButton);
        
        //init cancel Button
        cancelButton = new Button("Cancel");
        cancelButton.addActionListener(editTextDialogEventController);
        cancelButton.setName("cancel");
        buttonPanel.add(cancelButton);
        
        add("South", buttonPanel);
        
		//{{REGISTER_LISTENERS
		SymWindow aSymWindow = new SymWindow();
		this.addWindowListener(aSymWindow);
		//}}
		
	}

	/**
	 * @since 30.03.99
	 */
	
	public void addNotify()
	{
  	    // Record the size of the window prior to calling parents addNotify.
	    Dimension d = getSize();

		super.addNotify();

		if (fComponentsAdjusted)
			return;

		// Adjust components according to the insets
		Insets insets = getInsets();
		setSize(insets.left + insets.right + d.width, insets.top + insets.bottom + d.height);
		Component components[] = getComponents();
		for (int i = 0; i < components.length; i++)
		{
			Point p = components[i].getLocation();
			p.translate(insets.left, insets.top);
			components[i].setLocation(p);
		}
		fComponentsAdjusted = true;
	}

    // Used for addNotify check.
	boolean fComponentsAdjusted = false;



    /**
     * Shows or hides the component depending on the boolean flag b.
     * 
     * @param b if true, show the component
     * @since 30.03.99
     * @see java.awt.Component#isVisible
     */
    public void setVisible(boolean b)
	{
		if(b)
		{
			Rectangle bounds = getParent().getBounds();
			Rectangle abounds = getBounds();
	
			setLocation(bounds.x + (bounds.width - abounds.width)/ 2,
				 bounds.y + (bounds.height - abounds.height)/2);
		}
		super.setVisible(b);
	}


	/**
	 * Handles the WindowEvents
	 * 
	 * @author Klaus Kleber
	 * @version 1.0
	 * @since 30.03.99
	 */
	class SymWindow extends java.awt.event.WindowAdapter
	{
		public void windowClosing(java.awt.event.WindowEvent event)
		{
			Object object = event.getSource();
			if (object == EditTextDialog.this)
				Dialog1_WindowClosing(event);
		}
	}
	
	void Dialog1_WindowClosing(java.awt.event.WindowEvent event)
	{
		setVisible(false);
	}
}
/*
 *  CVS Log
 *  $Log: EditTextDialog.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:10  Schroeter
 *  initial commit of release 1.0
 *
*/
