/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:10 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package Viewer.GUI;

import java.awt.*;

import jToolkit.Gui.*;
import Viewer.Main.*;
import Main.*;
import Viewer.Presentation.*;

/**
 * This class contains the GUI of the function tab on the  right side.
 * 
 * @author Klaus Kleber
 * @since 30.04.1999
 */


public class FunktionBasisTabPanel extends TabPanel
{

	/**
	 * Contains the current ScreenImageHandler.
	 * 
	 * @since 30.03.99
	 */
	ScreenImageHandler screenImageHandler;


	/**
	 * Contains the panel with the image processing functions
	 * 
	 * @since 30.03.99
	 */
	public WLTabPanel wLTabPanel;

	/**
	 * Contains the panel with functions and informations of the 
	 * current presentation state.
	 * 
	 * @since 30.03.99
	 */
	public PresentationStatePanel presentationStatePanel;

	/**
	 * Contains the panel with layer based functions.
	 * 
	 * @since 30.03.99
	 */
	public LayerPanel layerPanel;

	/**
	 * Contains the panel with shutter based functions.
	 * 
	 * @since 30.03.99
	 */
	public ShutterPanel shutterPanel;

    /**
     * Constructor.
     * 
     * @param screenImageHandler Contains the current ScreenImageHandler.
     * @since 30.03.99
     */
    
    public FunktionBasisTabPanel(ScreenImageHandler screenImageHandler)
    { 
        super();
		this.screenImageHandler = screenImageHandler;
        
		
		setFont(MainContext.instance().getUsedFont());
		add ("Prs", presentationStatePanel = new PresentationStatePanel(screenImageHandler));
		add ("Fct", wLTabPanel = new WLTabPanel(screenImageHandler));
		add ("Layer", layerPanel = new LayerPanel(screenImageHandler));
		add ("Shutter", shutterPanel = new ShutterPanel(screenImageHandler));
		
    }

   /**
    * Notifies all panels to update their values.
    * 
    * @since 30.03.99
    */
   public void setValue()
   {
	    wLTabPanel.setValue();
	    presentationStatePanel.setValue();
	    layerPanel.setValue();
	    shutterPanel.setValue();
    }

    /**
     * Overwrites this method.
     * 
     * @since 30.03.99
     */
    public Dimension getPreferredSize()
    {
        return presentationStatePanel.getPreferredSize();
    }
	//{{DECLARE_CONTROLS
	//}}
}

/*
 *  CVS Log
 *  $Log: FunktionBasisTabPanel.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:10  Schroeter
 *  initial commit of release 1.0
 *
*/
