/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:11 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package Viewer.GUI;

import java.awt.*;

import Viewer.Main.*;
import Viewer.Presentation.*;

/**
 * This class contains the GUI in which the image will be drawn.
 * 
 * @author Klaus Kleber
 * @since 30.04.1999
 */
public class ImageCanvas extends Canvas
{

    /**
    * CurrentPopupMenu of the ImageCanvas
    * 
    * @since 30.04.99
    */
    private PopupMenu imageCanvasPopup;
    
    /**
     * Contains the current ScreenImageHandler.
     * 
     * @since 30.04.99
     */
    
    public ScreenImageHandler screenImageHandler;
    
    /**
     * Constructs an ImagaCanvas
     * 
     * @param screenImageHandler Contains the current ScreenImageHandler
     * @since 30.04.99
     */
    public ImageCanvas(ScreenImageHandler screenImageHandler)
    {
       super();
       this.screenImageHandler = screenImageHandler;
       setBackground(Color.black);
	   screenImageHandler.setImageCanvas(this);
		
		//{{REGISTER_LISTENERS
		//}}
	}
    /**
     * Removes the current PopupMenu from the ImageCanvas.
     *
     * @since 30.04.99
     */
    public void removePopupMenu()
    {
        if (imageCanvasPopup != null) remove(imageCanvasPopup);
    }
    
    /**
     * Adds the specified PopupMenu to the ImageCanvas.
     *
     * @since 30.04.99
     */
    public void addPopupMenu(PopupMenu newPopupMenu)
    {
        imageCanvasPopup = newPopupMenu;
        add(imageCanvasPopup);
    }
    
    /**
     * Standard paint
     * 
     * @param g graphic context
     * @since 30.04.99
     */
    public void paint(Graphics g) 
    {
        System.out.println("ImageCanvas.paint");
        update(g);
    }
    /**
     * Draws the image on the GUI.
     * 
     * @param g graphic context
     * @since 30.04.99
     */
    public void update(Graphics g) 
    {
         Graphics2D g1 = null;
         //Erstellen des Graphic
        System.out.println("ImageCanvas.update");
        
        try
        {
           g1 = (Graphics2D) g;    
            if (g1 != null)
            {
                g1.setColor(Color.black);
                screenImageHandler.drawScreenImage(g1);
            }
        }
        finally 
        {
            g1.dispose() ;
        }
    }
    

}    
/*
 *  CVS Log
 *  $Log: ImageCanvas.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/
    
    
   

