/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:11 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package Viewer.GUI;

import java.awt.*;

import Viewer.Presentation.*;
import Viewer.Controller.*;
import Viewer.Main.*;
import Main.*;

/**
 * This class contains the PopupMenue for editing PresentationStateGraphicObject.
 * 
 * @author Klaus Kleber
 * @since 30.04.1999
 */
public class ImageCanvasPopupEdit extends PopupMenu
{

    /**
     * Creates the PopupMenu and adds the listeners to the menue items.
     * 
     * @param screenImageHandler Contains the current ScreenImageHandler
     * @param clickedObject Contains the PresentationStateGraphicObject which is clicked with the mouse.
     * @since 30.03.99
     */
    public ImageCanvasPopupEdit(    ScreenImageHandler screenImageHandler,
                                    PresentationStateGraphicObject clickedObject)
     {
        
         
            //deltet Item
            MenuItem menuItem;
            PopupMenuEventController popupMenuController = new PopupMenuEventController(screenImageHandler);
            menuItem = new MenuItem("delete");
            menuItem.setName("delete");
            menuItem.setFont(MainContext.instance().getUsedFont());
            menuItem.addActionListener(popupMenuController);
            add(menuItem);
               
            //move item
            menuItem = new MenuItem("move");
            menuItem.setName("move");
            menuItem.setFont(MainContext.instance().getUsedFont());
            menuItem.addActionListener(popupMenuController);
            add(menuItem);
            addSeparator();
            
            //image relative checkbox
            CheckboxMenuItem checkBoxMenuItem ; 
            checkBoxMenuItem  = new CheckboxMenuItem("Image relative");
            checkBoxMenuItem.setName("Image relative");
            checkBoxMenuItem.setFont(MainContext.instance().getUsedFont());
            checkBoxMenuItem.addItemListener(popupMenuController);
            if (clickedObject.getAnnotationUnits()== 0)checkBoxMenuItem.setState(true);
            else checkBoxMenuItem.setState(false);
            add(checkBoxMenuItem);
            
            //Filled checkbox
            checkBoxMenuItem  = new CheckboxMenuItem("filled");
            checkBoxMenuItem.setName("filled");
            checkBoxMenuItem.setFont(MainContext.instance().getUsedFont());
            checkBoxMenuItem.addItemListener(popupMenuController);
            checkBoxMenuItem.setState(clickedObject.isfilled());
            //if the PresentationStateGraphicObject is closed it can be filled
            if(clickedObject.isClosed())add(checkBoxMenuItem);
     }
                                 
}

/*
 *  CVS Log
 *  $Log: ImageCanvasPopupEdit.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/
