/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:11 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package Viewer.GUI;

import java.awt.*;

import Viewer.Presentation.*;
import Viewer.Controller.*;
import Viewer.Main.*;
import Main.*;

/**
 * This class contains the PopupMenue for editing PresentationStateTextObject.
 * 
 * @author Klaus Kleber
 * @since 30.04.99
 */
public class ImageCanvasPopupEditText extends PopupMenu
{
    /**
     * Creates the PopupMenu and adds the listeners to the menue items.
     * 
     * @param screenImageHandler Contains the current ScreenImageHandler
     * @param clickedText Contains the PresentationStateTextObject which is clicked with the mouse.
     * @since 30.03.99
     */
    public ImageCanvasPopupEditText(    ScreenImageHandler screenImageHandler,
                                    PresentationStateTextObject clickedText)
     {
        
            //Delete Item
            MenuItem menuItem;
            PopupMenuEventController popupMenuController = new PopupMenuEventController(screenImageHandler);
            menuItem = new MenuItem("delete");
            menuItem.setName("delete");
            menuItem.setFont(MainContext.instance().getUsedFont());
            menuItem.addActionListener(popupMenuController);
            add(menuItem);
               
            //edit item
            menuItem = new MenuItem("edit");
            menuItem.setName("edit");
            menuItem.setFont(MainContext.instance().getUsedFont());
            menuItem.addActionListener(popupMenuController);
            add(menuItem);
            
            addSeparator();
            
            //If PresentationStateTextObject an anchor point an no bounding box
            //the user can insert an image or a display relative bounding box
            if (!clickedText.haveBoundingBox() &&clickedText.haveAnchorPoint())
            {
                //insert display relative bounding box 
                menuItem = new MenuItem("insert bounding box display relative");
                menuItem.setName("insert bounding box display relative");
                menuItem.setFont(MainContext.instance().getUsedFont());
                menuItem.addActionListener(popupMenuController);
                add(menuItem);
            
                //insert image relative biunding box
                menuItem = new MenuItem("insert bounding box image relative");
                menuItem.setName("insert bounding box image relative");
                menuItem.setFont(MainContext.instance().getUsedFont());
                menuItem.addActionListener(popupMenuController);
                add(menuItem);
                
            }
            
            //move bounging box item
            if (clickedText.haveBoundingBox())
            {
                menuItem = new MenuItem("move bounding box");
                menuItem.setName("move bounding box");
                menuItem.setFont(MainContext.instance().getUsedFont());
                menuItem.addActionListener(popupMenuController);
                add(menuItem);
            }
            
            
            //remove bounding box olny if there is an anchor point
            if (clickedText.haveBoundingBox() &&clickedText.haveAnchorPoint())
            {
                menuItem = new MenuItem("remove bounding box");
                menuItem.setName("remove bounding box");
                menuItem.setFont(MainContext.instance().getUsedFont());
                menuItem.addActionListener(popupMenuController);
                add(menuItem);
            }
            
            //change type of bounding box form
            if (clickedText.haveBoundingBox() &&(clickedText.getBoundingBoxAnnotationUnits() ==0))
            {
                menuItem = new MenuItem("set bounding box display relative");
                menuItem.setName("set bounding box display relative");
                menuItem.setFont(MainContext.instance().getUsedFont());
                menuItem.addActionListener(popupMenuController);
                add(menuItem);
            }
            else if (clickedText.haveBoundingBox() &&(clickedText.getBoundingBoxAnnotationUnits() ==1))
            {
                menuItem = new MenuItem("set bounding box image relative");
                menuItem.setName("set bounding box image relative");
                menuItem.setFont(MainContext.instance().getUsedFont());
                menuItem.addActionListener(popupMenuController);
                add(menuItem);
                
            }
            addSeparator();
            
            //insert anchor point
            if (clickedText.haveBoundingBox() &&!clickedText.haveAnchorPoint())
            {
                menuItem = new MenuItem("insert anchor point display relative");
                menuItem.setName("insert anchor point display relative");
                 menuItem.setFont(MainContext.instance().getUsedFont());
                menuItem.addActionListener(popupMenuController);
                add(menuItem);
            
                menuItem = new MenuItem("insert anchor point image relative");
                menuItem.setName("insert anchor point image relative");
                menuItem.setFont(MainContext.instance().getUsedFont());
                menuItem.addActionListener(popupMenuController);
                add(menuItem);
                
            }
            
            //remove boungin box
            if (clickedText.haveBoundingBox() &&clickedText.haveAnchorPoint())
            {
                menuItem = new MenuItem("remove anchor point");
                menuItem.setName("remove anchor point");
                menuItem.setFont(MainContext.instance().getUsedFont());
                menuItem.addActionListener(popupMenuController);
                add(menuItem);
            }
            
            //move bounding box
            if (clickedText.haveAnchorPoint())
            {
                menuItem = new MenuItem("move anchor point");
                menuItem.setName("move anchor point");
                menuItem.setFont(MainContext.instance().getUsedFont());
                menuItem.addActionListener(popupMenuController);
                add(menuItem);
            }
            
            //Change type of anchor point
            if (clickedText.haveAnchorPoint() &&(clickedText.getAnchorPointAnnotationUnits() ==0))
            {
                menuItem = new MenuItem("set anchor point display relative");
                menuItem.setName("set anchor point display relative");
                menuItem.setFont(MainContext.instance().getUsedFont());
                menuItem.addActionListener(popupMenuController);
                add(menuItem);
            }
            else if (clickedText.haveAnchorPoint() &&(clickedText.getAnchorPointAnnotationUnits() ==1))
            {
                menuItem = new MenuItem("set anchor point image relative");
                menuItem.setName("set anchor point image relative");
                menuItem.setFont(MainContext.instance().getUsedFont());
                menuItem.addActionListener(popupMenuController);
                add(menuItem);
                
            }
            
            //Set anchor poiunt visible/unvisible
            if (clickedText.haveAnchorPoint() )
            {
                if (clickedText.anchorPointIsVisible())
                {
                    menuItem = new MenuItem("set anchor point invisible");
                    menuItem.setName("set anchor point invisible");
                    menuItem.setFont(MainContext.instance().getUsedFont());
                    menuItem.addActionListener(popupMenuController);
                    add(menuItem);
                }
                else
                {
                    menuItem = new MenuItem("set anchor point visible");
                    menuItem.setName("set anchor point visible");
                    menuItem.setFont(MainContext.instance().getUsedFont());
                    menuItem.addActionListener(popupMenuController);
                    add(menuItem);
                    
                }
            }
            
     }
                                 
}

/*
 *  CVS Log
 *  $Log: ImageCanvasPopupEditText.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/
