/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:11 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package Viewer.GUI;

import java.awt.*;

import Viewer.Presentation.*;
import Viewer.Paint.*;
import Viewer.Controller.*;
import Viewer.Main.*;
import Main.*;

/**
 * This class contains the PopupMenue for PaintObject. 
 * This PopuMenu can called up by creating a new PaintObject. 
 * 
 * @author Klaus Kleber
 * @since 30.04.1999
 */
public class ImageCanvasPopupNew extends PopupMenu
{

    /**
     * Creates the PopupMenu and adds the listeners to the menue items.
     * 
     * @param screenImageHandler Contains the current ScreenImageHandler
     * @param thePaintObject The new PaintObject
     * @since 30.03.99
     */
    public ImageCanvasPopupNew(  ScreenImageHandler screenImageHandler,
                                 PaintObject thePaintObject)
     {
         
            MenuItem menuItem;
            
            //Actionlistener
            PopupMenuEventController popupMenuController = new PopupMenuEventController(screenImageHandler);
            
            //create the itemes for a PolylineObject
            if (thePaintObject instanceof PolylineObject)
            {
               
                //deltet item
                menuItem = new MenuItem("delete");
                menuItem.setName("deleteNew");
                menuItem.setFont(MainContext.instance().getUsedFont());
                menuItem.addActionListener(popupMenuController);
                add(menuItem);
                
                //close item
                menuItem = new MenuItem("close");
                menuItem.setName("close");
                menuItem.setFont(MainContext.instance().getUsedFont());
                menuItem.addActionListener(popupMenuController);
                add(menuItem);
                
                //stop item
                menuItem = new MenuItem("stop");
                menuItem.setName("stop");
                menuItem.setFont(MainContext.instance().getUsedFont());
                menuItem.addActionListener(popupMenuController);
                add(menuItem);
            }
            //create the itemes for a Line2DObject
            else if (thePaintObject instanceof Line2DObject)
            {
                menuItem = new MenuItem("delete");
                menuItem.setName("deleteNew");
                menuItem.setFont(MainContext.instance().getUsedFont());
                menuItem.addActionListener(popupMenuController);
                add(menuItem);
             
            }
            //create the itemes for a InterpolatedObject
            if (thePaintObject instanceof InterpolatedObject)
            {
               
                //deltet item
                menuItem = new MenuItem("delete");
                menuItem.setName("deleteNew");
                menuItem.setFont(MainContext.instance().getUsedFont());
                menuItem.addActionListener(popupMenuController);
                add(menuItem);
                
                
                //stop item
                menuItem = new MenuItem("stop");
                menuItem.setName("stop");
                menuItem.setFont(MainContext.instance().getUsedFont());
                menuItem.addActionListener(popupMenuController);
                add(menuItem);
            }
    }
}

/*
 *  CVS Log
 *  $Log: ImageCanvasPopupNew.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/
