/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:11 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package Viewer.GUI;

import Viewer.Presentation.*;
import Main.*;
import Viewer.Controller.*;
import Viewer.Main.*;

import java.awt.*;

	/**
	 * Contains the GUI for editing an old layer or for creating a new one.
	 * 
	 * @author Klaus Kleber
	 * @since 30.04.1999
	 */

public class LayerDialog extends Dialog
{

	/**
	 * Contains the current ScreenImageHAndler
	 * 
	 * @since 30.04.1999
	 */
	
	
	ScreenImageHandler screenImageHandler;

	/**
	 * ok Button
	 * 
	 * @since 30.04.1999
	 */
	Button okButton;

	/**
	 * cancel Button
	 * 
	 * @since 30.04.1999
	 */
	Button cancelButton;

	/**
	 * Contains the name of the layer
	 * 
	 * @since 30.04.1999
	 */
	public TextField nameTextField;

	/**
	 * Contains the description of the layer
	 * 
	 * @since 30.04.1999
	 */
	public TextArea descriptionTextArea;

	/**
	 * Contains the red color value of the layer if exits
	 * 
	 * @since 30.04.1999
	 */
	public TextField rTextField;

	/**
	 * Contains the green color value of the layer if exist
	 * 
	 * @since 30.04.1999
	 */
	public TextField gTextField;

	/**
	 * Contains the blue color value of the layer if exist.
	 * 
	 * @since 30.04.1999
	 */
	public TextField bTextField;

	/**
	 * Contains the gray color value of the layer if exits
	 * 
	 * @since 30.04.1999
	 */
	public TextField mTextField;

	/**
	 * true if layer has a gray color value, false if layer has a rgb color. 
	 *
	 * @since 30.04.1999
	 */
	public boolean isMonochrome = true;

	/**
	 * For RGB colors and monochrome color
	 *
	 * @since 30.04.1999
	 */
	 public CheckboxGroup colorCheckboxGroup;

	/**
	 * Contains RGB widgets
	 *
	 * @since 30.04.1999
	 */
	 public Panel rgbPanel;

	/**
	 * Contains monochrome widgets.
	 *
	 * @since 30.04.1999
	 */
	 public Panel monochromePanel;

	/**
	 * true if Dialog should editing an existing PresentationStateGraphicLayer, 
	 * false if Dialog should editing a new one.
	 *
	 * @since 30.04.1999
	 */
	public boolean edit = false;

	/**
	 * Contructs a new LayerDialog.
	 * 
	 * @param parent Contains the parent frame of the dialog
	 * @param title Contains the title of the dialog
	 * @param modal true, if Dialog is modal
	 * @param screenImageHandler Contains the current ScreenImageHandler
	 * @param edit true if Dialog should editing an existing PresentationStateGraphicLayer, 
	 *  false if Dialog should editing a new one.
	 * @since 30.04.1999
	 */
	
	
	public LayerDialog(Frame parent, String title, boolean modal,ScreenImageHandler screenImageHandler,boolean edit)
	{
		super(parent);
		this.edit = edit;
        setFont(MainContext.instance().getUsedFont());
        setSize(330*MainContext.instance().getSizeFactor(),370*MainContext.instance().getSizeFactor());
		this.screenImageHandler=screenImageHandler;
		setTitle(title);
        setModal(modal);
        LayerDialogEventController layerDialogActionHandler = new LayerDialogEventController(screenImageHandler,this);
        
		setBackground(new Color(12632256));
        setLayout(new BorderLayout(5,5));
        
        Panel topPanel = new Panel(new BorderLayout(5,5));
        
        
        Panel namePanel = new Panel(new GridLayout(3,2));
        namePanel.add(new Label(" "));
        namePanel.add(new Label(" "));
        namePanel.add(new Label("Layer Name:"));
        nameTextField = new TextField();
        
        namePanel.add(nameTextField);
        namePanel.add(new Label(" "));
        
        namePanel.add(new Label(" "));
        
        topPanel.add("North",namePanel);
        colorCheckboxGroup = new CheckboxGroup();
        Panel colorPanel = new Panel(new GridLayout(2,1));
        
        Panel rgbCheckboxPanel = new Panel(new GridLayout(2,1));
        Checkbox rgbCheckbox = new Checkbox("RGB", colorCheckboxGroup, false);
        rgbCheckbox.addItemListener(layerDialogActionHandler);
        rgbCheckboxPanel.add(rgbCheckbox);
        
        rgbPanel = new Panel();//(new GridLayout(1,7));
        rgbPanel.add(new Label(" "));
        
        rgbPanel.add(new Label("   r:"));
        rTextField = new TextField(4);
        rgbPanel.add(rTextField);
        
        rgbPanel.add(new Label("   g:"));
        gTextField = new TextField(4);
        rgbPanel.add(gTextField);
        
        rgbPanel.add(new Label("   b:"));
        bTextField = new TextField(4);
        rgbPanel.add(bTextField);
        rgbCheckboxPanel.add(rgbPanel);
        if(!MainContext.instance().usedRGB)rgbCheckboxPanel.setEnabled(false);
        
        Checkbox monochromeCheckbox = new Checkbox("Monochrome", colorCheckboxGroup, true);
        Panel monochromeCheckboxPanel = new Panel (new GridLayout(2,1));
        
        monochromeCheckbox.addItemListener(layerDialogActionHandler);
        monochromeCheckboxPanel.add(monochromeCheckbox);
        
        monochromePanel = new Panel(); // (new GridLayout(1,4));
        monochromePanel.add(new Label(" "));
        
        monochromePanel.add(new Label("gray-value 0.0 .. 1.0 "));
        mTextField = new TextField(4);
        mTextField.setText(new String("1"));
        monochromePanel.add(mTextField);
        monochromePanel.add(new Label(" "));
        
        
        monochromeCheckboxPanel.add(monochromePanel);
       
        colorPanel.add(monochromeCheckboxPanel);
        colorPanel.add(rgbCheckboxPanel);
        
        topPanel.add( "South",colorPanel);
        
        add("North", topPanel);
        
        Panel descriptionPanel = new Panel(new BorderLayout(0,0));
        descriptionPanel.add("North", new Label("Description"));
        descriptionTextArea = new TextArea("",64,4,TextArea.SCROLLBARS_NONE);
        descriptionPanel.add("Center",descriptionTextArea);
        add("Center", descriptionPanel);
        
        Panel buttonPanel = new Panel();
        okButton = new Button("OK");
        okButton.addActionListener(layerDialogActionHandler);
        okButton.setName("ok");
        buttonPanel.add(okButton);
        
        cancelButton = new Button("Cancel");
        cancelButton.addActionListener(layerDialogActionHandler);
        cancelButton.setName("cancel");
        buttonPanel.add(cancelButton);
        
        add("South", buttonPanel);

		
		
		
		//{{REGISTER_LISTENERS
		SymWindow aSymWindow = new SymWindow();
		this.addWindowListener(aSymWindow);
		//}}
		
	    if (edit)
	    {
	        nameTextField.setText(screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().getName());
	        descriptionTextArea.setText(screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().getDescription());
	     
	        if (screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().haveGraphicLayerRecommendedDisplayValue())
	        {
	            if (screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().isGray())
	            {
	                mTextField.setText(new Float(screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().getFloatGrayColorValue()).toString());
    	        
	            }   
	            else
	            {
	                isMonochrome = false; 
	                rgbCheckbox.setState(true);
	                rTextField.setText(new Integer(screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().getRed()).toString());
	                gTextField.setText(new Integer(screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().getBlue()).toString());
	                bTextField.setText(new Integer(screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().getGreen()).toString());
	                mTextField.setText("");
    	        
	            }
	        }
	                
	        else mTextField.setText("1");
	        
	    }
	    else
	    {
	        nameTextField.setText("new layer ");
	    }
	}

	/**
	 * @since 30.04.1999
	 */
	
	public void addNotify()
	{
  	    // Record the size of the window prior to calling parents addNotify.
	    Dimension d = getSize();

		super.addNotify();

		if (fComponentsAdjusted)
			return;

		// Adjust components according to the insets
		Insets insets = getInsets();
		setSize(insets.left + insets.right + d.width, insets.top + insets.bottom + d.height);
		Component components[] = getComponents();
		for (int i = 0; i < components.length; i++)
		{
			Point p = components[i].getLocation();
			p.translate(insets.left, insets.top);
			components[i].setLocation(p);
		}
		fComponentsAdjusted = true;
	}

    // Used for addNotify check.
	boolean fComponentsAdjusted = false;



    /**
     * Shows or hides the component depending on the boolean flag b.
     * 
     * @param b if true, show the component
     * @since 30.04.1999
     * @see java.awt.Component#isVisible
     */
    public void setVisible(boolean b)
	{
		if(b)
		{
			Rectangle bounds = getParent().getBounds();
			Rectangle abounds = getBounds();
	
			setLocation(bounds.x + (bounds.width - abounds.width)/ 2,
				 bounds.y + (bounds.height - abounds.height)/2);
		}
		super.setVisible(b);
	}

	//{{DECLARE_CONTROLS
	//}}

	/**
	 * Close the Dialog
	 *
	 * @author Klaus Kleber
	 * @since 30.04.1999
	 */

	class SymWindow extends java.awt.event.WindowAdapter
	{
		public void windowClosing(java.awt.event.WindowEvent event)
		{
			Object object = event.getSource();
			if (object == LayerDialog.this)
				Dialog1_WindowClosing(event);
		}
	}

	/**
	 * @param event
	 * @since 30.04.1999
	 */
	
	void Dialog1_WindowClosing(java.awt.event.WindowEvent event)
	{
		setVisible(false);
	}
}

/*
 *  CVS Log
 *  $Log: LayerDialog.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/
