/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/17 08:10:20 $
 *  Revision :    $Revision: 1.2 $
 *  State:        $State: Exp $
*/
package Viewer.GUI;

import Viewer.Controller.*;
import Viewer.Presentation.*;
import Viewer.Main.*;

import java.util.*;
import java.awt.*;
import java.awt.List;

/**
 * This class contains the GUI for the layer function tab. On this GUI are functionalities for 
 * creating, deleting, editing PresentationStateGraphicLayers , deleting and  moving PresentationStateAnnotationObjects.
 * 
 * @author Klaus Kleber
 * @since 30.04.1999
 * @see Controller.LayerPanelActionHandler
 */
public class LayerPanel extends java.awt.Panel
{

	/**
	 * Contains the current ScreenImageHandler.
	 * 
	 * @since 30.03.1999
	 */
	ScreenImageHandler screenImageHandler;

    /**
     * Creates an new PresntationStateGraphicLayer
     * 
     * @since 30.03.1999
     */
    
    Button newLayerButton;

    /**
     * Delete a PresentationStateGraphicLayer
     * 
     * @since 30.03.1999
     */
    Button deleteLayerButton;

    /**
     * Edit a PresentationStateGraphicState.
     * 
     * @since 30.03.1999
     */
    Button editButton;

    /**
     * Delete a PresentationStateAnnotationObject
     * 
     * @since 30.03.1999
     */
    Button deleteObjectButton;

    /**
     * Moves a PresentationStateAnnotationObject to an other PresentationStateGraphicLayer
     * 
     * @since 30.03.1999
     */
    Button moveToButton;

    /**
     * Contains the descrption of the PresentationStateGraphicLayer
     * 
     * @since 30.03.1999
     */
    TextArea descriptionTextArea;

    /**
     * Contains all PresentationStateGraphicLayer name for moving PresentationStateAnnotationObjects,
     *
     * @since 30.03.1999
     */
    
    public Choice moveToChoice;

    /**
     * Contains all PresentationStateGraphicLayer name.
     *
     * @since 30.03.1999
     */
    public Choice layerNameChoice;

    /**
     * Contains all PresentationStateAnnotationObjects of the selected PresentationStateGraphicLayer.
     *
     * @since 30.03.1999
     */
    public List annotationInLayerList;

    /**
     * if true the deaktivate list will be visbile.
     *
     * @since 30.03.1999
     */
    
    public boolean deactiveAnnotationListisVisible = false;

    /**
     * Creates the GUI.
     *
     * @param screenImageHandler Contains the current ScreenImageHandler.
     * @since 30.03.1999
     */
    public  LayerPanel(ScreenImageHandler screenImageHandler)
    {
        super();
        this.screenImageHandler = screenImageHandler;
        
        //Creates the Listener
        LayerPanelEventController layerPanelActionHandler = new LayerPanelEventController(screenImageHandler,this);
        
        setLayout(new BorderLayout());
        
        //init layer panel
        Panel layerPanel = new Panel();
        layerPanel.setLayout(new BorderLayout());
        
        Panel layerTopPanel = new Panel(new GridLayout(2,1));
        layerTopPanel.add(new Label("Graphic Layer"));
        
        //Init layer choice
        layerNameChoice = new Choice();
        layerNameChoice.setName("nameLayer");
        layerNameChoice.addItemListener(layerPanelActionHandler);
        layerTopPanel.add(layerNameChoice);
        layerPanel.add("North", layerTopPanel);
        
        //Init layer description
        Panel descriptionPanel = new Panel(new BorderLayout());
        descriptionTextArea = new TextArea("",6,25,TextArea.SCROLLBARS_VERTICAL_ONLY);
        descriptionTextArea.setEnabled(false);
        descriptionPanel.add("North", new Label("Description"));
        descriptionPanel.add("Center", descriptionTextArea);
        layerPanel.add("Center", descriptionPanel);
        
        //Init newButton
        Panel buttonPanel = new Panel();
        newLayerButton = new Button("New");
        newLayerButton.addActionListener(layerPanelActionHandler);
        newLayerButton.setName("new");
        buttonPanel.add(newLayerButton);
        
        //Init deleteButton
        deleteLayerButton = new Button("Delete");
        deleteLayerButton.addActionListener(layerPanelActionHandler);
        deleteLayerButton.setName("delete");
        buttonPanel.add(deleteLayerButton);
        
        //Init editButton
        editButton = new Button("Edit");
        editButton.addActionListener(layerPanelActionHandler);
        editButton.setName("edit");
        buttonPanel.add(editButton);
        layerPanel.add("South", buttonPanel);
    
        add("North",layerPanel);
    
    
        //Init annotationInLayerList
        Panel listPanel=new Panel();
        listPanel.setLayout(new BorderLayout());
        annotationInLayerList = new List();
        annotationInLayerList.addItemListener(layerPanelActionHandler);
        listPanel.add("Center", annotationInLayerList ); 
        
        //Init deleteObjectButton
        Panel objectPanel = new Panel(new GridLayout(2,1));
        Panel buttonObjectPanel = new Panel();
        deleteObjectButton = new Button("Delete");
        deleteObjectButton.setName("deleteObject");
        deleteObjectButton.addActionListener(layerPanelActionHandler);
        buttonObjectPanel.add(deleteObjectButton);
        
        //Init moveToButton
        moveToButton = new Button("Move to");
        moveToButton.setName("moveObject");
        moveToButton.addActionListener(layerPanelActionHandler);
        buttonObjectPanel.add(moveToButton);
        objectPanel.add(buttonObjectPanel);
        
        //Init moveToChoice
        moveToChoice = new Choice();
        moveToChoice.addItemListener(layerPanelActionHandler);
        objectPanel.add(moveToChoice);
        
        listPanel.add("South", objectPanel);
        add("Center", listPanel);
        
        
    }

    /**
     * Updates the content of this panel.
     * 
     * @since 30.03.1999
     */
    public void setValue()
    {
        //Gte layer list of the PresentationStateGraphicsHandler
        Vector listGraphicLayer = screenImageHandler.presentationStateGraphicsHandler.getListPresentationStateGraphicLayer();
        PresentationStateGraphicLayer nextLayer = null; 
        
        int nextLayerIndex = -1;
        this.setEnabled(true);
        
        //Remove contents of the widgets
        layerNameChoice.removeAll();
        moveToChoice.removeAll();
        annotationInLayerList.removeAll();
        descriptionTextArea.setText("");
        
        //if a presentation state is available then fill the widgets
        if (screenImageHandler.presentationStateGraphicsHandler.havePresentationState)
        {
            //fill the layerNameChoice and the moveToChoce with the GraphicLayers of the presentation state
            for (int i = 0; i < listGraphicLayer.size(); i++)
            {
                nextLayer =   (PresentationStateGraphicLayer) (listGraphicLayer.elementAt(i));
                layerNameChoice.add(new String(i + " " +nextLayer.getName()));
                moveToChoice.add(new String(i + " " +nextLayer.getName()));
            }
            
            //Adds an abstract layer in the layerNameChoice which contains the deactive layers
            if (screenImageHandler.presentationStateGraphicsHandler.overlayList.haveOverlays())
                layerNameChoice.add(new String("deactivate"));
            
            //if there is no current layer active then activate the first layer
            if (screenImageHandler.presentationStateGraphicsHandler.getCurrentLayerIndex() == -1) screenImageHandler.presentationStateGraphicsHandler.setCurrentLayerIndex(nextLayerIndex);
           
            //Fill the Annotation list
            if (listGraphicLayer.size() != 0) 
            {
                if (!deactiveAnnotationListisVisible)
                {
                    
                    layerNameChoice.select(screenImageHandler.presentationStateGraphicsHandler.getCurrentLayerIndex());
                    descriptionTextArea.setText(screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().getDescription());
                    for (int i = 0 ; i < screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().listPresentationStateObject.size(); i++)
                    {
                        annotationInLayerList.add(((PresentationStateLayerObject) screenImageHandler.presentationStateGraphicsHandler.getCurrentLayer().listPresentationStateObject.elementAt(i)).getListText());
                        
                    }
                    for (int i = 0; i < screenImageHandler.presentationStateGraphicsHandler.ps.getNumberOfActiveOverlays(screenImageHandler.presentationStateGraphicsHandler.getCurrentLayerIndex()); i++)
                    {
                        annotationInLayerList.add(screenImageHandler.presentationStateGraphicsHandler.overlayList.getListText(screenImageHandler.presentationStateGraphicsHandler.getCurrentLayerIndex(),i));
                    }
                }
                else
                {
                    layerNameChoice.select(listGraphicLayer.size());
                    descriptionTextArea.setText("deactivate overlays");
                    
                    for (int i = 0; i < screenImageHandler.presentationStateGraphicsHandler.ps.getNumberOfOverlaysInImage(); i++)
                    {
                        if (screenImageHandler.presentationStateGraphicsHandler.ps.getOverlayInImageActivationLayer(i) == -1)
                            annotationInLayerList.add(screenImageHandler.presentationStateGraphicsHandler.overlayList.getImageListText(i));
                        
                    }
                    for (int i = 0; i < screenImageHandler.presentationStateGraphicsHandler.ps.getNumberOfOverlaysInPresentationState(); i++)
                    {
                        if (screenImageHandler.presentationStateGraphicsHandler.ps.getOverlayInPresentationStateActivationLayer(i) == -1)
                            annotationInLayerList.add(screenImageHandler.presentationStateGraphicsHandler.overlayList.getPresentationStateListText(i));
                        
                    }
                    
                }
            }
            annotationInLayerList.select(screenImageHandler.presentationStateGraphicsHandler.getCurrentLayerObjectIndex());
        } 
            
        else this.setEnabled(false);
    }
    
}

/*
 *  CVS Log
 *  $Log: LayerPanel.java,v $
 *  Revision 1.2  1999/05/17 08:10:20  Schroeter
 *  Correction of some bad log tags
 *
*/ 