/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:11 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package Viewer.GUI;

import java.awt.*;
import java.awt.image.*;

import Viewer.Main.*;
import Viewer.Presentation.*;
import Viewer.Controller.*;
import Main.*;
import jToolkit.Gui.*;

/**
* This class contains the main panel of the image viewer. All other 
* components are integrated in this panel.
* 
* @author Klaus Kleber
* @since 30.04.1999
*/
public class MainImageViewerPanel extends java.awt.Panel
{

    /**
     * Contains a panel for creating Annotations.
     *
     * @since 30.04.1999
     */
    public AnnotationPanel annotationPanel;

	/**
	 * @since 30.04.1999
	 */
	public ScreenImageHandler screenImageHandler;

    /**
     * Contains the image viewer.
     *
     * @since 30.04.1999
     */
    PanelScrollImage panelScrollImage;

    /**
     * Contains the function tabs.
     *
     * @since 30.04.1999
     */
    public FunktionBasisTabPanel funktionBasisTabPanel;

    /**
     * Contains the parentFrame of this Panel
     * 
     * @since 30.04.1999
     */
    public Frame parentFrame;

    /**
     * Contains a status bar form an other Widget.
     * 
     * @since 30.04.1999
     */
    public Statusline sl;
    
    /**
     * Constructs a new object.
     * 
     * @param presentationStateGraphicsHandler Contains the current PresentationStateGraphicsHandler.
     * @param parentFrame Contains the parent frame of this Panel
     * @param sl Contains reference of a status bar
     * @since 30.04.1999
     */
    public  MainImageViewerPanel(PresentationStateGraphicsHandler presentationStateGraphicsHandler,Frame parentFrame, Statusline sl)
    {
         super();
         
           this.sl = sl;
		   this.parentFrame = parentFrame;
		   
		   //Init screenImageHandler
		   screenImageHandler = new ScreenImageHandler(this,presentationStateGraphicsHandler);
		   setBackground(Color.lightGray);
		   setLayout(new BorderLayout(5,5));
           setFont(MainContext.instance().getUsedFont());
	       
	       //Init PanelScollImage
	       panelScrollImage = new PanelScrollImage(screenImageHandler);
           add("Center",panelScrollImage);

		   //Init AnnotationPanel
		   annotationPanel = new AnnotationPanel(screenImageHandler);
		   add("South", annotationPanel);
           
           //Init FunctionBasisTabPanel
           funktionBasisTabPanel = new FunktionBasisTabPanel(screenImageHandler);
           if (MainContext.instance().highQualitySystem)
           {
                Panel eastPanel = new Panel(new GridLayout(2,1));
                eastPanel.add(new Label(" "));
                eastPanel.add(funktionBasisTabPanel);
                add("East", eastPanel);
           } else add("East", funktionBasisTabPanel);
           
           setEnabled(false); 
    
    }

    /**
     * Updates the content off all widgets in this panel.
     * 
     * @since 30.04.1999
     */
    public void setValue()
    {
        funktionBasisTabPanel.setValue();
        annotationPanel.setValue();
    }

    /**
     * Returns the ImageCanvas which contains the GUI of the image.
     * 
     * @return The imageCanvas which contains the image
     * @since 30.04.1999
     */
    public ImageCanvas getImageCanvas()
    {
        return panelScrollImage.imageBig;
    }
    
    /**
     * Returns the PanelScrollImage
     * 
     * @return PanelScrollImage.
     * @since 30.04.1999
     */
    public PanelScrollImage getPanelScrollImage()
    {
        return panelScrollImage;
    }

}

/*
 *  CVS Log
 *  $Log: MainImageViewerPanel.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/
