/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:11 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/
package Viewer.GUI;

import Viewer.Main.*;
import Viewer.Controller.*;
import Viewer.Presentation.*;
import Main.MainContext;
import jToolkit.Gui.*;

import java.awt.*;
import java.beans.*;


/**
 * This class contains the image viewer. It can show the image and 
 * supports scrollbars for scrolling in the image.
 * 
 * @author Klaus Kleber
 * @since 30.04.1999
 */

public class PanelScrollImage extends java.awt.Panel
{

    /**
     * Canvas which shows the image
     * 
     * @since 30.04.1999
     */
    //Canvas, das das Bild anzeigt
    ImageCanvas imageBig;

	/**
	 * Scrollbar width.
	 * 
	 * @since 30.04.1999
	 */
	CommandAWTScrollbar widthScrollbar;

	/**
	 * Scroolbar height.
	 * 
	 * @since 30.04.1999
	 */
	CommandAWTScrollbar heightScrollbar;

	/**
	 * Contains the current ScreenImageHandler.
	 * 
     * @param screenImageHandler Contains the current ScreenImageHandler.
	 * @since 30.04.1999
	 */
	public PanelScrollImage(ScreenImageHandler screenImageHandler)
	{
		super();		
		CommandImageScrollbarHandler imageScrollBarHandler = new CommandImageScrollbarHandler(screenImageHandler);
		
		
		setLayout(new BorderLayout());
		setBackground(Color.black);
	    imageBig = new ImageCanvas(screenImageHandler);
	    add("Center", imageBig);
	    
	    
	    widthScrollbar = new CommandAWTScrollbar(Scrollbar.HORIZONTAL,0,0,0,0, imageScrollBarHandler, 0);
	    widthScrollbar.setName("widthScrollbar");
	    heightScrollbar = new CommandAWTScrollbar(Scrollbar.VERTICAL,0,0,0,0, imageScrollBarHandler, 1);
	    add("East", heightScrollbar);
	    add("South", widthScrollbar);	    
	    
	    
		if (MainContext.instance().highQualitySystem)
		{
	        widthScrollbar.setEventOnlyOnMouseRelease (true);
	        heightScrollbar.setEventOnlyOnMouseRelease (true);
	    }
	    
	}

    /**
     * Sets maxium and values of the scrollbars
     * 
     * @param width Contains the width of the image and therefore the maximum horizontal scroll value.
     * @param height Contains the width of the image and therefore the maximum vertical scroll value.
     * @param values Contains the values of the scollbars.
     * @since 30.04.1999
     */
    public void setNewScrollbarValues(int width,int height, Point values)
    {
        widthScrollbar.setMaximum(width);
        heightScrollbar.setMaximum(height);
        widthScrollbar.setValue(values.x);
        heightScrollbar.setValue(values.y);
    }
}

/*
 *  CVS Log
 *  $Log: PanelScrollImage.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/
