/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:11 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package Viewer.GUI;

import Viewer.Main.*;
import Viewer.Controller.*;

import Main.*;
import java.awt.*;
import java.awt.event.*;

/**
 * This class contains a GUI component with a Scollbar and a TextField
 * containing the value of the Scollbar.
 * The PanelSlider and the interface is not
 * designed well but it works. 
 * 
 * @author Klaus Kleber
 * @since 30.04.1999
 * @see Controller.SliderPanelListener
 */
public class PanelSlider extends java.awt.Panel
{
    /**
    * Contains the label of the component
    * 
    * @since 30.04.1999
    */
    Label nameLabel;
    
    /**
    * Contains the TextField of the component.
    * 
    * @since 30.04.1999
    */
    TextField valueTextField;
    
    /**
    * Contains the Scrollbar of the component
    * 
    * @since 30.04.1999
    */
    public Scrollbar valueScrollbar;
    
    
    /**
    * Handles the Events
    * 
    * @since 30.04.1999
    */
    SliderPanelListener sliderPanelListener;
    
    /**
    * Constructs a new object.
    * 
    * @param sliderPanelListener Handles the Events.
    * @param name Text for the label.
    * @param colums Not used yet
    * @param orientation Orietation of the Scrollbar.
    * @param blockIncrement Block increment of the Scroolbar
    * @param min Minimum value of the Scrollbar.
    * @param max Maximum value of the Scrollbar.
    * @since 30.04.1999
    */
    public PanelSlider (SliderPanelListener sliderPanelListener,
                        String name ,
                        int columns,
                        int orientation, 
                        int blockIncrement,
                        int min, 
                        int max )
    {
        super();
        this.sliderPanelListener = sliderPanelListener;
        if (sliderPanelListener != null) this.sliderPanelListener.setPanelSlider(this);
        nameLabel = new Label(name);
        nameLabel.setAlignment(1);
        
        valueTextField = new TextField();
		valueTextField.setEditable(true);
        valueTextField.setName(name + "TextField");
		valueTextField.addActionListener(sliderPanelListener);
		valueTextField.addFocusListener(sliderPanelListener);
        valueScrollbar = new Scrollbar(orientation,0,0, min,max);
        valueScrollbar.setBlockIncrement(blockIncrement);
        valueScrollbar.setName(name + "Scrollbar");
        
        valueScrollbar.addAdjustmentListener(sliderPanelListener);
        valueTextField.setText(String.valueOf(valueScrollbar.getValue()));
        
        setLayout(new BorderLayout());
        add("North",nameLabel);
        Panel scrollPanelGrid = new Panel();
        scrollPanelGrid.setLayout(new GridLayout(1,3));
        scrollPanelGrid.add(new Panel());
        scrollPanelGrid.add(valueScrollbar);
        scrollPanelGrid.add(new Panel());
        
        add("Center",scrollPanelGrid);
        add("South",valueTextField);
    
    }
    
    
    /**
    * Returns the value of the Scrollbar.
    * 
    * @return The value of the Scrollbar
    * @since 30.04.1999
    */
    public int getValue()
    {
        return valueScrollbar.getValue();
    }
        
    
    
    /**
    * Sets a new value for the TextField.
    * 
    * @param text The  new value for the TextField.
    * @since 30.04.1999
    */
    public void setText(String text)
    {
        valueTextField.setText(text);
        
    }
    
    
    /**
    * Sets a new value for the Scrollbar
    * 
    * @param newValue The  new value for the Scrollbar.
    * @since 30.04.1999
    */
    public void setScrollbarValue(int newValue)
    {
        valueScrollbar.setValue(newValue);
    }
    
    /**
    * Sets a new value for the Scrollbar and insert the value in the 
    * TextField
    * 
    * @param newValue The new value for the Scrollbar and TextField.
    * @since 30.04.1999
    */
    public void setNewValue(int newValue)
    {
        valueScrollbar.setValue(newValue);
        valueTextField.setText((new Integer(newValue)).toString());
    }
    
    
    /**
    * Sets a new value for the Scrollbar and insert the value in the 
    * TextField
    * 
    * @param newValue The new value for the Scrollbar and TextField.
    * @since 30.04.1999
    */
    public void setNewValue(double newValue)
    {
        valueScrollbar.setValue((int)(newValue));
        valueTextField.setText((new Double(valueScrollbar.getValue()).toString()));
    }
    
    
    /**
    * Sets a new rounded value for the Scrollbar 
    * and insert the value in the TextField
    * 
    * @param newValue The new value for the Scrollbar and TextField.
    * @since 30.04.1999
    */
    public void setNewValue100(double newValue)
    {
        valueScrollbar.setValue((int)(newValue*100));
        valueTextField.setText((new Double(valueScrollbar.getValue()/100d).toString()));
    }
    
    /**
    * Sets a minimum and maximum values for the Scrollbar
    * 
    * @param min Minimum value of the Scrollbar.
    * @param max Maximum value of the Scrollbar.
    * @since 30.04.1999
    */
    
    public void setMinMax(int min, int max)
    {
        if (!(valueScrollbar.getMinimum() == min))
        {
            valueScrollbar.setMinimum(min);
        }
        if (!(valueScrollbar.getMaximum() == max))
        {
            valueScrollbar.setMaximum(max);
        }
}   
}
/*
 *  CVS Log
 *  $Log: PanelSlider.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/
