/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/17 08:10:21 $
 *  Revision :    $Revision: 1.3 $
 *  State:        $State: Exp $
*/

package Viewer.GUI;
import Main.*;
import Viewer.Main.*;
import Viewer.Presentation.*;
import Viewer.Controller.*;
import J2Ci.*;

import java.awt.*;

/**
 * Contains the GUI for some functionalities and informations of 
 * a presentation state.
 * 
 * @author Klaus Kleber
 * @since 30.04.1999
 * @see Controller.PresentationStateActionHandler
 */

public class PresentationStatePanel extends java.awt.Panel
{

	/**
	 * Contains the current ScreenImageHandler
	 * 
	 * @since 30.04.1999
	 */
	ScreenImageHandler screenImageHandler;

	/**
	 * Contains the label of the presentation state.
	 * 
	 * @since 30.04.1999
	 */
	TextField labelTextField;

	/**
	 * Contains the creators name of the presentation state.
	 * 
	 * @since 30.04.1999
	 */
	TextField creatorsNameTextField;

	/**
	 * Contains the description of the presentation state
	 * 
	 * @since 30.04.1999
	 */
	TextArea descriptionTextArea;

	/**
	 * Contains the value for the ambient light.
	 * 
	 * @since 30.04.1999
	 */
	
	TextField ambientLightTextField;

	/**
	 * Resets the presentation state as its last saved status.
	 * 
	 * @since 30.04.1999
	 */
	Button resetButton;

	/**
	 * Saves the presentation state in the database
	 * 
	 * @since 30.04.1999
	 */
	Button saveButton;

	/**
	 * Saves the presentation state in a seperate file
	 * 
	 * @since 30.04.1999
	 */
	Button saveFileButton;

	/**
	 * Saves the current screen as Dicom file.
	 *
	 * @since 30.04.1999
	 */
	Button saveScrShotButton;

	/**
	 * Sets the calibration of the color monitor on/off.
	 * 
	 * @since 30.04.1999
	 */
	Button bartenButton;

	/**
	 * Sets the presentation state on/off
	 * 
	 * @since 30.04.1999
	 */
	Button prsButton;

    /**
     * Contains some information about the presentation state
     * 
     * @since 30.04.1999
     */
    TextArea infoTextArea;

    /**
     * Builbs the Panel and adds the Listeners to the widgets
     * 
     * @param screenImageHandler Contains the current ScreenImageHandler
     */
    
    public  PresentationStatePanel(ScreenImageHandler screenImageHandler)
    {
        super();
        this.screenImageHandler = screenImageHandler;
        PresentationStatePanelEventController presentationStatePanelEventController = new PresentationStatePanelEventController(screenImageHandler,this);
        setLayout(new BorderLayout());
        Panel topPanel = new Panel();
        topPanel.setLayout(new BorderLayout());
        
        
        Panel psPanel = new Panel();
        if (screenImageHandler.presentationStateGraphicsHandler.dvi.isBartenTransformPossible()) psPanel.setLayout(new GridLayout(8,1));
        else psPanel.setLayout(new GridLayout(7,1));
        
        Panel buttonPanel1 = new Panel();
        Panel buttonPanel2 = new Panel();
        
        //Init saveButton
        saveButton = new Button("save");
        saveButton.setName("save");
        saveButton.addActionListener(presentationStatePanelEventController);
        buttonPanel1.add(saveButton);
        
        //Init saveFileButton
        saveFileButton = new Button("save as file...");
        saveFileButton.setName("savefile");
        saveFileButton.addActionListener(presentationStatePanelEventController);
        buttonPanel1.add(saveFileButton);
        
        //Init saveScrShotButton
        saveScrShotButton = new Button("save screen");
        saveScrShotButton.setName("savescreen");
        saveScrShotButton.addActionListener(presentationStatePanelEventController);
        buttonPanel1.add(saveScrShotButton);
        
        //Init reset Button
        resetButton = new Button("reset");
        resetButton.setName("reset");
        resetButton.addActionListener(presentationStatePanelEventController);
        buttonPanel2.add(resetButton);
        
        //Init bartenButton 
        bartenButton = new Button("set Barten off");
        bartenButton.setName("bartenOnOff");
        bartenButton.addActionListener(presentationStatePanelEventController);
        if (screenImageHandler.presentationStateGraphicsHandler.dvi.isBartenTransformPossible()) buttonPanel2.add(bartenButton);
        //if (!MainContext.instance().highQualitySystem) buttonPanel2.add(bartenButton);
        
        //Init prsButton 
        prsButton = new Button("set PS on");
        prsButton.setName("psOnOff");
        prsButton.addActionListener(presentationStatePanelEventController);
        buttonPanel2.add(prsButton);
               
        
        psPanel.add(buttonPanel1);
        psPanel.add(buttonPanel2);
        
        //Init ambientLightTextField 
        Panel ambientLightPanel = new Panel();
        ambientLightPanel.add (new Label ("Ambient Light "));
        ambientLightTextField = new TextField(4);
        ambientLightTextField.setText(new String("0.0"));
        ambientLightTextField.setName("ambientlight");        
        ambientLightTextField.addFocusListener(presentationStatePanelEventController);
        ambientLightTextField.addActionListener(presentationStatePanelEventController);
        ambientLightPanel.add (ambientLightTextField);
        ambientLightPanel.add (new Label (" "));
        
        jDoubleByRef al = new jDoubleByRef();
        int status = screenImageHandler.presentationStateGraphicsHandler.dvi.getAmbientLightValue(al);        
        ambientLightTextField.setText (al.value+"");
        
        
        if (screenImageHandler.presentationStateGraphicsHandler.dvi.isBartenTransformPossible()) psPanel.add (ambientLightPanel);
        
        
        psPanel.add(new Label("Label"));
        labelTextField = new TextField(16);
		labelTextField.addFocusListener(presentationStatePanelEventController);
        labelTextField.setName("label");
        
        psPanel.add(labelTextField);
        
        psPanel.add(new Label("Creators Name"));
        
        creatorsNameTextField = new TextField(30);
		creatorsNameTextField.addFocusListener(presentationStatePanelEventController);
        creatorsNameTextField.setName("creator");
        psPanel.add(creatorsNameTextField);
        
        psPanel.add(new Label("Description"));
        
        topPanel.add("North", psPanel);
        
        descriptionTextArea = new TextArea("",3,30,TextArea.SCROLLBARS_VERTICAL_ONLY);
		descriptionTextArea.addFocusListener(presentationStatePanelEventController);
        topPanel.add("South", descriptionTextArea);
        
        add("North", topPanel);
        
        Panel infoPanel = new Panel();
        infoPanel.setLayout(new BorderLayout());
        infoPanel.add("North", new Label("Infos"));
        
        infoTextArea = new TextArea(20,30);
        infoTextArea.setEditable(false);
        infoPanel.add("Center", infoTextArea);
        
        add("Center", infoPanel);
        
        
    }


    /**
     * Updates the widgets of the Panel
     * 
     * @since 30.04.1999
     */
    public void setValue()
    {
        
        //update bartenButton
        if (screenImageHandler.presentationStateGraphicsHandler.ps.getBartenTransform())bartenButton.setLabel("set Barten off");
        else bartenButton.setLabel("set Barten on");
        
        //update prsButton
        if (screenImageHandler.presentationStateGraphicsHandler.enablePresentationState) prsButton.setLabel ("set PS off");
        else prsButton.setLabel ("set PS on");
        
        //update ambientLightTextField
        jDoubleByRef al = new jDoubleByRef();
        int status = screenImageHandler.presentationStateGraphicsHandler.dvi.getAmbientLightValue(al);        
        ambientLightTextField.setText (al.value+"");
        
        //update TextFields
        labelTextField.setText(screenImageHandler.presentationStateGraphicsHandler.ps.getPresentationLabel());
        creatorsNameTextField.setText(screenImageHandler.presentationStateGraphicsHandler.ps.getPresentationCreatorsName());
        descriptionTextArea.setText(screenImageHandler.presentationStateGraphicsHandler.ps.getPresentationDescription());
        
        
        infoTextArea.setText("PresState: " + "\n" +
                             "   Rotation: " + (screenImageHandler.presentationStateGraphicsHandler.ps.getRotation()*90) +"\n" +
                             "   Flip: " + screenImageHandler.presentationStateGraphicsHandler.ps.getFlip()+"\n" +
                             "   TLHC: x = " +screenImageHandler.presentationStateGraphicsHandler.ps.getDisplayedAreaTLHC_x()  +", y = "+ screenImageHandler.presentationStateGraphicsHandler.ps.getDisplayedAreaTLHC_y() + "\n" +
                             "   BRHC: x = " +screenImageHandler.presentationStateGraphicsHandler.ps.getDisplayedAreaBRHC_x()  +", y = "+ screenImageHandler.presentationStateGraphicsHandler.ps.getDisplayedAreaBRHC_y() + "\n" +
                             "Image: " + "\n" +
                             "   Rows:  " + screenImageHandler.presentationStateGraphicsHandler.getImageWidth() + ", cols: " + screenImageHandler.presentationStateGraphicsHandler.getImageHeight()+ "\n"+
                             "   Pixel Aspect Ratio: " +  screenImageHandler.presentationStateGraphicsHandler.getPixelAspectRatio()+ " (cols/rows)");
    }
}




/*
 *  CVS Log
 *  $Log: PresentationStatePanel.java,v $
 *  Revision 1.3  1999/05/17 08:10:21  Schroeter
 *  Correction of some bad log tags
 *
 *  Revision 1.2  1999/05/14 10:02:35  Schroeter
 *  Log-Tags for CVS corrected
 *
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/
