/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/17 08:10:21 $
 *  Revision :    $Revision: 1.3 $
 *  State:        $State: Exp $
*/

package Viewer.GUI;

import Viewer.Controller.*;
import Viewer.Main.*;
import Viewer.Presentation.*;

import java.awt.*;

/**
 * This class contains the functions for creating and deleting vector shutters
 * and activating and deactivation bitmapped shutters.
 * 
 * @author Klaus Kleber
 * @since 30.04.1999
 */
public class ShutterPanel extends java.awt.Panel
{

	/**
	 * Button for deleting a circular shutter
	 * 
	 * @since 30.04.1999
	 */
	Button deleteCircleButton;

	/**
	 * Button for creating a new circular shutter
	 * 
	 * @since 30.04.1999
	 */
	Button newCircleButton;

	/**
	 * Button for deleting a rectangular shutter
	 * 
	 * @since 30.04.1999
	 */
	Button deleteRectangleButton;

	/**
	 * Button for creating a new rectangular shutter.
	 * 
	 * @since 30.04.1999
	 */
	Button newRectangleButton;

	/**
	 * Button for deleting a poygonal shutter
	 * 
	 * @since 30.04.1999
	 */
	Button deletePolylineButton;

	/**
	 * Button for creating a new polygonal shutter.
	 * 
	 * @since 30.04.1999
	 */
	Button newPolylineButton;

	/**
	 * @since 30.04.1999
	 */
	Checkbox circleShutterCheckbox;

	/**
	 * @since 30.04.1999
	 */
	Checkbox polylineShutterCheckbox;

	/**
	 * @since 30.04.1999
	 */
	Checkbox rectangleShutterCheckbox;

	/**
	 * Choice which contains all overlays which are suitable as bitmapped shutters.
	 * 
	 * @since 30.04.1999
	 */
	Choice bitmapShutterChoice;

	/**
	 * Contains the shutter presentation value. This value is transformed in 
	 * a value between 0 by 1.
	 * 
	 * @since 30.04.1999
	 */
	TextField shutterPVTextField;

	/**
	 * Contains the current ScreenImageHandler
	 * 
	 * @since 30.04.1999
	 */
	ScreenImageHandler screenImageHandler;

	/**
	 * Builds the GUI and adds the Listeners
	 * 
	 * @param screenImageHandler Contains the current ScreenImageHandler.
	 * @since 30.04.1999
	 */
	public ShutterPanel(ScreenImageHandler screenImageHandler)
	{
        super();
        this.screenImageHandler = screenImageHandler;
        setLayout(new BorderLayout());
        ShutterPanelEventController shutterPanelEventController = new ShutterPanelEventController(screenImageHandler,this);
        
        Panel topPanel = new Panel(new GridLayout(7,1));
	    
	    
	    topPanel.add(new Label("Vector"));	    
	    Panel rectanglePanel = new Panel(new GridLayout(1,3));
	    rectanglePanel.add(new Label(""));
	    
	    //init rectangle
	    rectangleShutterCheckbox = new Checkbox("rectangle", false);
	    rectangleShutterCheckbox.addItemListener(shutterPanelEventController);
	    rectanglePanel.add(rectangleShutterCheckbox);
	    Panel rectangleButtonPanel = new Panel(new GridLayout(1,2));
	    newRectangleButton = new Button("new");
	    newRectangleButton.addActionListener(shutterPanelEventController);
	    newRectangleButton.setName("newRectangle");
	    rectangleButtonPanel.add(newRectangleButton);
	    deleteRectangleButton = new Button("del");
	    deleteRectangleButton.setName("delRectangle");
	    deleteRectangleButton.addActionListener(shutterPanelEventController);
	    rectangleButtonPanel.add(deleteRectangleButton);
	    rectanglePanel.add(rectangleButtonPanel);
	    topPanel.add(rectanglePanel);

	    //Init cicle
	    Panel circlePanel = new Panel(new GridLayout(1,3));
	    circlePanel.add(new Label(""));
	    circleShutterCheckbox = new Checkbox("circle", false);
	    circleShutterCheckbox.addItemListener(shutterPanelEventController);
	    circlePanel.add(circleShutterCheckbox);
	    Panel circleButtonPanel = new Panel(new GridLayout(1,2));
	    newCircleButton = new Button("new");
	    newCircleButton.addActionListener(shutterPanelEventController);
	    newCircleButton.setName("newCircle");
	    circleButtonPanel.add(newCircleButton);
	    deleteCircleButton = new Button("del");
	    deleteCircleButton.setName("delCircle");
	    deleteCircleButton.addActionListener(shutterPanelEventController);
	    circleButtonPanel.add(deleteCircleButton);
	    circlePanel.add(circleButtonPanel);
	    topPanel.add(circlePanel);
	    
	    //Init polyline
	    Panel polylinePanel = new Panel(new GridLayout(1,3));
	    polylinePanel.add(new Label(""));
	    polylineShutterCheckbox = new Checkbox("polygon", false);
	    polylineShutterCheckbox.addItemListener(shutterPanelEventController);
	    polylinePanel.add(polylineShutterCheckbox);
	    Panel polylineButtonPanel = new Panel(new GridLayout(1,2));
	    newPolylineButton = new Button("new");
	    newPolylineButton.setName("newPolyline");
	    newPolylineButton.addActionListener(shutterPanelEventController);
	    polylineButtonPanel.add(newPolylineButton);
	    deletePolylineButton = new Button("del");
	    deletePolylineButton.setName("delPolyline");
	    deletePolylineButton.addActionListener(shutterPanelEventController);
	    polylineButtonPanel.add(deletePolylineButton);
	    polylinePanel.add(polylineButtonPanel);
	    topPanel.add(polylinePanel);
	    
	    
	    //Init bitmapp
	    topPanel.add(new Label("Bitmap"));	    
	    bitmapShutterChoice = new Choice();
	    bitmapShutterChoice.addItemListener(shutterPanelEventController);
	    topPanel.add(bitmapShutterChoice);
	    add("North", topPanel);
        Panel shutterPVPanel = new Panel(new FlowLayout(FlowLayout.LEFT));
        shutterPVPanel.setLayout(new FlowLayout());
        shutterPVPanel.add( new Label("gray-value 0.0 .. 1.0 "));
        shutterPVTextField = new TextField(4);
        shutterPVTextField.addFocusListener(shutterPanelEventController);
        shutterPVTextField.addActionListener(shutterPanelEventController);
        shutterPVPanel.add(shutterPVTextField);
        topPanel.add(shutterPVPanel);
	    
	}

    /**
     * Updates the widgets on the panel.
     * 
     * @since 30.04.1999
     */
    public void setValue()
    {
        ShutterList shutterList = screenImageHandler.presentationStateGraphicsHandler.shutterList;
        if (shutterList.haveRectangularShutter())
        {
            rectangleShutterCheckbox.setState(true);
            newRectangleButton.setEnabled(false);
            deleteRectangleButton.setEnabled(true);
            
        }
        else
        {
            rectangleShutterCheckbox.setState(false);
            newRectangleButton.setEnabled(true);
            deleteRectangleButton.setEnabled(false);
        }
        
        if (shutterList.haveCircularShutter())
        {
            circleShutterCheckbox.setState(true);
            newCircleButton.setEnabled(false);
            deleteCircleButton.setEnabled(true);
            
        }
        else
        {
            circleShutterCheckbox.setState(false);
            newCircleButton.setEnabled(true);
            deleteCircleButton.setEnabled(false);
        }
        if (shutterList.havePolygonalShutter())
        {
            polylineShutterCheckbox.setState(true);
            newPolylineButton.setEnabled(false);
            deletePolylineButton.setEnabled(true);
            
        }
        else
        {
            polylineShutterCheckbox.setState(false);
            newPolylineButton.setEnabled(true);
            deletePolylineButton.setEnabled(false);
        }
        bitmapShutterChoice.removeAll();
        bitmapShutterChoice.setEnabled(true); 
        
        if (shutterList.numberOfSuitableBitmapShutter ==0)
        {
            bitmapShutterChoice.add(new String("no bitmap available")); 
            bitmapShutterChoice.select(0);
            bitmapShutterChoice.setEnabled(false); 
        }
        else
        {
           bitmapShutterChoice.add(new String("no bitmap available")); 
           for (int i = 0; i <  shutterList.numberOfSuitableBitmapShutter; i++)
           {
               bitmapShutterChoice.add(shutterList.overlayIsShutterLabelList[i]); 
           }
        }
        if (shutterList.haveBitmapShutter())
        {
            bitmapShutterChoice.select(shutterList.activeBitmapShutterIndex+1);
            
        }
        else bitmapShutterChoice.select(0);
    
    
        shutterPVTextField.setText(new Float(shutterList.getShutterColorValue()).toString());
        
    }
}




/*
 *  CVS Log
 *  $Log: ShutterPanel.java,v $
 *  Revision 1.3  1999/05/17 08:10:21  Schroeter
 *  Correction of some bad log tags
 *
 *  Revision 1.2  1999/05/14 10:02:36  Schroeter
 *  Log-Tags for CVS corrected
 *
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/
