/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:11 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package Viewer.GUI;

import Viewer.Presentation.*;
import Viewer.Controller.*;
import Viewer.Main.*;
import Main.*;

import java.awt.*;

/**
 * This class contains the widgets for creating a new PresentationStateTextObject
 * instance.
 * 
 * @author Klaus Kleber
 * @since 30.04.1999
 */

public class TextDialog extends Dialog
{



	/**
	 * Contains the text of the PresentationStateTextObject.
	 * 
	 * @since 30.04.1999
	 */
	public TextField nameTextField;

	/**
	 * Checkbox for a new bounding box.
	 * 
	 * @since 30.04.1999
	 */
	public Checkbox isBoundingCheckbox;

	/**
	 * Checkbox for an new anchor point.
	 * 
	 * @since 30.04.1999
	 */
	public Checkbox isAnchorCheckbox;

	/**
	 * Checkbox for a new anchor point and a new bounding box.
	 * 
	 * @since 30.04.1999
	 */
	public Checkbox isBothCheckbox;

	/**
	 * Checkbox for image/display relative anchor point.
	 * 
	 * @since 30.04.1999
	 */
	public Checkbox isAnchorDisplayRelativeCheckbox;

	/**
	 * Checkbox for visible/unvisible anchorpoint.
	 * 
	 * @since 30.04.1999
	 */
	public Checkbox isAnchorVisibleCheckbox;

	/**
	 * Checkbox for image/display relative bounding box.
	 * 
	 * @since 30.04.1999
	 */
	public Checkbox isBoxDisplayRelativeCheckbox;
	

	/**
	 * Construct a new Object.
	 * 
	 * @param parent Contains the parent of this Dialog
	 * @param title Contains the title of this Dialog.
	 * @param modal true, if dialog should be modal.
	 * @param screenImageHandler Contains the current ScreenImageHandler
	 * @since 30.04.1999
	 */
	public TextDialog(Frame parent, String title, boolean modal,ScreenImageHandler screenImageHandler)
	{
		super(parent);
	    
	    Button okButton;
	    Button cancelButton;
        CheckboxGroup initCheckboxGroup; 
        
		setTitle(title);
        setModal(modal);
        setFont(MainContext.instance().getUsedFont());
        
        setSize(300*MainContext.instance().getSizeFactor(),300*MainContext.instance().getSizeFactor());
        TextDialogEventController textDialogEventController = new TextDialogEventController(screenImageHandler,this);
        
		setBackground(new Color(12632256));
        setLayout(new BorderLayout(10,10));
        
        Panel topPanel = new Panel(new GridLayout(11,1));
        
        topPanel.add(new Label(""));
        
        //Init NameTextField
        nameTextField = new TextField();
        topPanel.add(nameTextField);
        
        topPanel.add(new Label(""));
        
        //initCheckboxGroup
        initCheckboxGroup = new CheckboxGroup();
        
        //Init isBoundingCheckbox
        isBoundingCheckbox = new Checkbox("Bounding Box", initCheckboxGroup, true);
        topPanel.add(isBoundingCheckbox);
        
        //Init isAnchorCheckbox
        isAnchorCheckbox = new Checkbox("Anchor Point", initCheckboxGroup, false);
        topPanel.add(isAnchorCheckbox);
        
        //Init isBothCheckbox
        isBothCheckbox = new Checkbox("Anchor Point and Bounding Box", initCheckboxGroup, false);
        topPanel.add(isBothCheckbox);
        topPanel.add(new Label(""));
        
        //Init isBoxDisplayRelativeCheckbox
        isBoxDisplayRelativeCheckbox = new Checkbox("display relative bounding box", false);
        topPanel.add(isBoxDisplayRelativeCheckbox);
        
        //Init isBoxDisplayRelativeCheckbox
        isAnchorDisplayRelativeCheckbox = new Checkbox("display relative anchor point", false);
        topPanel.add(isAnchorDisplayRelativeCheckbox);
        
        //Init isAnchorVisibleCheckbox
        isAnchorVisibleCheckbox = new Checkbox("anchor point visible", true);
        topPanel.add(isAnchorVisibleCheckbox);
        
        add("North", topPanel);
        
        
        //Init okButton
        Panel buttonPanel = new Panel();
        okButton = new Button("OK");
        okButton.addActionListener(textDialogEventController);
        okButton.setName("ok");
        buttonPanel.add(okButton);
        
        //Init cancelButton
        cancelButton = new Button("Cancel");
        cancelButton.addActionListener(textDialogEventController);
        cancelButton.setName("cancel");
        buttonPanel.add(cancelButton);
        
        add("South", buttonPanel);
        

		
		
		
		//{{REGISTER_LISTENERS
		SymWindow aSymWindow = new SymWindow();
		this.addWindowListener(aSymWindow);
		//}}
		
	}

	/**
	 * @since 30.04.1999
	 */
	
	public void addNotify()
	{
  	    // Record the size of the window prior to calling parents addNotify.
	    Dimension d = getSize();

		super.addNotify();

		if (fComponentsAdjusted)
			return;

		// Adjust components according to the insets
		Insets insets = getInsets();
		setSize(insets.left + insets.right + d.width, insets.top + insets.bottom + d.height);
		Component components[] = getComponents();
		for (int i = 0; i < components.length; i++)
		{
			Point p = components[i].getLocation();
			p.translate(insets.left, insets.top);
			components[i].setLocation(p);
		}
		fComponentsAdjusted = true;
	}

    // Used for addNotify check.
	boolean fComponentsAdjusted = false;



    /**
     * Shows or hides the component depending on the boolean flag b.
     * 
     * @param b if true, show the component
     * @since 30.04.1999
     * @see java.awt.Component#isVisible
     */
    public void setVisible(boolean b)
	{
		if(b)
		{
			Rectangle bounds = getParent().getBounds();
			Rectangle abounds = getBounds();
	
			setLocation(bounds.x + (bounds.width - abounds.width)/ 2,
				 bounds.y + (bounds.height - abounds.height)/2);
		}
		super.setVisible(b);
	}

	//{{DECLARE_CONTROLS
	//}}

	/**
	 * Handles the WindowEvents
	 * 
	 * @author Klaus Kleber
	 * @version 1.0
	 * @since 30.04.1999
	 */

	class SymWindow extends java.awt.event.WindowAdapter
	{
		public void windowClosing(java.awt.event.WindowEvent event)
		{
			Object object = event.getSource();
			if (object == TextDialog.this)
				Dialog1_WindowClosing(event);
		}
	}

	/**
	 * @param event
	 * @since 30.04.1999
	 */
	
	void Dialog1_WindowClosing(java.awt.event.WindowEvent event)
	{
		setVisible(false);
	}
}

/*
 *  CVS Log
 *  $Log: TextDialog.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/

