/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:11 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package Viewer.GUI;

import Viewer.Controller.*;
import Viewer.Presentation.*;
import Viewer.Main.*;
import Main.*;
import J2Ci.*;

import java.awt.*;

/**
 * This class contains the widgets for the function tab. There are 
 * functions for windowing, zooming, rotationd, flipping and inverting
 *  available.
 * 
 * @author Klaus Kleber
 * @since 30.04.1999
 */
public class WLTabPanel extends Panel
{

    /**
     * Contains the current ScreenImageHandler
     * 
     * @since 30.04.1999
     */
   
    ScreenImageHandler screenImageHandler;

    /**
     * Contains the standard windows.
     * 
     * @since 30.04.1999
     */
    Choice imageWindowChoise;


    /**
     * GUI component for width settings.
     * 
     * @since 30.04.1999
     */
    PanelSlider windowPanelSlider;

    /**
     * GUI component for center settings.
     * 
     * @since 30.04.1999
     */
    PanelSlider centerPanelSlider;

    /**
     * GUI Compontent for zooming
     * 
     * @since 30.04.1999
     */
    
    PanelSlider zoomPanelSlider;


    /**
     * Enables/disables the lut settings.
     * 
     * @since 30.04.1999
     */
    Checkbox lutCheckbox;

    /**
     * Enables/disables the window settings.
     * 
     * @since 30.04.1999
     */
    Checkbox winCheckbox;

    /**
     * Contains the available LUT.
     * 
     * @since 30.04.1999
     */
    Choice lutChoice;

    /**
     * GUI Components for inverting.
     * 
     * @since 30.04.1999
     */
    Button invertButton;

    /**
     * GUI Components for flipping.
     * 
     * @since 30.04.1999
     */
    Button flipButton;

    /**
     * GUI Component for 0 deg rotation.
     * 
     * @since 30.04.1999
     */
    
    Button left0Button;

    /**
     * GUI Component for 90 deg rotation.
     * 
     * @since 30.04.1999
     */
    Button left1Button;

    /**
     * GUI Component for 180 deg rotation.
     * 
     * @since 30.04.1999
     */
    Button left2Button;

    /**
     * GUI Component for 270 deg rotation.
     * 
     * @since 30.04.1999
     */
    Button left3Button;




    /**
     * Listener for the width settings.
     * 
     * @since 30.04.1999
     */
    WLTabPanelWidthEventController wLTabPanelWidthEventController;

    /**
     * Listener for the center settings.
     * 
     * @since 30.04.1999
     */
        WLTabPanelCenterEventController wLTabPanelCenterEventController;

    /**
     * Constructs a new object.
     * 
     * @param screenImageHandler Contains the current ScreenImageHandler.
     * @since 30.04.1999
     */
    public WLTabPanel( ScreenImageHandler screenImageHandler)
    {
        super();
        Panel buttonPanel;
        Panel sliderPanel;
        CheckboxGroup windowCheckboxGroup;
		
		
		this.screenImageHandler = screenImageHandler;
		WLTabPanelItemEventController wLTabPanelItemEventController =new WLTabPanelItemEventController(screenImageHandler,this);
		setLayout(new BorderLayout());
        Panel inPanel = new Panel();
		inPanel.setLayout(new BorderLayout());
		add("Center" ,inPanel);
		
		//Standard window GUI
        Panel standardWindowPanel;
		standardWindowPanel = new Panel();
		windowCheckboxGroup = new CheckboxGroup();
		
		standardWindowPanel.setLayout(new GridLayout(5,1));
		
		lutCheckbox = new Checkbox("activate VOI/LUT", windowCheckboxGroup, false);
        lutCheckbox.setName("lutCheckbox");
        lutCheckbox.addItemListener(wLTabPanelItemEventController);
		standardWindowPanel.add(lutCheckbox);
		
		lutChoice = new Choice();
        lutChoice.setName("lutChoice");
        lutChoice.addItemListener(wLTabPanelItemEventController);
		
		standardWindowPanel.add(lutChoice);
		
		standardWindowPanel.add(new Label(""));
		
		winCheckbox = new Checkbox("activate VOI/WIN", windowCheckboxGroup, true);
        winCheckbox.setName("winCheckbox");
        winCheckbox.addItemListener(wLTabPanelItemEventController);
		
		standardWindowPanel.add(winCheckbox);
		
        
        imageWindowChoise = new Choice();
        imageWindowChoise.setName("imageWindowChoise");
        imageWindowChoise.addItemListener(wLTabPanelItemEventController);
		
		
		standardWindowPanel.add(imageWindowChoise);
		inPanel.add("North",standardWindowPanel);
		
		
		
		//Windowing GUI
        sliderPanel = new Panel();
        sliderPanel.setLayout(new GridLayout(2,1));
        inPanel.add("Center",sliderPanel);
        
        Panel winLevelPanel= new Panel();
        winLevelPanel.setLayout(new GridLayout(1,2));
		wLTabPanelCenterEventController = new WLTabPanelCenterEventController(screenImageHandler);
		wLTabPanelWidthEventController = new WLTabPanelWidthEventController(screenImageHandler);
		windowPanelSlider = new PanelSlider(wLTabPanelWidthEventController,"Width",100,1,50,1,10000);
		centerPanelSlider = new PanelSlider(wLTabPanelCenterEventController,"Center",100,1,50,0,10000);
        centerPanelSlider.setScrollbarValue(0);
        winLevelPanel.add(centerPanelSlider);
        winLevelPanel.add(windowPanelSlider);
        sliderPanel.add(winLevelPanel);
        
        zoomPanelSlider = new PanelSlider(new WLTabPanelZoomEventController(screenImageHandler),"Zoom",1,1,10,10,1000);
        sliderPanel.add(zoomPanelSlider);
        
        
        WLTabPanelImageProcessEventController imageProcessListener = new WLTabPanelImageProcessEventController(screenImageHandler);
        invertButton = new Button("Invert");
        invertButton.setName("Invert");
        invertButton.addActionListener(imageProcessListener);
        
        
        flipButton = new Button("Flip");
        flipButton.setName("Flip");
        flipButton.addActionListener(imageProcessListener);
        
        left0Button = new Button("0-deg");
        left0Button.setName("left0");
        left0Button.addActionListener(imageProcessListener);
        
        left1Button = new Button("90-deg");
        left1Button.setName("left1");
        left1Button.addActionListener(imageProcessListener);
        left2Button = new Button("180-deg");
        left2Button.setName("left2");
        left2Button.addActionListener(imageProcessListener);
        
        
        
        left3Button = new Button("270-deg");
        left3Button.setName("left3");
        left3Button.addActionListener(imageProcessListener);
        
       
        buttonPanel = new Panel();
        buttonPanel.setLayout(new GridLayout(3,2));
        buttonPanel.add(invertButton);
        buttonPanel.add(flipButton);
        buttonPanel.add(left0Button);
        buttonPanel.add(left1Button);
        buttonPanel.add(left2Button);
        buttonPanel.add(left3Button);
        inPanel.add("South",buttonPanel);
        
        
    }

    /**
     * Updates the values of the Widgets.
     * 
     * @since 30.04.1999
     */
    public void setValue()
    {
        
        jDVPresentationState ps = screenImageHandler.presentationStateGraphicsHandler.ps;
        
        //sets the zoomvalue
        zoomPanelSlider.setNewValue((int)(screenImageHandler.presentationStateGraphicsHandler.getZoomValue()*100d));
        zoomPanelSlider.setText(Double.toString(Math.round(screenImageHandler.presentationStateGraphicsHandler.getZoomValue()*100d)/100d));
        
        //gets the maximum pixel range
        jDoubleByRef minRange = new jDoubleByRef();
        jDoubleByRef maxRange = new jDoubleByRef();
        ps.getImageMinMaxPixelRange(minRange, maxRange);
        int range =(int)( maxRange.value -minRange.value + 1);
        
        //Sets the values of the window center slider
        windowPanelSlider.setMinMax(1,2*range+1);
        wLTabPanelWidthEventController.setMinMax(1,2*range+1);
        centerPanelSlider.setMinMax((int)(-range+minRange.value),(int)( maxRange.value + range));
        wLTabPanelCenterEventController.setMinMax((int)(-range+minRange.value),(int)( maxRange.value + range));
        
        
        //removes the values of the choices
        imageWindowChoise.removeAll();
        lutChoice.removeAll();
        lutCheckbox.setEnabled(true);
        centerPanelSlider.setEnabled(true);
        windowPanelSlider.setEnabled(true);
        
        imageWindowChoise.setEnabled(true);
        lutChoice.setEnabled(true);
        winCheckbox.setState(true);
        
        //gets the pixel range
        jDoubleByRef minValue = new jDoubleByRef();
        jDoubleByRef maxValue = new jDoubleByRef();
        ps.getImageMinMaxPixelValue(minValue, maxValue);
        imageWindowChoise.add("auto: center= " + ((int)(minValue.value+(maxValue.value-minValue.value+1)/2)) +" width= " + ((int)(maxValue.value -minValue.value))  );
        
        for (int i = 0; i < ps.getNumberOfVOIWindowsInImage(); i++)
        {
            if (ps.getDescriptionOfVOIWindowsInImage(i)!= null) imageWindowChoise.add("VOI/WIN: " +ps.getDescriptionOfVOIWindowsInImage(i));
            else imageWindowChoise.add("VOI/WIN: " + i);
        }
        
        if (ps.haveActiveVOIWindow())
        {
            jDoubleByRef widthValue = new jDoubleByRef();
            ps.getCurrentWindowWidth(widthValue);
            windowPanelSlider.setNewValue(widthValue.value);
            lutChoice.setEnabled(false);
            jDoubleByRef centerValue = new jDoubleByRef();
            ps.getCurrentWindowCenter(centerValue);
            
            centerPanelSlider.setNewValue(centerValue.value);
        
        }
        else if (!ps.haveActiveVOILUT())
        {
            windowPanelSlider.setNewValue((maxValue.value-minValue.value+1));
            centerPanelSlider.setNewValue((minValue.value+(maxValue.value-minValue.value+1)/2));
            lutChoice.setEnabled(false);
            
            imageWindowChoise.select(0);
        }
        
        for (int i = 0; i < ps.getNumberOfVOILUTsInImage(); i++)
        {
            if (ps.getDescriptionOfVOILUTsInImage(i)!= null) lutChoice.add("VOI/LUT: " +ps.getDescriptionOfVOILUTsInImage(i));
            else lutChoice.add("VOI/LUT: " + i);
        }
        if (ps.haveActiveVOILUT())        
        {
            if (ps.getCurrentVOIDescription()!= null) lutChoice.add("active: " +ps.getCurrentVOIDescription());
            else lutChoice.add("active LUT");
            lutCheckbox.setState(true);
            centerPanelSlider.setEnabled(false);
            windowPanelSlider.setEnabled(false);
            
            imageWindowChoise.setEnabled(false);
            lutChoice.setEnabled(true);
            
            lutChoice.select(ps.getNumberOfVOILUTsInImage());
        }
        else if(ps.getNumberOfVOILUTsInImage()== 0) lutCheckbox.setEnabled(false);
        
        //Updates the buttons
        if ( ps.isInverse()) invertButton.setBackground(Color.gray);
        else invertButton.setBackground(Color.lightGray);
        if (ps.getFlip())flipButton.setBackground(Color.gray);
        else flipButton.setBackground(Color.lightGray);
        if (ps.getRotation() == 0)left0Button.setBackground(Color.gray);
        else left0Button.setBackground(Color.lightGray);
        if (ps.getRotation() == 1)left1Button.setBackground(Color.gray);
        else left1Button.setBackground(Color.lightGray);
        if (ps.getRotation() == 2)left2Button.setBackground(Color.gray);
        else left2Button.setBackground(Color.lightGray);
        if (ps.getRotation() == 3)left3Button.setBackground(Color.gray);
        else left3Button.setBackground(Color.lightGray);
    
    }
        
    
   
    
}

/*
 *  CVS Log
 *  $Log: WLTabPanel.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/
