/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:11 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/
package Viewer.Main;

import java.awt.event.*;
import java.awt.*;
import java.io.*;
import java.awt.image.*;
import java.awt.geom.*;

import Main.*;
import Viewer.GUI.*;
import Viewer.Presentation.*;
import jToolkit.Gui.*;

/**
 * This class contains is the interface for the image viewer of DICOMscope.
 * 
 * 
 * @author Klaus Kleber
 * @since 30.04.1999
 */
public class ViewInterface extends Object
{
    /**
    * Contains the main panel of the image viewer
    *
    * @since 30.04.1999
    */
    MainImageViewerPanel mainImageViewerPanel;


    /**
    * Constructs a new object
    * 
    * @param presentationStateGraphicsHandler Contains the current PresentationStateGraphicsHandler.
    * @param frame Contains the parent frame of the image viewer.
    * @param sl Contains a status bar in the parent frame.
    * @since 30.04.1999
    */
    public  ViewInterface(PresentationStateGraphicsHandler presentationStateGraphicsHandler, Frame frame, Statusline sl)
    {
        mainImageViewerPanel = new MainImageViewerPanel(presentationStateGraphicsHandler,frame, sl);
    }

    /**
    * Returns the main panel of the image viewer
    *
    * @return The main panel of the image viewer.
    * @since 30.04.1999
    */
    public  Panel getViewPanel()
    {
        return mainImageViewerPanel;
    }
            
    /**
    * Invoking the image viewer for reveiving a 
    * new presentation state in the c++ interface.
    *
    * @since 30.04.1999
    */
    public void setImage()
    {
        mainImageViewerPanel.screenImageHandler.setNewPresentationState();
        mainImageViewerPanel.setEnabled(true); 
       
    }
}

/*
 *  CVS Log
 *  $Log: ViewInterface.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/
