/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:11 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/
package Viewer.Paint;

import J2Ci.*;

import java.awt.*;
import java.util.*;
import java.awt.geom.*;

/**
 * This class contains methods for creating an interpolated polyline.
 * We use bezier curves to interpolate. This class is not ready yet. We have only 
 * implemented the needed functionality.
 * <br>
 * These objects can be display or image relative.
 *
 * @author Klaus Kleber
 * @since 30.04.1999
 * @see PaintObject
 */
public class InterpolatedObject extends PaintObject 
{
    /**
     * Contains the geometic form of the circle.
     * 
     * @since 30.04.1999
     */
    GeneralPath thisShape = null;
    
    
    GeneralPath helpShape = null;
    int countPoint = 0; 
    Point2D.Float firstPoint;
    Point2D.Float point1;
    Point2D.Float point2;
    
    /**
     * Constructs a new object.
     * 
     * @since 30.04.1999
     */
    public InterpolatedObject()
    {
        super();
        
    }
    
    /**
     * Constucts a new object with the specified parameter.
     * 
     * @param filled true if the object should be filled
     * @param isDisplayRelative true if the object should be display relative.
     * @param isShutter true if the object should be a shutter.
     * @since 30.04.1999
     */
    public InterpolatedObject(boolean filled, boolean isDisplayRelative,boolean isShutter)
    {
        super();
        this.filled = filled;
        this.isShutter = isShutter;
        this.isDisplayRelative = isDisplayRelative;
    }
    
        

    /**
     * Constucts a new object form the specified parameter
     * 
     * @param anInterpolatedObject Costructor copies the specified object.
     * @param isDisplayRelative true if the object should be display relative.
     * @param isShutter true if the object should be a shutter.
     * @since 30.04.1999
     */
    
    public InterpolatedObject(InterpolatedObject anInterpolatedObject)
    {
        super();
        for (int i = 0; i < anInterpolatedObject.getObjectPoints().size(); i++)
        {
            setNewPoint((Point2D.Float) (anInterpolatedObject.getObjectPoints().elementAt(i)));
        }
        this.setStatus( anInterpolatedObject.getStatus());
        this.setFilled(anInterpolatedObject.filled);
        this.isDisplayRelative = anInterpolatedObject.isDisplayRelative;
    
    }
    
    
    /**
    * Returns the part of the InterpolatedObject which should be redraw if the Circle2DObject will be created. 
    *
    * @param nextPoint The next drawing Point. 
    * @return The part of the PaintObject which should be redraw. 
    * @see PaintObject#getMovePaintObject
    */
    
    public  PaintObject getMovePaintObject(Point2D.Float nextPoint)
    {
      return   new CurveObject(isDisplayRelative, countPoint,firstPoint,point1, point2, nextPoint);
    } 
    
    /**
     * Insert a new point to the objectPoints. 
     * 
     * @param The new point of the InterpolatedObject
     * @since 30.04.1999
     */
    
    public  void setNewPoint(Point2D.Float newPoint)
    {
      if (objectPoints.size() == 0)
      {
         status = STATUS_BEGIN;
         thisShape = new GeneralPath();
         thisShape.moveTo(newPoint.x,newPoint.y);
         helpShape = new GeneralPath();
         countPoint = 1;
         firstPoint = new Point2D.Float(newPoint.x,newPoint.y);
         helpShape.moveTo(newPoint.x,newPoint.y);
        
      }
      else 
      {
         if (countPoint == 1) 
         {
            point1 = new Point2D.Float(newPoint.x,newPoint.y);
            point2 = new Point2D.Float(newPoint.x,newPoint.y);
            helpShape.curveTo(point1.x, point1.y, point2.x, point2.y, newPoint.x, newPoint.y);
            
            countPoint = 2;
         }
         else if(countPoint == 2) 
         {
            point2 = new Point2D.Float(newPoint.x,newPoint.y);
            helpShape.curveTo(point1.x, point1.y, point2.x, point2.y, newPoint.x, newPoint.y);
            countPoint = 3;
            
         }
         else
         {
            helpShape = new GeneralPath();
            helpShape.moveTo(newPoint.x,newPoint.y);
            
            firstPoint = new Point2D.Float(newPoint.x,newPoint.y);
            
            thisShape.curveTo(point1.x, point1.y, point2.x, point2.y, newPoint.x, newPoint.y);
            countPoint = 1;
         }
      }
      status = STATUS_WORK;
      objectPoints.add(newPoint);
    }
    /**
     * Gets the Shape of the InterpolatedObject.
     * 
     * @return The Shape of the InterpolatedObject
     * @since 30.04.1999
     */
    public  Shape getShape()
    {
        return thisShape;
    }
    /**
     * Gets the Shape of the InterpolatedObject.
     * 
     * @return The Shape of the InterpolatedObject.
     * @since 30.04.1999
     */
    
   public  void drawShape(Graphics2D g)
   {
      if ((g!=null) && (thisShape!= null))
      {
       
         
         g.draw(thisShape);
      }
   }
    /**
    * Returns a real copy of the InterpolatedObject.
    *
    * @return a real copy of this InterpolatedObject.
    * @since 30.04.1999
    */
    public PaintObject copy()
    {
      return  new InterpolatedObject(this);
    }

    /**
    * Returns new InterpolatedObject with the  same properties as the current object.
    *
    * @return A new InterpolatedObject with the same properties.
    * @since 30.04.1999
    */
    public  PaintObject getNewPaintObject()
    {
      return new InterpolatedObject(filled,isDisplayRelative,isShutter);
    }
}

/*
 *  CVS Log
 *  $Log: InterpolatedObject.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:11  Schroeter
 *  initial commit of release 1.0
 *
*/
