/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Schroeter $
 *  Last update : $Date: 1999/05/14 09:33:10 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/

package jToolkit.Gui;

import javax.swing.*;
import java.awt.event.*;

/**
 * The CommandJButton extends the normal (Swing-)JButton with an automatic command
 * call when the button is pressed. 
 *
 * Usage:
 * 
 * class FooClass extends JPanel implements CommandButtonListener
 * {
 *  final int IDOK = 1;
 *  final int IDCANCEL = 2;
 *
 *  void Constructor ()
 *  {
 *      CommandJButton ok = new CommandJButton ("OK", this, IDOK);
 *      CommandJButton cancel = new CommandJButton ("Cancel", this, IDCANCEL);
 *      add (ok);
 *      add (cancel);
 *  }
 * 
 *  void ButtonClicked (int ID);
 *  {
 *      if (ID == IDOK) doOK(); // OK pressed
 *      if (ID == IDCANCEL) doCancel(); // Cancel pres
 *  }
 * } 
 *
 * @author Andreas Schroeter
 * @since 30.03.
*/
public class CommandJButton extends JButton implements ActionListener
{
    private int ID;
    private CommandButtonListener cbl;
    
    public CommandJButton (String label, CommandButtonListener cbl, int ID)
    {
        super (label);
        this.ID = ID;
        this.cbl = cbl;
        addActionListener (this);
    }

    public CommandJButton (CommandButtonListener cbl, int ID)
    {
        super ();
        this.ID = ID;
        this.cbl = cbl;
        addActionListener (this);
    }

    public CommandJButton(String text, Icon icon, CommandButtonListener cbl, int ID)
    {
        super (text, icon);
        this.ID = ID;
        this.cbl = cbl;
        addActionListener (this);
    }


    public CommandJButton(Icon icon, CommandButtonListener cbl, int ID)
    {
        super (icon);
        this.ID = ID;
        this.cbl = cbl;
        addActionListener (this);
    }
    
    public void actionPerformed(ActionEvent e)
    {
        if (e.getSource() == this) cbl.ButtonClicked (ID);
    }
}
/*
 *  CVS Log
 *  $Log: CommandJButton.java,v $
 *  Revision 1.1.1.1  1999/05/14 09:33:10  Schroeter
 *  initial commit of release 1.0
 *
*/
